////////////////////////////////////////////////////////////////////////////
// PAXScript Importing
// Author: Alexander Baranovsky (ab@cable.netlux.org)
// ========================================================================
// Copyright (c) Alexander Baranovsky, 2003. All rights reserved.                                  
// Code Version: 1.5
// ========================================================================
// Unit: IMP_Classes.pas
// ========================================================================
////////////////////////////////////////////////////////////////////////////


// Imports classes:
//
//   TBasicAction
//   TBasicActionLink
//   TBits
//   TCollection
//   TCollectionItem
//   TComponent
//   TCustomMemoryStream
//   TFiler
//   THandleStream
//   TList
//   TParser
//   TPersistent
//   TReader
//   TStream
//   TStringList
//   TStrings
//   TStringStream
//   TThread
//   TThreadList
//   TWriter


unit IMP_Classes;
interface
uses
  Classes,
  PaxScripter;

implementation

//---- TList ----------------------------------------------------
function TList_GetCapacity: Integer;
begin
 result := TList(_Self).Capacity;
end;

procedure TList_SetCapacity(NewCapacity: Integer);
begin
  TList(_Self).Capacity := NewCapacity;
end;

function TList_GetCount: Integer;
begin
 result := TList(_Self).Count;
end;

procedure TList_SetCount(NewCount: Integer);
begin
 TList(_Self).Count := NewCount;
end;

function TList_Get(Index: Integer): Pointer;
begin
 result := TList(_Self).Items[Index];
end;

procedure TList_Put(Index: Integer; Item: Pointer);
begin
 TList(_Self).Items[Index] := Item;
end;

//---- TThreadList ----------------------------------------------

function TThreadList_GetDuplicates: TDuplicates;
begin
 result := TThreadList(_Self).Duplicates;
end;

procedure TThreadList_SetDuplicates(Value: TDuplicates);
begin
 TThreadList(_Self).Duplicates := Value;
end;

//---- TBits ----------------------------------------------------

function TBits_GetBit(Index: Integer): Boolean;
begin
  result := TBits(_Self).Bits[Index];
end;

procedure TBits_SetBit(Index: Integer; Value: Boolean);
begin
 TBits(_Self).Bits[Index] := Value;
end;

function TBits_GetSize: Integer;
begin
 result := TBits(_Self).Size;
end;

procedure TBits_SetSize(Value: Integer);
begin
 TBits(_Self).Size := Value;
end;

//---- TCollectionItem ----------------------------------------------------

function TCollectionItem_GetCollection: TCollection;
begin
 result := TCollectionItem(_Self).Collection;
end;

procedure TCollectionItem_SetCollection(Value: TCollection);
begin
 TCollectionItem(_Self).Collection := Value;
end;

function TCollectionItem_GetID: Integer;
begin
 result := TCollectionItem(_Self).ID;
end;

function TCollectionItem_GetIndex: Integer;
begin
 result := TCollectionItem(_Self).Index;
end;

procedure TCollectionItem_SetIndex(Value: Integer);
begin
 TCollectionItem(_Self).Index := Value;
end;

function TCollectionItem_GetDisplayName: string;
begin
 result := TCollectionItem(_Self).DisplayName;
end;

procedure TCollectionItem_SetDisplayName(const Value: string);
begin
 TCollectionItem(_Self).DisplayName := Value;
end;

//---- TCollection ----------------------------------------------------

function TCollection_GetCount: Integer;
begin
 result := TCollection(_Self).Count;
end;

function TCollection_GetItemClass: TCollectionItemClass;
begin
 result := TCollection(_Self).ItemClass;
end;

function TCollection_GetItem(Index: Integer): TCollectionItem;
begin
 result := TCollection(_Self).Items[Index];
end;

procedure TCollection_SetItem(Index: Integer; Value: TCollectionItem);
begin
 TCollection(_Self).Items[Index] := Value;
end;

//---- TStrings ----------------------------------------------------

function TStrings_GetCapacity: Integer;
begin
 result := TStrings(_Self).Capacity;
end;

procedure TStrings_SetCapacity(NewCapacity: Integer);
begin
 TStrings(_Self).Capacity := NewCapacity;
end;

function TStrings_GetCommaText: string;
begin
 result := TStrings(_Self).CommaText;
end;

procedure TStrings_SetCommaText(const Value: string);
begin
 TStrings(_Self).CommaText := Value;
end;

function TStrings_GetCount: Integer;
begin
 result := TStrings(_Self).Count;
end;

function TStrings_GetName(Index: Integer): string;
begin
 result := TStrings(_Self).Names[Index];
end;

function TStrings_GetObject(Index: Integer): TObject;
begin
 result := TStrings(_Self).Objects[Index];
end;

procedure TStrings_PutObject(Index: Integer; AObject: TObject);
begin
 TStrings(_Self).Objects[Index] := AObject;
end;

function TStrings_GetValue(const Name: string): string;
begin
 result := TStrings(_Self).Values[Name];
end;

procedure TStrings_SetValue(const Name, Value: string);
begin
 TStrings(_Self).Values[Name] := Value;
end;

function TStrings_Get(Index: Integer): string;
begin
  result := TStrings(_Self).Strings[Index];
end;

procedure TStrings_Put(Index: Integer; const S: string);
begin
  TStrings(_Self).Strings[Index] := S;
end;

function TStrings_GetText: string;
begin
 result := TStrings(_Self).Text;
end;

procedure TStrings_SetText(const Value: string);
begin
 TStrings(_Self).Text := Value;
end;

//---- TStringList ----------------------------------------------------

function TStringList_GetDuplicates: TDuplicates;
begin
 result := TStringList(_Self).Duplicates;
end;

procedure TStringList_SetDuplicates(Value: TDuplicates);
begin
 TStringList(_Self).Duplicates := Value;
end;

function TStringList_GetSorted: Boolean;
begin
 result := TStringList(_Self).Sorted;
end;

procedure TStringList_SetSorted(Value: Boolean);
begin
 TStringList(_Self).Sorted := Value;
end;

function TStringList_GetOnChange: TNotifyEvent;
begin
 result := TStringList(_Self).OnChange;
end;

procedure TStringList_SetOnChange(Value: TNotifyEvent);
begin
 TStringList(_Self).OnChange := Value;
end;

function TStringList_GetOnChanging: TNotifyEvent;
begin
 result := TStringList(_Self).OnChanging;
end;

procedure TStringList_SetOnChanging(Value: TNotifyEvent);
begin
 TStringList(_Self).OnChanging := Value;
end;

//---- TStream ----------------------------------------------------

function TStream_GetPosition: Longint;
begin
 result := TStream(_Self).Position;
end;

procedure TStream_SetPosition(Pos: Longint);
begin
 TStream(_Self).Position := Pos;
end;

function TStream_GetSize: Longint;
begin
 result := TStream(_Self).Size;
end;

procedure TStream_SetSize(NewSize: Longint);
begin
 TStream(_Self).Size := NewSize;
end;

//---- THandleStream ----------------------------------------------------

function THandleStream_GetHandle: Integer;
begin
 result := THandleStream(_Self).Handle;
end;

//---- TCustomMemoryStream --------------------------------------

function TCustomMemoryStream_GetMemory: Pointer;
begin
 result := TCustomMemoryStream(_Self).Memory;
end;

//---- TStringStream --------------------------------------------

function TStringStream_GetDataString: String;
begin
 result := TStringStream(_Self).DataString;
end;

//---- TFiler ---------------------------------------------------

function TFiler_GetRoot: TComponent;
begin
 result := TFiler(_Self).Root;
end;

procedure TFiler_SetRoot(Value: TComponent);
begin
 TFiler(_Self).Root := Value;
end;

function TFiler_GetLookupRoot: TComponent;
begin
 result := TFiler(_Self).LookupRoot;
end;

function TFiler_GetAncestor: TPersistent;
begin
 result := TFiler(_Self).Ancestor;
end;

procedure TFiler_SetAncestor(Value: TPersistent);
begin
 TFiler(_Self).Ancestor := Value;
end;

function TFiler_GetIgnoreChildren: Boolean;
begin
 result := TFiler(_Self).IgnoreChildren;
end;

procedure TFiler_SetIgnoreChildren(Value: Boolean);
begin
 TFiler(_Self).IgnoreChildren := Value;
end;

//---- TReader ----------------------------------------------------

function TReader_GetOwner: TComponent;
begin
 result := TReader(_Self).Owner;
end;

procedure TReader_SetOwner(Value: TComponent);
begin
 TReader(_Self).Owner := Value;
end;

function TReader_GetParent: TComponent;
begin
 result := TReader(_Self).Parent;
end;

procedure TReader_SetParent(Value: TComponent);
begin
 TReader(_Self).Parent := Value;
end;

function TReader_GetPosition: Longint;
begin
 result := TReader(_Self).Position;
end;

procedure TReader_SetPosition(Value: Longint);
begin
 TReader(_Self).Position := Value;
end;

function TReader_GetOnError: TReaderError;
begin
 result := TReader(_Self).OnError;
end;

procedure TReader_SetOnError(Value: TReaderError);
begin
 TReader(_Self).OnError := Value;
end;

function TReader_GetOnFindMethod: TFindMethodEvent;
begin
 result := TReader(_Self).OnFindMethod;
end;

procedure TReader_SetOnFindMethod(Value: TFindMethodEvent);
begin
 TReader(_Self).OnFindMethod := Value;
end;

function TReader_GetOnSetName: TSetNameEvent;
begin
 result := TReader(_Self).OnSetName;
end;

procedure TReader_SetOnSetName(Value: TSetNameEvent);
begin
 TReader(_Self).OnSetName := Value;
end;

function TReader_GetOnReferenceName: TReferenceNameEvent;
begin
 result := TReader(_Self).OnReferenceName;
end;

procedure TReader_SetOnReferenceName(Value: TReferenceNameEvent);
begin
 TReader(_Self).OnReferenceName := Value;
end;

function TReader_GetOnAncestorNotFound: TAncestorNotFoundEvent;
begin
 result := TReader(_Self).OnAncestorNotFound;
end;

procedure TReader_SetOnAncestorNotFound(Value: TAncestorNotFoundEvent);
begin
 TReader(_Self).OnAncestorNotFound := Value;
end;

function TReader_GetOnCreateComponent: TCreateComponentEvent;
begin
 result := TReader(_Self).OnCreateComponent;
end;

procedure TReader_SetOnCreateComponent(Value: TCreateComponentEvent);
begin
 TReader(_Self).OnCreateComponent := Value;
end;

//---- TWriter ---------------------------------------------------

function TWriter_GetPosition: Longint;
begin
 result := TWriter(_Self).Position;
end;

procedure TWriter_SetPosition(Value: Longint);
begin
 TWriter(_Self).Position := Value;
end;

function TWriter_GetRootAncestor: TComponent;
begin
 result := TWriter(_Self).RootAncestor;
end;

procedure TWriter_SetRootAncestor(Value: TComponent);
begin
 TWriter(_Self).RootAncestor := Value;
end;

function TWriter_GetOnFindAncestor: TFindAncestorEvent;
begin
 result := TWriter(_Self).OnFindAncestor;
end;

procedure TWriter_SetOnFindAncestor(Value: TFindAncestorEvent);
begin
 TWriter(_Self).OnFindAncestor := Value;
end;

//---- TParser ----------------------------------------------------

function TParser_GetFloatType: Char;
begin
 result := TParser(_Self).FloatType;
end;

function TParser_GetSourceLine: Integer;
begin
 result := TParser(_Self).SourceLine;
end;

function TParser_GetToken: Char;
begin
 result := TParser(_Self).Token;
end;

//----------- TThread ------------------------------------------

function TThread_GetFreeOnTerminate: Boolean;
begin
 result := TThread(_Self).FreeOnTerminate;
end;

procedure TThread_SetFreeOnTerminate(Value: Boolean);
begin
 TThread(_Self).FreeOnTerminate := Value;
end;

function TThread_GetSuspended: Boolean;
begin
 result := TThread(_Self).Suspended;
end;

procedure TThread_SetSuspended(Value: Boolean);
begin
 TThread(_Self).Suspended := Value;
end;

function TThread_GetOnTerminate: TNotifyEvent;
begin
 result := TThread(_Self).OnTerminate;
end;

procedure TThread_SetOnTerminate(Value: TNotifyEvent);
begin
 TThread(_Self).OnTerminate := Value;
end;

// --------- TComponent ---------------------------------------

function TComponent_GetComponent(AIndex: Integer): TComponent;
begin
  result := TComponent(_Self).Components[AIndex];
end;

function TComponent_GetComponentCount: Integer;
begin
  result := TComponent(_Self).ComponentCount;
end;

function TComponent_GetComponentIndex: Integer;
begin
 result := TComponent(_Self).ComponentIndex;
end;

procedure TComponent_SetComponentIndex(Value: Integer);
begin
 TComponent(_Self).ComponentIndex := Value;
end;

function TComponent_GetComponentState: TComponentState;
begin
 result := TComponent(_Self).ComponentState;
end;

function TComponent_GetComponentStyle: TComponentStyle;
begin
 result := TComponent(_Self).ComponentStyle;
end;

function TComponent_GetDesignInfo: Longint;
begin
 result := TComponent(_Self).DesignInfo;
end;

procedure TComponent_SetDesignInfo(Value: Longint);
begin
 TComponent(_Self).DesignInfo := Value;
end;

function TComponent_GetOwner: TComponent;
begin
 result := TComponent(_Self).Owner;
end;

function TComponent_GetVCLComObject: Pointer;
begin
 result := TComponent(_Self).VCLComObject;
end;

procedure TComponent_SetVCLComObject(Value: Pointer);
begin
 TComponent(_Self).VCLComObject := Value;
end;

// ----- TBasicActionLink -------------------------------------

function TBasicActionLink_GetAction: TBasicAction;
begin
 result := TBasicActionLink(_Self).Action;
end;

procedure TBasicActionLink_SetAction(Value: TBasicAction);
begin
 TBasicActionLink(_Self).Action := Value;
end;

function TBasicActionLink_GetOnChange: TNotifyEvent;
begin
 result := TBasicActionLink(_Self).OnChange;
end;

procedure TBasicActionLink_SetOnChange(Value: TNotifyEvent);
begin
 TBasicActionLink(_Self).OnChange := Value;
end;

// ----- TBasicAction ----------------------------------------------

function TBasicAction_GetOnExecute: TNotifyEvent;
begin
 result := TBasicAction(_Self).OnExecute;
end;

procedure TBasicAction_SetOnExecute(Value: TNotifyEvent);
begin
 TBasicAction(_Self).OnExecute := Value;
end;

function TBasicAction_GetOnUpdate: TNotifyEvent;
begin
 result := TBasicAction(_Self).OnUpdate;
end;

procedure TBasicAction_SetOnUpdate(Value: TNotifyEvent);
begin
 TBasicAction(_Self).OnUpdate := Value;
end;

var
  H: Integer;
initialization

  H := RegisterNamespace('Classes');

//---- TPersistent ----------------------------------------
  RegisterClassType(TPersistent, H);

  RegisterMethod(TPersistent, 'constructor Create;', @TPersistent.Create);
  RegisterMethod(TPersistent, 'procedure Assign(Source: TPersistent);', @TPersistent.Assign);
  RegisterMethod(TPersistent, 'function  GetNamePath: string;', @TPersistent.GetNamePath);
  RegisterRoutine('function FindClass(const ClassName: string): TPersistentClass;', @FindClass);
  RegisterRoutine('function GetClass(const ClassName: string): TPersistentClass;', @GetClass);
  RegisterRoutine('procedure RegisterClass(AClass: TPersistentClass);', @RegisterClass);

//---- TList ----------------------------------------------------
  RegisterClassType(TList, H);
  RegisterMethod(TList, 'constructor Create;', @TList.Create);
  RegisterMethod(TList, 'function Add(Item: Pointer): Integer;', @TList.Add);
  RegisterMethod(TList, 'procedure Clear; virtual;', @TList.Clear);
  RegisterMethod(TList, 'procedure Delete(Index: Integer);', @TList.Delete);
  RegisterMethod(TList, 'procedure Exchange(Index1, Index2: Integer);', @TList.Exchange);
  RegisterMethod(TList, 'function Expand: TList;', @TList.Expand);
  RegisterMethod(TList, 'function First: Pointer;', @TList.First);
  RegisterMethod(TList, 'function IndexOf(Item: Pointer): Integer;', @TList.IndexOf);
  RegisterMethod(TList, 'procedure Insert(Index: Integer; Item: Pointer);', @TList.Insert);
  RegisterMethod(TList, 'function Last: Pointer;', @TList.Last);
  RegisterMethod(TList, 'procedure Move(CurIndex, NewIndex: Integer);', @TList.Move);
  RegisterMethod(TList, 'function Remove(Item: Pointer): Integer;', @TList.Remove);
  RegisterMethod(TList, 'procedure Pack;', @TList.Pack);

  RegisterMethod(TList, 'function GetCapacity: Integer;', @TList_GetCapacity, Fake);
  RegisterMethod(TList, 'procedure SetCapacity(NewCapacity: Integer);', @TList_SetCapacity, Fake);
  RegisterProperty(TList, 'property Capacity: Integer read GetCapacity write SetCapacity;');

  RegisterMethod(TList, 'function GetCount: Integer;', @TList_GetCount, Fake);
  RegisterMethod(TList, 'procedure SetCount(NewCount: Integer);',  @TList_SetCount, Fake);
  RegisterProperty(TList, 'property Count: Integer read GetCount write SetCount;');

  RegisterMethod(TList, 'function Get(Index: Integer): Pointer;', @TList_Get, Fake);
  RegisterMethod(TList, 'procedure Put(Index: Integer; Item: Pointer);', @TList_Put, Fake);
  RegisterProperty(TList, 'property Items[Index: Integer]: Pointer read Get write Put; default;');

//---- TThreadList -------------------------------------------------------------

  RegisterClassType(TThreadList, H);

  RegisterMethod(TThreadList, 'constructor Create;', @TThreadList.Create);
  RegisterMethod(TThreadList, 'procedure Add(Item: Pointer);', @TThreadList.Add);
  RegisterMethod(TThreadList, 'procedure Clear;', @TThreadList.Clear);
  RegisterMethod(TThreadList, 'function  LockList: TList;', @TThreadList.LockList);
  RegisterMethod(TThreadList, 'procedure Remove(Item: Pointer);', @TThreadList.Remove);
  RegisterMethod(TThreadList, 'procedure UnlockList;', @TThreadList.UnlockList);
  RegisterMethod(TThreadList, 'function GetDuplicates: TDuplicates;',
                @TThreadList_GetDuplicates, Fake);
  RegisterMethod(TThreadList, 'procedure SetDuplicates(Value: TDuplicates);',
                @TThreadList_SetDuplicates, Fake);
  RegisterProperty(TThreadList, 'property Duplicates: TDuplicates read'
                +' GetDuplicates write SetDuplicates;');

//---- TBits -------------------------------------------------------------------

  RegisterClassType(TBits, H);

  RegisterMethod(TBits, 'constructor Create;', @TBits.Create);
  RegisterMethod(TBits, 'function OpenBit: Integer;',
                @TBits.OpenBit);
  RegisterMethod(TBits, 'function GetBit(Index: Integer): Boolean;',
                @TBits_GetBit, Fake);
  RegisterMethod(TBits, 'procedure SetBit(Index: Integer; Value: Boolean);',
                @TBits_SetBit, Fake);
  RegisterProperty(TBits, 'property Bits[Index: Integer]: Boolean read GetBit'
                +' write SetBit;');
  RegisterMethod(TBits, 'function GetSize: Integer;',
                @TBits_GetSize, Fake);
  RegisterMethod(TBits, 'procedure SetSize(Value: Integer);',
                @TBits_SetSize, Fake);
  RegisterProperty(TBits, 'property Size: Integer read GetSize write SetSize;');

//---- TCollectionItem ---------------------------------------------------------

  RegisterClassType(TCollectionItem, H);

  RegisterMethod(TCollectionItem, 'constructor Create(Collection: TCollection); virtual;',
                @TCollectionItem.Create);
  RegisterMethod(TCollectionItem, 'function GetNamePath: string; override;',
                @TCollectionItem.GetNamePath);
  RegisterMethod(TCollectionItem, 'function GetCollection: TCollection;',
                @TCollectionItem_GetCollection, Fake);
  RegisterMethod(TCollectionItem, 'procedure SetCollection(Value: TCollection);',
                @TCollectionItem_SetCollection, Fake);
  RegisterProperty(TCollectionItem, 'property Collection: TCollection read'
                +' GetCollection write SetCollection;');
  RegisterMethod(TCollectionItem, 'function GetID: Integer;',
                @TCollectionItem_GetID, Fake);
  RegisterProperty(TCollectionItem, 'property ID: Integer read GetID;');
  RegisterMethod(TCollectionItem, 'function GetIndex: Integer;',
                @TCollectionItem_GetIndex, Fake);
  RegisterMethod(TCollectionItem, 'procedure SetIndex(Value: Integer);',
                @TCollectionItem_SetIndex, Fake);
  RegisterProperty(TCollectionItem, 'property Index: Integer read GetIndex write'
                +' SetIndex;');
  RegisterMethod(TCollectionItem, 'function GetDisplayName: string;',
                @TCollectionItem_GetDisplayName, Fake);
  RegisterMethod(TCollectionItem, 'procedure SetDisplayName(const Value: string);',
                @TCollectionItem_SetDisplayName, Fake);
  RegisterProperty(TCollectionItem, 'property DisplayName: string read'
                +' GetDisplayName write SetDisplayName;');

//---- TCollection -------------------------------------------------------------

  RegisterClassType(TCollection, H);

  RegisterMethod(TCollection, 'constructor Create(ItemClass: TCollectionItemClass);',
                 @TCollection.Create);
  RegisterMethod(TCollection, 'function Add: TCollectionItem;',
                @TCollection.Add);
  RegisterMethod(TCollection, 'procedure Assign(Source: TPersistent); override;',
                @TCollection.Assign);
  RegisterMethod(TCollection, 'procedure BeginUpdate; virtual;',
                @TCollection.BeginUpdate);
  RegisterMethod(TCollection, 'procedure Clear;',
                @TCollection.Clear);
  RegisterMethod(TCollection, 'procedure Delete(Index: Integer);',
                @TCollection.Delete);
  RegisterMethod(TCollection, 'procedure EndUpdate; virtual;',
                @TCollection.EndUpdate);
  RegisterMethod(TCollection, 'function FindItemID(ID: Integer): TCollectionItem;',
                @TCollection.FindItemID);
  RegisterMethod(TCollection, 'function GetNamePath: string; override;',
                @TCollection.GetNamePath);
  RegisterMethod(TCollection, 'function Insert(Index: Integer): TCollectionItem;',
                @TCollection.Insert);
  RegisterMethod(TCollection, 'function GetCount: Integer;',
                @TCollection_GetCount, Fake);
  RegisterProperty(TCollection, 'property Count: Integer read GetCount;');
  RegisterMethod(TCollection, 'function GetItemClass: TCollectionItemClass;',
                 @TCollection_GetItemClass, Fake);
  RegisterProperty(TCollection, 'property ItemClass: TCollectionItemClass read'
                 +' GetItemClass;');
  RegisterMethod(TCollection, 'function GetItem(Index: Integer): TCollectionItem;',
                @TCollection_GetItem, Fake);
  RegisterMethod(TCollection, 'procedure SetItem(Index: Integer; Value: TCollectionItem);',
                @TCollection_SetItem, Fake);
  RegisterProperty(TCollection, 'property Items[Index: Integer]: TCollectionItem'
                +' read GetItem write SetItem;');

//---- TOwnedCollection --------------------------------------------------------

  RegisterClassType(TOwnedCollection, H);
  RegisterMethod(TOwnedCollection, 'constructor Create(AOwner: TPersistent; ItemClass: TCollectionItemClass);',
       @TOwnedCollection.Create);

//---- TStrings ----------------------------------------------------------------

  RegisterClassType(TStrings, H);
  RegisterMethod(TStrings, 'constructor Create;', @TStrings.Create);
  RegisterMethod(TStrings, 'function Add(const S: string): Integer; virtual;',
                @TStrings.Add);
  RegisterMethod(TStrings, 'function AddObject(const S: string; AObject: TObject): Integer; virtual;',
                @TStrings.AddObject);
  RegisterMethod(TStrings, 'procedure Append(const S: string);',
                @TStrings.Append);
  RegisterMethod(TStrings, 'procedure AddStrings(Strings: TStrings); virtual;',
                @TStrings.AddStrings);
  RegisterMethod(TStrings, 'procedure Assign(Source: TPersistent); override;',
                @TStrings.Assign);
  RegisterMethod(TStrings, 'procedure BeginUpdate;',
                @TStrings.BeginUpdate);
  RegisterMethod(TStrings, 'procedure EndUpdate;',
                @TStrings.EndUpdate);
  RegisterMethod(TStrings, 'function Equals(Strings: TStrings): Boolean;',
                @TStrings.EndUpdate);
  RegisterMethod(TStrings, 'procedure Exchange(Index1, Index2: Integer); virtual;',
                @TStrings.Exchange);
  RegisterMethod(TStrings, 'function GetText: PChar; virtual;',
                @TStrings.GetText);
  RegisterMethod(TStrings, 'function IndexOf(const S: string): Integer; virtual;',
                @TStrings.IndexOf);
  RegisterMethod(TStrings, 'function IndexOfName(const Name: string): Integer;',
                @TStrings.IndexOfName);
  RegisterMethod(TStrings, 'function IndexOfObject(AObject: TObject): Integer;',
                @TStrings.IndexOfObject);
  RegisterMethod(TStrings, 'procedure InsertObject(Index: Integer; const S: string;'
                +' AObject: TObject);',
                @TStrings.InsertObject);
  RegisterMethod(TStrings, 'procedure LoadFromFile(const FileName: string); virtual;',
                @TStrings.LoadFromFile);
  RegisterMethod(TStrings, 'procedure LoadFromStream(Stream: TStream); virtual;',
                @TStrings.LoadFromStream);
  RegisterMethod(TStrings, 'procedure Move(CurIndex, NewIndex: Integer); virtual;',
                @TStrings.Move);
  RegisterMethod(TStrings, 'procedure SaveToFile(const FileName: string); virtual;',
                @TStrings.SaveToFile);
  RegisterMethod(TStrings, 'procedure SaveToStream(Stream: TStream); virtual;',
                @TStrings.SaveToStream);
  RegisterMethod(TStrings, 'function GetCapacity: Integer;',
                @TStrings_GetCapacity, Fake);
  RegisterMethod(TStrings, 'procedure SetCapacity(NewCapacity: Integer);',
                @TStrings_SetCapacity, Fake);
  RegisterProperty(TStrings, 'property Capacity: Integer read GetCapacity write'
                +' SetCapacity;');
  RegisterMethod(TStrings, 'function GetCommaText: string;',
                @TStrings_GetCommaText, Fake);
  RegisterMethod(TStrings, 'procedure SetCommaText(const Value: string);',
                @TStrings_SetCommaText, Fake);
  RegisterProperty(TStrings, 'property CommaText: string read GetCommaText write'
                +' SetCommaText;');
  RegisterMethod(TStrings, 'function GetCount: Integer;',
                @TStrings_GetCount, Fake);
  RegisterProperty(TStrings, 'property Count: Integer read GetCount;');
  RegisterMethod(TStrings, 'function GetName(Index: Integer): string;',
                @TStrings_GetName, Fake);
  RegisterProperty(TStrings, 'property Names[Index: Integer]: string read GetName;');
  RegisterMethod(TStrings, 'function GetObject(Index: Integer): TObject;',
                @TStrings_GetObject, Fake);
  RegisterMethod(TStrings, 'procedure PutObject(Index: Integer; AObject: TObject);',
                @TStrings_PutObject, Fake);
  RegisterProperty(TStrings, 'property Objects[Index: Integer]: TObject read'
                +' GetObject write PutObject;');
  RegisterMethod(TStrings, 'function GetValue(const Name: string): string;',
                @TStrings_GetValue, Fake);
  RegisterMethod(TStrings, 'procedure SetValue(const Name, Value: string);',
                @TStrings_SetValue, Fake);
  RegisterProperty(TStrings, 'property Values[const Name: string]: string read'
                +' GetValue write SetValue;');
  RegisterMethod(TStrings, 'function Get(Index: Integer): string;',
                @TStrings_Get, Fake);
  RegisterMethod(TStrings, 'procedure Put(Index: Integer; const S: string);',
                @TStrings_Put, Fake);
  RegisterProperty(TStrings, 'property Strings[Index: Integer]: string read Get write Put; default;');
  RegisterMethod(TStrings, 'function GetTextStr: string;',
                @TStrings_GetText, Fake);
  RegisterMethod(TStrings, 'procedure SetTextStr(const Value: string);',
                @TStrings_SetText, Fake);
  RegisterProperty(TStrings, 'property Text: string read GetText write SetText;');

//---- TStringList -------------------------------------------------------------

  RegisterClassType(TStringList, H);
  RegisterMethod(TStringList, 'constructor Create;', @TStringList.Create);
  RegisterMethod(TStringList, 'function Add(const S: string): Integer; override;',
                @TStringList.Add);
  RegisterMethod(TStringList, 'procedure Clear; override;',
                @TStringList.Clear);
  RegisterMethod(TStringList, 'procedure Delete(Index: Integer); override;',
                @TStringList.Delete);
  RegisterMethod(TStringList, 'procedure Exchange(Index1, Index2: Integer); override;',
                @TStringList.Exchange);
  RegisterMethod(TStringList, 'function Find(const S: string; var Index: Integer): Boolean; virtual;',
                @TStringList.Find);
  RegisterMethod(TStringList, 'function IndexOf(const S: string): Integer; override;',
                @TStringList.IndexOf);
  RegisterMethod(TStringList, 'procedure Insert(Index: Integer; const S: string); override;',
                @TStringList.Insert);
  RegisterMethod(TStringList, 'procedure Sort; virtual;',
                @TStringList.Sort);
  RegisterMethod(TStringList, 'procedure CustomSort(Compare: TStringListSortCompare); virtual;',
                @TStringList.CustomSort);
  RegisterMethod(TStringList, 'function GetDuplicates: TDuplicates;',
                @TStringList_GetDuplicates, Fake);
  RegisterMethod(TStringList, 'procedure SetDuplicates(Value: TDuplicates);',
                @TStringList_SetDuplicates, Fake);
  RegisterProperty(TStringList, 'property Duplicates: TDuplicates read'
                +' GetDuplicates write SetDuplicates;');
  RegisterMethod(TStringList, 'function GetSorted: Boolean;',
                @TStringList_GetSorted, Fake);
  RegisterMethod(TStringList, 'procedure SetSorted(Value: Boolean);',
                @TStringList_SetSorted, Fake);
  RegisterProperty(TStringList, 'property Sorted: Boolean read GetSorted write SetSorted;');
  RegisterMethod(TStringList, 'function GetOnChange: TNotifyEvent;',
                @TStringList_GetOnChange, Fake);
  RegisterMethod(TStringList, 'procedure SetOnChange(Value: TNotifyEvent);',
                @TStringList_SetOnChange, Fake);
  RegisterProperty(TStringList, 'property OnChange: TNotifyEvent read GetOnChange'
                +' write SetOnChange;');
  RegisterMethod(TStringList, 'function GetOnChanging: TNotifyEvent;',
                @TStringList_GetOnChanging, Fake);
  RegisterMethod(TStringList, 'procedure SetOnChanging(Value: TNotifyEvent);',
                @TStringList_SetOnChanging, Fake);
  RegisterProperty(TStringList, 'property OnChanging: TNotifyEvent read GetOnChanging'
                +' write SetOnChanging;');

//---- TStream -----------------------------------------------------------------

  RegisterClassType(TStream, H);
  RegisterMethod(TStream, 'constructor Create;', @TStream.Create);
  RegisterMethod(TStream, 'procedure ReadBuffer(var Buffer; Count: Longint);',
                @TStream.ReadBuffer);
  RegisterMethod(TStream, 'procedure WriteBuffer(const Buffer; Count: Longint);',
                @TStream.WriteBuffer);
  RegisterMethod(TStream, 'function CopyFrom(Source: TStream; Count: Longint): Longint;',
                @TStream.CopyFrom);
  RegisterMethod(TStream, 'function ReadComponent(Instance: TComponent): TComponent;',
                @TStream.ReadComponent);
  RegisterMethod(TStream, 'function ReadComponentRes(Instance: TComponent): TComponent;',
                @TStream.ReadComponentRes);
  RegisterMethod(TStream, 'procedure WriteComponent(Instance: TComponent);',
                @TStream.WriteComponent);
  RegisterMethod(TStream, 'procedure WriteComponentRes(const ResName: string; Instance: TComponent);',
                @TStream.WriteComponentRes);
  RegisterMethod(TStream, 'procedure WriteDescendent(Instance, Ancestor: TComponent);',
                @TStream.WriteDescendent);
  RegisterMethod(TStream, 'procedure WriteDescendentRes(const ResName: string; Instance, Ancestor: TComponent);',
                @TStream.WriteDescendentRes);
  RegisterMethod(TStream, 'procedure WriteResourceHeader(const ResName: string; out FixupInfo: Integer);',
                @TStream.WriteResourceHeader);
  RegisterMethod(TStream, 'procedure FixupResourceHeader(FixupInfo: Integer);',
                @TStream.FixupResourceHeader);
  RegisterMethod(TStream, 'procedure ReadResHeader;',
                @TStream.ReadResHeader);
  RegisterMethod(TStream, 'function GetPosition: Longint;',
                @TStream_GetPosition, Fake);
  RegisterMethod(TStream, 'procedure SetPosition(Value: Longint);',
                @TStream_SetPosition, Fake);
  RegisterProperty(TStream, 'property Position: Longint read GetPosition write'
                +' SetPosition;');
  RegisterMethod(TStream, 'function GetSize: Longint;',
                @TStream_GetSize, Fake);
  RegisterMethod(TStream, 'procedure SetSize(NewSize: Longint);',
                @TStream_SetSize, Fake);
  RegisterProperty(TStream, 'property Size: Longint read GetSize write SetSize;');

//---- THandleStream -----------------------------------------------------------

  RegisterClassType(THandleStream, H);
  RegisterMethod(THandleStream, 'constructor Create(AHandle: Integer);',
                @THandleStream.Create);
  RegisterMethod(THandleStream, 'function Read(var Buffer; Count: Longint): Longint; override;',
                @THandleStream.Read);
  RegisterMethod(THandleStream, 'function Write(const Buffer; Count: Longint): Longint; override;',
                @THandleStream.Write);
  RegisterMethod(THandleStream, 'function Seek(Offset: Longint; Origin: Word): Longint; override;',
                @THandleStream.Seek);
  RegisterMethod(THandleStream, 'function GetHandle: Integer;',
                @THandleStream_GetHandle, Fake);
  RegisterProperty(THandleStream, 'property Handle: Integer read GetHandle;');

//---- TFileStream -------------------------------------------------------------

  RegisterClassType(TFileStream, H);
  RegisterMethod(TFileStream, 'constructor Create(const FileName: string; Mode: Word);',
                @TFileStream.Create);

//---- TCustomMemoryStream -----------------------------------------------------

  RegisterClassType(TCustomMemoryStream, H);
  RegisterMethod(TCustomMemoryStream, 'constructor Create;', @TCustomMemoryStream.Create);
  RegisterMethod(TCustomMemoryStream, 'function Seek(Offset: Longint; Origin: Word): Longint; override;',
                @TCustomMemoryStream.Seek);
  RegisterMethod(TCustomMemoryStream, 'procedure SaveToStream(Stream: TStream);',
                @TCustomMemoryStream.SaveToStream);
  RegisterMethod(TCustomMemoryStream, 'procedure SaveToFile(const FileName: string);',
                @TCustomMemoryStream.SaveToFile);
  RegisterMethod(TCustomMemoryStream, 'function GetMemory: Pointer;',
                @TCustomMemoryStream_GetMemory, Fake);
  RegisterProperty(TCustomMemoryStream, 'property Memory: Pointer read GetMemory;');

//---- TMemoryStream -----------------------------------------------------------

  RegisterClassType(TMemoryStream, H);
  RegisterMethod(TMemoryStream, 'procedure Clear;',
                @TMemoryStream.Clear);
  RegisterMethod(TMemoryStream, 'procedure LoadFromStream(Stream: TStream);',
                @TMemoryStream.LoadFromStream);
  RegisterMethod(TMemoryStream, 'procedure LoadFromFile(const FileName: string);',
                @TMemoryStream.LoadFromFile);
  RegisterMethod(TMemoryStream, 'procedure SetSize(NewSize: Longint); override;',
                @TMemoryStream.SetSize);
  RegisterMethod(TMemoryStream, 'function Write(const Buffer; Count: Longint): Longint; override;',
                @TMemoryStream.Write);

//---- TStringStream -----------------------------------------------------------

  RegisterClassType(TStringStream, H);
  RegisterMethod(TStringStream, 'constructor Create(const AString: string);',
                @TStringStream.Create);
  RegisterMethod(TStringStream, 'function ReadString(Count: Longint): string;',
                @TStringStream.ReadString);
  RegisterMethod(TStringStream, 'function Seek(Offset: Longint; Origin: Word): Longint; override;',
                @TStringStream.Seek);
  RegisterMethod(TStringStream, 'function Write(const Buffer; Count: Longint): Longint; override;',
                @TStringStream.Write);
  RegisterMethod(TStringStream, 'procedure WriteString(const AString: string);',
                @TStringStream.WriteString);
  RegisterMethod(TStringStream, 'function GetDataString: String;',
                @TStringStream_GetDataString, Fake);
  RegisterProperty(TStringStream, 'property DataString: string read GetDataString;');

//---- TResourceStream ---------------------------------------------------------

  RegisterClassType(TResourceStream, H);
  RegisterMethod(TResourceStream, 'constructor Create(Instance: THandle; const ResName: string; ResType: PChar);',
                @TResourceStream.Create);
  RegisterMethod(TResourceStream, 'constructor CreateFromID(Instance: THandle; ResID: Integer; ResType: PChar);',
                @TResourceStream.CreateFromID);
  RegisterMethod(TResourceStream, 'function Write(const Buffer; Count: Longint): Longint; override;',
                @TResourceStream.Write);

//---- TFiler ------------------------------------------------------------------

  RegisterClassType(TFiler, H);
  RegisterMethod(TFiler, 'constructor Create(Stream: TStream; BufSize: Integer);',
                @TFiler.Create);
  RegisterMethod(TFiler, 'function GetRoot: TComponent;',
                @TFiler_GetRoot, Fake);
  RegisterMethod(TFiler, 'procedure SetRoot(Value: TComponent);',
                @TFiler_SetRoot, Fake);
  RegisterProperty(TFiler, 'property Root: TComponent read GetRoot write SetRoot;');
  RegisterMethod(TFiler, 'function GetLookupRoot: TComponent;',
                @TFiler_GetLookupRoot, Fake);
  RegisterProperty(TFiler, 'property LookupRoot: TComponent read GetLookupRoot;');
  RegisterMethod(TFiler, 'function GetAncestor: TPersistent;',
                @TFiler_GetAncestor, Fake);
  RegisterMethod(TFiler, 'procedure SetAncestor(Value: TPersistent);',
                @TFiler_SetAncestor, Fake);
  RegisterProperty(TFiler, 'property Ancestor: TPersistent read GetAncestor'
                +' write SetAncestor;');
  RegisterMethod(TFiler, 'function GetIgnoreChildren: Boolean;',
                @TFiler_GetIgnoreChildren, Fake);
  RegisterMethod(TFiler, 'procedure SetIgnoreChildren(Value: Boolean);',
                @TFiler_SetIgnoreChildren, Fake);
  RegisterProperty(TFiler, 'property IgnoreChildren: Boolean read'
                +' GetIgnoreChildren write SetIgnoreChildren;');

//---- TReader -----------------------------------------------------------------

  RegisterClassType(TReader, H);
  RegisterMethod(TReader, 'constructor Create(Stream: TStream; BufSize: Integer);',
                 @TReader.Create);

  RegisterMethod(TReader, 'procedure BeginReferences;',
                @TReader.BeginReferences);
  RegisterMethod(TReader, 'procedure CheckValue(Value: TValueType);',
                @TReader.CheckValue);
  RegisterMethod(TReader, 'function EndOfList: Boolean;',
                @TReader.EndOfList);
  RegisterMethod(TReader, 'procedure EndReferences;',
                @TReader.EndReferences);
  RegisterMethod(TReader, 'procedure FixupReferences;',
                @TReader.FixupReferences);
  RegisterMethod(TReader, 'procedure FlushBuffer; override;',
                @TReader.FlushBuffer);
  RegisterMethod(TReader, 'function NextValue: TValueType;',
                @TReader.NextValue);
  RegisterMethod(TReader, 'function ReadBoolean: Boolean;',
                @TReader.ReadBoolean);
  RegisterMethod(TReader, 'function ReadChar: Char;',
                @TReader.ReadChar);
  RegisterMethod(TReader, 'procedure ReadCollection(Collection: TCollection);',
                @TReader.ReadCollection);
  RegisterMethod(TReader, 'function ReadComponent(Component: TComponent): TComponent;',
                @TReader.ReadComponent);
  RegisterMethod(TReader, 'procedure ReadComponents(AOwner, AParent: TComponent;'
                +' Proc: TReadComponentsProc);',
                @TReader.ReadComponents);
  RegisterMethod(TReader, 'function ReadFloat: Extended;',
                @TReader.ReadFloat);
  RegisterMethod(TReader, 'function ReadSingle: Single;',
                @TReader.ReadSingle);
  RegisterMethod(TReader, 'function ReadCurrency: Currency;',
                @TReader.ReadCurrency);
  RegisterMethod(TReader, 'function ReadDate: TDateTime;',
                @TReader.ReadDate);
  RegisterMethod(TReader, 'function ReadIdent: string;',
                @TReader.ReadIdent);
  RegisterMethod(TReader, 'function ReadInteger: Longint;',
                @TReader.ReadInteger);
  RegisterMethod(TReader, 'function ReadInt64: Int64;',
                @TReader.ReadInt64);
  RegisterMethod(TReader, 'procedure ReadListBegin;',
                @TReader.ReadListBegin);
  RegisterMethod(TReader, 'procedure ReadListEnd;',
                @TReader.ReadListEnd);
  RegisterMethod(TReader, 'procedure ReadPrefix(var Flags: TFilerFlags; var AChildPos: Integer); virtual;',
                @TReader.ReadPrefix);
  RegisterMethod(TReader, 'function ReadRootComponent(Root: TComponent): TComponent;',
                @TReader.ReadRootComponent);
  RegisterMethod(TReader, 'procedure ReadSignature;',
                @TReader.ReadSignature);
  RegisterMethod(TReader, 'function ReadStr: string;',
                @TReader.ReadStr);
  RegisterMethod(TReader, 'function ReadString: string;',
                @TReader.ReadString);
  RegisterMethod(TReader, 'function ReadWideString: WideString;',
                @TReader.ReadWideString);
  RegisterMethod(TReader, 'function ReadValue: TValueType;',
                @TReader.ReadValue);
  RegisterMethod(TReader, 'procedure CopyValue(Writer: TWriter);',
                @TReader.CopyValue);
  RegisterMethod(TReader, 'function GetOwner: TComponent;',
                @TReader_GetOwner, Fake);
  RegisterMethod(TReader, 'procedure SetOwner(Value: TComponent);',
                @TReader_SetOwner, Fake);
  RegisterProperty(TReader, 'property Owner: TComponent read GetOwner write'
                +' SetOwner;');
  RegisterMethod(TReader, 'function GetParent: TComponent;',
                @TReader_GetParent, Fake);
  RegisterMethod(TReader, 'procedure SetParent(Value: TComponent);',
                @TReader_SetParent, Fake);
  RegisterProperty(TReader, 'property Parent: TComponent read GetParent write'
                +' SetParent;');
  RegisterMethod(TReader, 'function GetPosition: Longint;',
                @TReader_GetPosition, Fake);
  RegisterMethod(TReader, 'procedure SetPosition(Value: Longint);',
                @TReader_SetPosition, Fake);
  RegisterProperty(TReader, 'property Position: Longint read GetPosition write'
                +' SetPosition;');
  RegisterMethod(TReader, 'function GetOnError: TReaderError;',
                @TReader_GetOnError, Fake);
  RegisterMethod(TReader, 'procedure SetOnError(Value: TReaderError);',
                @TReader_SetOnError, Fake);
  RegisterProperty(TReader, 'property OnError: TReaderError read GetOnError'
                +' write SetOnError;');
  RegisterMethod(TReader, 'function GetOnFindMethod: TFindMethodEvent;',
                @TReader_GetOnFindMethod, Fake);
  RegisterMethod(TReader, 'procedure SetOnFindMethod(Value: TFindMethodEvent);',
                @TReader_SetOnFindMethod, Fake);
  RegisterProperty(TReader, 'property OnFindMethod: TFindMethodEvent read'
                +' GetOnFindMethod write SetOnFindMethod;');
  RegisterMethod(TReader, 'function GetOnSetName: TSetNameEvent;',
                @TReader_GetOnSetName, Fake);
  RegisterMethod(TReader, 'procedure SetOnSetName(Value: TSetNameEvent);',
                @TReader_SetOnSetName, Fake);
  RegisterProperty(TReader, 'property OnSetName: TSetNameEvent read GetOnSetName'
                +' write SetOnSetName;');
  RegisterMethod(TReader, 'function GetOnReferenceName: TReferenceNameEvent;',
                @TReader_GetOnReferenceName, Fake);
  RegisterMethod(TReader, 'procedure SetOnReferenceName(Value: TReferenceNameEvent);',
                @TReader_SetOnReferenceName, Fake);
  RegisterProperty(TReader, 'property OnReferenceName: TReferenceNameEvent read'
                +' GetOnReferenceName write SetOnReferenceName;');

//---- TWriter -----------------------------------------------------------------

  RegisterClassType(TWriter, H);
  RegisterMethod(TWriter, 'constructor Create(Stream: TStream; BufSize: Integer);',
                 @TWriter.Create);

  RegisterMethod(TWriter, 'procedure FlushBuffer; override;',
                @TWriter.FlushBuffer);
  RegisterMethod(TWriter, 'procedure Write(const Buf; Count: Longint);',
                @TWriter.Write);
  RegisterMethod(TWriter, 'procedure WriteBoolean(Value: Boolean);',
                @TWriter.WriteBoolean);
  RegisterMethod(TWriter, 'procedure WriteCollection(Value: TCollection);',
                @TWriter.WriteCollection);
  RegisterMethod(TWriter, 'procedure WriteComponent(Component: TComponent);',
                @TWriter.WriteComponent);
  RegisterMethod(TWriter, 'procedure WriteChar(Value: Char);',
                @TWriter.WriteChar);
  RegisterMethod(TWriter, 'procedure WriteDescendent(Root: TComponent; AAncestor: TComponent);',
                @TWriter.WriteDescendent);
  RegisterMethod(TWriter, 'procedure WriteFloat(const Value: Extended);',
                @TWriter.WriteFloat);
  RegisterMethod(TWriter, 'procedure WriteCurrency(const Value: Currency);',
                @TWriter.WriteCurrency);
  RegisterMethod(TWriter, 'procedure WriteDate(const Value: TDateTime);',
                @TWriter.WriteDate);
  RegisterMethod(TWriter, 'procedure WriteIdent(const Ident: string);',
                @TWriter.WriteIdent);
  RegisterMethod(TWriter, 'procedure WriteInteger(Value: Longint); overload;',
                @TWriter.WriteInteger);
  RegisterMethod(TWriter, 'procedure WriteInteger(Value: Int64); overload;',
                @TWriter.WriteInteger);
  RegisterMethod(TWriter, 'procedure WriteListBegin;',
                @TWriter.WriteListBegin);
  RegisterMethod(TWriter, 'procedure WriteListEnd;',
                @TWriter.WriteListEnd);
  RegisterMethod(TWriter, 'procedure WriteRootComponent(Root: TComponent);',
                @TWriter.WriteRootComponent);
  RegisterMethod(TWriter, 'procedure WriteSignature;',
                @TWriter.WriteSignature);
  RegisterMethod(TWriter, 'procedure WriteStr(const Value: string);',
                @TWriter.WriteStr);
  RegisterMethod(TWriter, 'procedure WriteString(const Value: string);',
                @TWriter.WriteString);
  RegisterMethod(TWriter, 'procedure WriteWideString(const Value: WideString);',
                @TWriter.WriteWideString);
  RegisterMethod(TWriter, 'function GetPosition: Longint;',
                @TWriter_GetPosition, Fake);
  RegisterMethod(TWriter, 'procedure SetPosition(Value: Longint);',
                @TWriter_SetPosition, Fake);
  RegisterProperty(TWriter, 'property Position: Longint read GetPosition write'
                +' SetPosition;');
  RegisterMethod(TWriter, 'function GetRootAncestor: TComponent;',
                @TWriter_GetRootAncestor, Fake);
  RegisterMethod(TWriter, 'procedure SetRootAncestor(Value: TComponent);',
                @TWriter_SetRootAncestor, Fake);
  RegisterProperty(TWriter, 'property RootAncestor: TComponent read'
                +' GetRootAncestor write SetRootAncestor;');

//---- TParser -----------------------------------------------------------------

  RegisterClassType(TParser, H);
  RegisterMethod(TParser, 'constructor Create(Stream: TStream);',
                @TParser.Create);
  RegisterMethod(TParser, 'procedure CheckToken(T: Char);',
                @TParser.CheckToken);
  RegisterMethod(TParser, 'procedure CheckTokenSymbol(const S: string);',
                @TParser.CheckTokenSymbol);
  RegisterMethod(TParser, 'procedure Error(const Ident: string);',
                @TParser.Error);
  RegisterMethod(TParser, 'procedure ErrorStr(const Message: string);',
                @TParser.ErrorStr);
  RegisterMethod(TParser, 'procedure HexToBinary(Stream: TStream);',
                @TParser.HexToBinary);
  RegisterMethod(TParser, 'function NextToken: Char;',
                @TParser.NextToken);
  RegisterMethod(TParser, 'function SourcePos: Longint;',
                @TParser.SourcePos);
  RegisterMethod(TParser, 'function TokenComponentIdent: string;',
                @TParser.TokenComponentIdent);
  RegisterMethod(TParser, 'function TokenFloat: Extended;',
                @TParser.TokenFloat);
  RegisterMethod(TParser, 'function TokenInt: Int64;',
                @TParser.TokenInt);
  RegisterMethod(TParser, 'function TokenString: string;',
                @TParser.TokenString);
  RegisterMethod(TParser, 'function TokenWideString: WideString;',
                @TParser.TokenWideString);
  RegisterMethod(TParser, 'function TokenSymbolIs(const S: string): Boolean;',
                @TParser.TokenSymbolIs);
  RegisterMethod(TParser, 'function GetFloatType: Char;',
                @TParser_GetFloatType, Fake);
  RegisterProperty(TParser, 'property FloatType: Char read GetFloatType;');
  RegisterMethod(TParser, 'function GetSourceLine: Integer;',
                @TParser_GetSourceLine, Fake);
  RegisterProperty(TParser, 'property SourceLine: Integer read GetSourceLine;');
  RegisterMethod(TParser, 'function GetToken: Char;',
                @TParser_GetToken, Fake);
  RegisterProperty(TParser, 'property Token: Char read GetToken;');

//---- TThread -----------------------------------------------------------------

  RegisterClassType(TThread, H);
  RegisterMethod(TThread, 'constructor Create(CreateSuspended: Boolean);',
                @TThread.Create);
  RegisterMethod(TThread, 'procedure Resume;',
                @TThread.Resume);
  RegisterMethod(TThread, 'procedure Suspend;',
                @TThread.Suspend);
  RegisterMethod(TThread, 'procedure Terminate;',
                @TThread.Terminate);
  RegisterMethod(TThread, 'function WaitFor: LongWord;',
                @TThread.WaitFor);
  RegisterMethod(TThread, 'function GetFreeOnTerminate: Boolean;',
                @TThread_GetFreeOnTerminate, Fake);
  RegisterMethod(TThread, 'procedure SetFreeOnTerminate(Value: Boolean);',
                @TThread_SetFreeOnTerminate, Fake);
  RegisterProperty(TThread, 'property FreeOnTerminate: Boolean read'
                +' GetFreeOnTerminate write SetFreeOnTerminate;');
  RegisterMethod(TThread, 'function GetSuspended: Boolean;',
                @TThread_GetSuspended, Fake);
  RegisterMethod(TThread, 'procedure SetSuspended(Value: Boolean);',
                @TThread_SetSuspended, Fake);
  RegisterProperty(TThread, 'property Suspended: Boolean read GetSuspended'
                +' write SetSuspended;');

//---- TComponent --------------------------------------------------------------

  RegisterClassType(TComponent, H);
  RegisterMethod(TComponent, 'constructor Create(AOwner: TComponent); virtual;',
                @TComponent.Create);
  RegisterMethod(TComponent, 'procedure BeforeDestruction; override;',
                @TComponent.BeforeDestruction);
  RegisterMethod(TComponent, 'procedure DestroyComponents;',
                @TComponent.DestroyComponents);
  RegisterMethod(TComponent, 'procedure Destroying;',
                @TComponent.Destroying);
  RegisterMethod(TComponent, 'function ExecuteAction(Action: TBasicAction): Boolean; dynamic;',
                @TComponent.ExecuteAction);
  RegisterMethod(TComponent, 'function FindComponent(const AName: string): TComponent;',
                @TComponent.FindComponent);
  RegisterMethod(TComponent, 'procedure FreeNotification(AComponent: TComponent);',
                @TComponent.FreeNotification);
  RegisterMethod(TComponent, 'procedure RemoveFreeNotification(AComponent: TComponent);',
                @TComponent.RemoveFreeNotification);
  RegisterMethod(TComponent, 'procedure FreeOnRelease;',
                @TComponent.FreeOnRelease);
  RegisterMethod(TComponent, 'function GetParentComponent: TComponent; dynamic;',
                @TComponent.GetParentComponent);
  RegisterMethod(TComponent, 'function GetNamePath: string; override;',
                @TComponent.GetNamePath);
  RegisterMethod(TComponent, 'function HasParent: Boolean; dynamic;',
                @TComponent.HasParent);
  RegisterMethod(TComponent, 'procedure InsertComponent(AComponent: TComponent);',
                @TComponent.InsertComponent);
  RegisterMethod(TComponent, 'procedure RemoveComponent(AComponent: TComponent);',
                @TComponent.RemoveComponent);
  RegisterMethod(TComponent, 'function SafeCallException(ExceptObject: TObject;'
                +' ExceptAddr: Pointer): HResult; override;',
                @TComponent.SafeCallException);
  RegisterMethod(TComponent, 'function UpdateAction(Action: TBasicAction): Boolean; dynamic;',
                @TComponent.UpdateAction);
  RegisterMethod(TComponent, 'function GetComponent(AIndex: Integer): TComponent;',
                @TComponent_GetComponent, Fake);
  RegisterProperty(TComponent, 'property Components[Index: Integer]: TComponent'
                +' read GetComponent;');
  RegisterMethod(TComponent, 'function GetComponentCount: Integer;',
                @TComponent_GetComponentCount, Fake);
  RegisterProperty(TComponent, 'property ComponentCount: Integer read GetComponentCount;');
  RegisterMethod(TComponent, 'function GetComponentIndex: Integer;',
                @TComponent_GetComponentIndex, Fake);
  RegisterMethod(TComponent, 'procedure SetComponentIndex(Value: Integer);',
                @TComponent_SetComponentIndex, Fake);
  RegisterProperty(TComponent, 'property ComponentIndex: Integer read'
                +' GetComponentIndex write SetComponentIndex;');
  RegisterMethod(TComponent, 'function GetComponentState: TComponentState;',
                @TComponent_GetComponentState, Fake);
  RegisterProperty(TComponent, 'property ComponentState: TComponentState read'
                +' GetComponentState;');
  RegisterMethod(TComponent, 'function GetComponentStyle: TComponentStyle;',
                @TComponent_GetComponentStyle, Fake);
  RegisterProperty(TComponent, 'property ComponentStyle: TComponentStyle read'
                +' GetComponentStyle;');
  RegisterMethod(TComponent, 'function GetDesignInfo: Longint;',
                @TComponent_GetDesignInfo, Fake);
  RegisterMethod(TComponent, 'procedure SetDesignInfo(Value: Longint);',
                @TComponent_SetDesignInfo, Fake);
  RegisterProperty(TComponent, 'property DesignInfo: Longint read GetDesignInfo'
                +' write SetDesignInfo;');
  RegisterMethod(TComponent, 'function GetOwner: TComponent;',
                @TComponent_GetOwner, Fake);
  RegisterProperty(TComponent, 'property Owner: TComponent read GetOwner;');

//---- TBasicActionLink --------------------------------------------------------

  RegisterClassType(TBasicActionLink, H);
  RegisterMethod(TBasicActionLink, 'constructor Create(AClient: TObject); virtual;',
                @TBasicActionLink.Create);
  RegisterMethod(TBasicActionLink, 'function Execute: Boolean; virtual;',
                @TBasicActionLink.Execute);
  RegisterMethod(TBasicActionLink, 'function Update: Boolean; virtual;',
                @TBasicActionLink.Update);
  RegisterMethod(TBasicActionLink, 'function GetAction: TBasicAction;',
                @TBasicActionLink_GetAction, Fake);
  RegisterMethod(TBasicActionLink, 'procedure SetAction(Value: TBasicAction);',
                @TBasicActionLink_SetAction, Fake);
  RegisterProperty(TBasicActionLink, 'property Action: TBasicAction read GetAction'
                +' write SetAction;');

//---- TBasicAction ------------------------------------------------------------

  RegisterClassType(TBasicAction, H);
  RegisterMethod(TBasicAction, 'constructor Create(AOwner: TComponent); override;',
                @TBasicAction.Create);
  RegisterMethod(TBasicAction, 'function HandlesTarget(Target: TObject): Boolean; virtual;',
                @TBasicAction.HandlesTarget);
  RegisterMethod(TBasicAction, 'procedure UpdateTarget(Target: TObject); virtual;',
                @TBasicAction.UpdateTarget);
  RegisterMethod(TBasicAction, 'procedure ExecuteTarget(Target: TObject); virtual;',
                @TBasicAction.ExecuteTarget);
  RegisterMethod(TBasicAction, 'function Execute: Boolean; dynamic;',
                @TBasicAction.Execute);
  RegisterMethod(TBasicAction, 'procedure RegisterChanges(Value: TBasicActionLink);',
                @TBasicAction.RegisterChanges);
  RegisterMethod(TBasicAction, 'procedure UnRegisterChanges(Value: TBasicActionLink);',
                @TBasicAction.UnRegisterChanges);
  RegisterMethod(TBasicAction, 'function Update: Boolean; virtual;',
                @TBasicAction.Update);

end.
