////////////////////////////////////////////////////////////////////////////
// PAXScript Importing
// Author: Alexander Baranovsky (ab@cable.netlux.org)
// ========================================================================
// Copyright (c) Alexander Baranovsky, 2003. All rights reserved.
// Code Version: 1.5
// ========================================================================
// Unit: IMP_ComCtrls.pas
// ========================================================================
////////////////////////////////////////////////////////////////////////////


// Imports classes:
//   TAnimate,
//   TCommonCalendar,
//   TConversion,
//   TCoolBand,
//   TCoolBands,
//   TCoolBar,
//   TCustomHotKey,
//   TCustomListView,
//   TCustomRichEdit,
//   TCustomTabControl,
//   TCustomTreeView,
//   TCustomUpDown,
//   TDateTimePicker,
//   THeaderControl,
//   THeaderSection,
//   THeaderSections,
//   THotKey,
//   TIconOptions,
//   TListColumn,
//   TListColumns,
//   TListItem,
//   TListItems,
//   TListView,
//   TMonthCalColors,
//   TMonthCalendar,
//   TPageControl,
//   TPageScroller,
//   TParaAttributes,
//   TProgressBar,
//   TRichEdit,
//   TStatusBar,
//   TStatusPanel,
//   TStatusPanels,
//   TTabControl,
//   TTabSheet,
//   TTextAttributes,
//   TToolButton,
//   TToolBar,
//   TTrackBar,
//   TTreeNode,
//   TTreeNodes,
//   TTreeView,
//   TUpDown,
//   TWorkArea, (D5 and later)
//   TWorkAreas, (D5 and later)
//
// Imported routines:
//
///////////////////////////////////////////////////////////////////////////////

unit IMP_ComCtrls;

interface

uses
  SysUtils,
  Classes,
  TypInfo,
{$IFDEF WIN32}
  Windows,
{$ENDIF}
{$IFDEF LINUX}
  Types,
  QControls,
  QComctrls,
  QGraphics,
  QImgList,
{$ELSE}
  Controls,
  Comctrls,
  Graphics,
  ImgList,
{$ENDIF}
  PaxScripter;

implementation

type
  TSubItems = class(TStringList);

{$IFDEF MSWINDOWS}
//------TTextAttributes---------------------------------------------------------

function TTextAttributes_GetCharset: TFontCharset;
begin
 result := TTextAttributes(_Self).Charset;
end;

procedure TTextAttributes_SetCharset(Value: TFontCharset);
begin
 TTextAttributes(_Self).Charset := Value;
end;

function TTextAttributes_GetColor: TColor;
begin
 result := TTextAttributes(_Self).Color;
end;

procedure TTextAttributes_SetColor(Value: TColor);
begin
 TTextAttributes(_Self).Color := Value;
end;

function TTextAttributes_GetConsistentAttributes: TConsistentAttributes;
begin
 result := TTextAttributes(_Self).ConsistentAttributes;
end;

function TTextAttributes_GetName: TFontName;
begin
 result := TTextAttributes(_Self).Name;
end;

procedure TTextAttributes_SetName(Value: TFontName);
begin
 TTextAttributes(_Self).Name := Value;
end;

function TTextAttributes_GetPitch: TFontPitch;
begin
 result := TTextAttributes(_Self).Pitch;
end;

procedure TTextAttributes_SetPitch(Value: TFontPitch);
begin
 TTextAttributes(_Self).Pitch := Value;
end;

function TTextAttributes_GetProtected: Boolean;
begin
 result := TTextAttributes(_Self).Protected;
end;

procedure TTextAttributes_SetProtected(Value: Boolean);
begin
 TTextAttributes(_Self).Protected := Value;
end;

function TTextAttributes_GetSize: Integer;
begin
 result := TTextAttributes(_Self).Size;
end;

procedure TTextAttributes_SetSize(Value: Integer);
begin
 TTextAttributes(_Self).Size := Value;
end;

function TTextAttributes_GetStyle: TFontStyles;
begin
 result := TTextAttributes(_Self).Style;
end;

procedure TTextAttributes_SetStyle(Value: TFontStyles);
begin
 TTextAttributes(_Self).Style := Value;
end;

function TTextAttributes_GetHeight: Integer;
begin
 result := TTextAttributes(_Self).Height;
end;

procedure TTextAttributes_SetHeight(Value: Integer);
begin
 TTextAttributes(_Self).Height := Value;
end;

{$ENDIF}
{$IFDEF MSWINDOWS}

//------TParaAttributes---------------------------------------------------------

function TParaAttributes_GetAlignment: TAlignment;
begin
 result := TParaAttributes(_Self).Alignment;
end;

procedure TParaAttributes_SetAlignment(Value: TAlignment);
begin
  TParaAttributes(_Self).Alignment := Value;
end;

function TParaAttributes_GetFirstIndent: Longint;
begin
 result := TParaAttributes(_Self).FirstIndent;
end;

procedure TParaAttributes_SetFirstIndent(Value: Longint);
begin
 TParaAttributes(_Self).FirstIndent := Value;
end;

function TParaAttributes_GetLeftIndent: Longint;
begin
 result := TParaAttributes(_Self).LeftIndent;
end;

procedure TParaAttributes_SetLeftIndent(Value: Longint);
begin
 TParaAttributes(_Self).LeftIndent := Value;
end;

function TParaAttributes_GetNumbering: TNumberingStyle;
begin
 result := TParaAttributes(_Self).Numbering;
end;

procedure TParaAttributes_SetNumbering(Value: TNumberingStyle);
begin
 TParaAttributes(_Self).Numbering := Value;
end;

function TParaAttributes_GetRightIndent: Longint;
begin
 result := TParaAttributes(_Self).RightIndent;
end;

procedure TParaAttributes_SetRightIndent(Value: Longint);
begin
 TParaAttributes(_Self).RightIndent := Value;
end;

function TParaAttributes_GetTab(Index: Byte): Longint;
begin
 result := TParaAttributes(_Self).Tab[Index];
end;

procedure TParaAttributes_SetTab(Index: Byte; Value: Longint);
begin
 TParaAttributes(_Self).Tab[Index] := Value;
end;

function TParaAttributes_GetTabCount: Integer;
begin
 result := TParaAttributes(_Self).TabCount;
end;

procedure TParaAttributes_SetTabCount(Value: Integer);
begin
 TParaAttributes(_Self).TabCount := Value;
end;

{$ENDIF}

{$IFDEF MSWINDOWS}

//------TCustomRichEdit---------------------------------------------------------

function TCustomRichEdit_GetDefAttributes: TTextAttributes;
begin
 result := TCustomRichEdit(_Self).DefAttributes;
end;

procedure TCustomRichEdit_SetDefAttributes(Value: TTextAttributes);
begin
 TCustomRichEdit(_Self).DefAttributes := Value;
end;

function TCustomRichEdit_GetSelAttributes: TTextAttributes;
begin
 result := TCustomRichEdit(_Self).SelAttributes;
end;

procedure TCustomRichEdit_SetSelAttributes(Value: TTextAttributes);
begin
 TCustomRichEdit(_Self).SelAttributes := Value;
end;


function TCustomRichEdit_GetPageRect: TRect;
begin
 result := TCustomRichEdit(_Self).PageRect;
end;

procedure TCustomRichEdit_SetPageRect(Value: TRect);
begin
 TCustomRichEdit(_Self).PageRect := Value;
end;


function TCustomRichEdit_GetParagraph: TParaAttributes;
begin
 result := TCustomRichEdit(_Self).Paragraph;
end;

{$ENDIF}

{$IFDEF MSWINDOWS}

//-------TListColumn------------------------------------------------------------

function TListColumn_GetWidth: TWidth;
begin
 result := TListColumn(_Self).WidthType;
end;


//-------TListColumns-----------------------------------------------------------

function TListColumns_GetOwner: TCustomListView;
begin
 result := TListColumns(_Self).Owner;
end;
{$ENDIF}

function TListColumns_GetItem(Index: Integer): TListColumn;
begin
 result := TListColumns(_Self).Items[Index];
end;

procedure TListColumns_SetItem(Index: Integer; Value: TListColumn);
begin
 TListColumns(_Self).Items[Index] := Value;
end;

//--------TCustomTabControl-----------------------------------------------------

function TCustomTabControl_GetCanvas: TCanvas;
begin
 result := TCustomTabControl(_Self).Canvas;
end;

//------TPageControl------------------------------------------------------------

function TPageControl_GetActivePageIndex: Integer;
begin
 result := TPageControl(_Self).ActivePageIndex;
end;

procedure TPageControl_SetActivePageIndex(const Value: Integer);
begin
 TPageControl(_Self).ActivePageIndex := Value;
end;

function TPageControl_GetPageCount: Integer;
begin
 result := TPageControl(_Self).PageCount;
end;

function TPageControl_GetPage(Index: Integer): TTabSheet;
begin
 result := TPageControl(_Self).Pages[Index];
end;

//-------TTabSheet--------------------------------------------------------------

function TTabSheet_GetPageControl: TPageControl;
begin
 result := TTabSheet(_Self).PageControl;
end;

procedure TTabSheet_SetPageControl(APageControl: TPageControl);
begin
  TTabSheet(_Self).PageControl := APageControl;
end;

function TTabSheet_GetTabIndex: Integer;
begin
 result := TTabSheet(_Self).TabIndex;
end;

//------TAnimate----------------------------------------------------------------

function TAnimate_GetFrameHeight: Integer;
begin
 result := TAnimate(_Self).FrameHeight;
end;

function TAnimate_GetFrameWidth: Integer;
begin
 result := TAnimate(_Self).FrameWidth;
end;

function TAnimate_GetOpen: Boolean;
begin
 result := TAnimate(_Self).Open;
end;

procedure TAnimate_SetOpen(Value: Boolean);
begin
  TAnimate(_Self).Open := Value;
end;

//-------TStatusPanels----------------------------------------------------------

function TStatusPanels_GetItem(Index: Integer): TStatusPanel;
begin
 result := TStatusPanels(_Self).Items[Index];
end;

procedure TStatusPanels_SetItem(Index: Integer; Value: TStatusPanel);
begin
 TStatusPanels(_Self).Items[Index] := Value;
end;

//-------TStatusBar-------------------------------------------------------------

function TStatusBar_GetCanvas: TCanvas;
begin
 result := TStatusBar(_Self).Canvas;
end;

//-------THeaderSection---------------------------------------------------------

function THeaderSection_GetLeft: Integer;
begin
 result := THeaderSection(_Self).Left;
end;

function THeaderSection_GetRight: Integer;
begin
 result := THeaderSection(_Self).Right;
end;

//-------THeaderControl---------------------------------------------------------

function THeaderControl_GetCanvas: TCanvas;
begin
 result := THeaderControl(_Self).Canvas;
end;

//-------THeaderSections--------------------------------------------------------

function THeaderSections_GetItem(Index: Integer): THeaderSection;
begin
 result := THeaderSections(_Self).Items[Index];
end;

procedure THeaderSections_SetItem(Index: Integer; Value: THeaderSection);
begin
 THeaderSections(_Self).Items[Index] := Value;
end;

//-------TTreeNode--------------------------------------------------------------

function TTreeNode_GetAbsoluteIndex: Integer;
begin
 result := TTreeNode(_Self).AbsoluteIndex;
end;

function TTreeNode_GetCount: Integer;
begin
 result := TTreeNode(_Self).Count;
end;

function TTreeNode_GetData: Pointer;
begin
 result := TTreeNode(_Self).Data;
end;

procedure TTreeNode_SetData(Value: Pointer);
begin
 TTreeNode(_Self).Data := Value;
end;

function TTreeNode_GetDeleting: Boolean;
begin
 result := TTreeNode(_Self).Deleting;
end;

function TTreeNode_GetFocused: Boolean;
begin
 result := TTreeNode(_Self).Focused;
end;

procedure TTreeNode_SetFocused(Value: Boolean);
begin
 TTreeNode(_Self).Focused := Value;
end;

function TTreeNode_GetDropTarget: Boolean;
begin
 result := TTreeNode(_Self).DropTarget;
end;

function TTreeNode_GetSelected: Boolean;
begin
 result := TTreeNode(_Self).Selected;
end;

procedure TTreeNode_SetSelected(Value: Boolean);
begin
 TTreeNode(_Self).Selected := Value;
end;

function TTreeNode_GetExpanded: Boolean;
begin
 result := TTreeNode(_Self).Expanded;
end;

procedure TTreeNode_SetExpanded(Value: Boolean);
begin
 TTreeNode(_Self).Expanded := Value;
end;

function TTreeNode_GetChildren: Boolean;
begin
 result := TTreeNode(_Self).HasChildren;
end;

procedure TTreeNode_SetChildren(Value: Boolean);
begin
 TTreeNode(_Self).HasChildren := Value;
end;

function TTreeNode_GetImageIndex: TImageIndex;
begin
 result := TTreeNode(_Self).ImageIndex;
end;

procedure TTreeNode_SetImageIndex(Value: TImageIndex);
begin
 TTreeNode(_Self).ImageIndex := Value;
end;

function TTreeNode_GetIndex: Integer;
begin
  result := TTreeNode(_Self).Index;
end;

function TTreeNode_IsNodeVisible: Boolean;
begin
 result := TTreeNode(_Self).IsVisible;
end;

function TTreeNode_GetItem(Index: Integer): TTreeNode;
begin
 result := TTreeNode(_Self).Item[Index];
end;

procedure TTreeNode_SetItem(Index: Integer; Value: TTreeNode);
begin
 TTreeNode(_Self).Item[Index] := Value;
end;

function TTreeNode_GetLevel: Integer;
begin
 result := TTreeNode(_Self).Level;
end;

function TTreeNode_GetOwner: TTreeNodes;
begin
 result := TTreeNode(_Self).Owner;
end;

function TTreeNode_GetParent: TTreeNode;
begin
 result := TTreeNode(_Self).Parent;
end;

function TTreeNode_GetSelectedIndex: Integer;
begin
 result := TTreeNode(_Self).SelectedIndex;
end;

procedure TTreeNode_SetSelectedIndex(Value: Integer);
begin
 TTreeNode(_Self).SelectedIndex := Value;
end;

function TTreeNode_GetText: String;
begin
 result := TTreeNode(_Self).Text;
end;

procedure TTreeNode_SetText(const S: string);
begin
 TTreeNode(_Self).Text := S;
end;

function TTreeNode_GetTreeView: TCustomTreeView;
begin
 result := TTreeNode(_Self).TreeView;
end;

function TTreeNodes_GetCount: Integer;
begin
 result := TTreeNodes(_Self).Count;
end;

function TTreeNodes_GetNodeFromIndex(Index: Integer): TTreeNode;
begin
 result := TTreeNodes(_Self).Item[Index];
end;

function TTreeNodes_GetOwner: TCustomTreeView;
begin
 result := TTreeNodes(_Self).Owner;
end;

//--------TCustomTreeView-------------------------------------------------------

function TCustomTreeView_GetSelection: TTreeNode;
begin
 result := TCustomTreeView(_Self).Selected;
end;

procedure TCustomTreeView_SetSelection(Value: TTreeNode);
begin
 TCustomTreeView(_Self).Selected := Value;
end;

function TCustomTreeView_GetTopItem: TTreeNode;
begin
 result := TCustomTreeView(_Self).TopItem;
end;

procedure TCustomTreeView_SetTopItem(Value: TTreeNode);
begin
 TCustomTreeView(_Self).TopItem := Value;
end;

//-------TListItem--------------------------------------------------------------

function TListItem_GetCaption: String;
begin
 result := TListItem(_Self).Caption;
end;

procedure TListItem_SetCaption(const Value: string);
begin
 TListItem(_Self).Caption := Value;
end;

function TListItem_GetChecked: Boolean;
begin
 result := TListItem(_Self).Checked;
end;

procedure TListItem_SetChecked(Value: Boolean);
begin
 TListItem(_Self).Checked := Value;
end;

function TListItem_GetData: Pointer;
begin
 result := TListItem(_Self).Data;
end;

procedure TListItem_SetData(Value: Pointer);
begin
 TListItem(_Self).Data := Value;
end;

function TListItem_GetFocused: Boolean;
begin
 result := TListItem(_Self).Focused;
end;

procedure TListItem_SetFocused(State: Boolean);
begin
 TListItem(_Self).Focused := State;
end;

function TListItem_GetImageIndex: TImageIndex;
begin
 result := TListItem(_Self).ImageIndex;
end;

procedure TListItem_SetImageIndex(Value: TImageIndex);
begin
 TListItem(_Self).ImageIndex := Value;
end;

function TListItem_GetIndex: Integer;
begin
 result := TListItem(_Self).Index;
end;

function TListItem_GetListView: TCustomListView;
begin
 result := TListItem(_Self).ListView;
end;

function TListItem_GetOwner: TListItems;
begin
 result := TListItem(_Self).Owner;
end;

function TListItem_GetSelected: Boolean;
begin
 result := TListItem(_Self).Selected;
end;

procedure TListItem_SetSelected(State: Boolean);
begin
 TListItem(_Self).Selected := State;
end;

function TListItem_GetSubItems: TStrings;
begin
 result := TListItem(_Self).SubItems;
end;

procedure TListItem_SetSubItems(Value: TStrings);
begin
 TListItem(_Self).SubItems := Value;
end;

function TListItem_GetSubItemImage(Index: Integer): Integer;
begin
 result := TListItem(_Self).SubItemImages[Index];
end;

procedure TListItem_SetSubItemImage(Index: Integer; const Value: Integer);
begin
 TListItem(_Self).SubItemImages[Index] := Value;
end;

//--------TListItems------------------------------------------------------------

function TListItems_GetCount: Integer;
begin
 result := TListItems(_Self).Count;
end;

function TListItems_GetItem(Index: Integer): TListItem;
begin
 result := TListItems(_Self).Item[Index];
end;

procedure TListItems_SetItem(Index: Integer; Value: TListItem);
begin
 TListItems(_Self).Item[Index] := Value;
end;

function TListItems_GetOwner: TCustomListView;
begin
 result := TListItems(_Self).Owner;
end;

{$IFDEF MSWINDOWS}
//-------TWorkArea--------------------------------------------------------------

function TWorkArea_GetRect: TRect;
begin
 result := TWorkArea(_Self).Rect;
end;

procedure TWorkArea_SetRect(const Value: TRect);
begin
 TWorkArea(_Self).Rect := Value;
end;

function TWorkArea_GetColor: TColor;
begin
 result := TWorkArea(_Self).Color;
end;

procedure TWorkArea_SetColor(const Value: TColor);
begin
 TWorkArea(_Self).Color := Value;
end;

//-------TWorkAreas-------------------------------------------------------------

function TWorkAreas_GetItem(Index: Integer): TWorkArea;
begin
 result := TWorkAreas(_Self).Items[Index];
end;

procedure TWorkAreas_SetItem(Index: Integer; const Value: TWorkArea);
begin
 TWorkAreas(_Self).Items[Index] := Value;
end;

{$ENDIF}
//-------TCustomListView--------------------------------------------------------

function TCustomListView_GetDropTarget: TListItem;
begin
 result := TCustomListView(_Self).DropTarget;
end;

function TCustomListView_GetFocused: TListItem;
begin
 result := TCustomListView(_Self).ItemFocused;
end;

procedure TCustomListView_SetFocused(Value: TListItem);
begin
 TCustomListView(_Self).ItemFocused := Value;
end;

function TCustomListView_GetSelection: TListItem;
begin
 result := TCustomListView(_Self).Selected;
end;

procedure TCustomListView_SetSelection(Value: TListItem);
begin
 TCustomListView(_Self).Selected := Value;
end;

function TCustomListView_GetTopItem: TListItem;
begin
 result := TCustomListView(_Self).TopItem;
end;

//-------TToolButton------------------------------------------------------------

function TToolButton_GetIndex: Integer;
begin
 result := TToolButton(_Self).Index;
end;

//-------TToolBar---------------------------------------------------------------

function TToolBar_GetButtonCount: Integer;
begin
 result := TToolBar(_Self).ButtonCount;
end;

{$IFDEF MSWINDOWS}
//-------TDateTimePicker--------------------------------------------------------

function TDateTimePicker_GetDroppedDown: Boolean;
begin
 result := TDateTimePicker(_Self).DroppedDown;
end;

//-------TCoolBand--------------------------------------------------------------

function TCoolBand_GetHeight: Integer;
begin
 result := TCoolBand(_Self).Height;
end;

//-------TCoolBands-------------------------------------------------------------

function TCoolBands_GetCoolBar: TCoolBar;
begin
 result := TCoolBands(_Self).CoolBar;
end;

function TCoolBands_GetItem(Index: Integer): TCoolBand;
begin
 result := TCoolBands(_Self).Items[Index];
end;

procedure TCoolBands_SetItem(Index: Integer; Value: TCoolBand);
begin
  TCoolBands(_Self).Items[Index] := Value;
end;

{$ENDIF}

var
  H: Integer;
initialization
  H := RegisterNamespace('ComCtrls');

  RegisterRTTIType(TypeInfo(TShiftState));
  RegisterRTTIType(TypeInfo(TMouseButton));
  RegisterRTTIType(TypeInfo(TDragObject));
  RegisterRTTIType(TypeInfo(TStatusPanelBevel));
  RegisterRTTIType(TypeInfo(TBevelCut));
  
{$IFDEF MSWINDOWS}
//---- TTextAttributes----------------------------------------------------------

  RegisterClassType(TTextAttributes, H);
  RegisterMethod(TTextAttributes, 'constructor Create(AOwner: TCustomRichEdit; AttributeType: TAttributeType);',
                 @TTextAttributes.Create);
  RegisterMethod(TTextAttributes, 'procedure Assign(Source: TPersistent); override;',
                 @TTextAttributes.Assign);
  RegisterMethod(TTextAttributes, 'function GetCharset: TFontCharset;',
                @TTextAttributes_GetCharset, Fake);
  RegisterMethod(TTextAttributes, 'procedure SetCharset(Value: TFontCharset);',
                @TTextAttributes_SetCharset, Fake);
  RegisterProperty(TTextAttributes, 'property Charset: TFontCharset read GetCharset'
                   +' write SetCharset;');
  RegisterMethod(TTextAttributes, 'function GetColor: TColor;',
                @TTextAttributes_GetColor, Fake);
  RegisterMethod(TTextAttributes, 'procedure SetColor(Value: TColor);',
                @TTextAttributes_SetColor, Fake);
  RegisterProperty(TTextAttributes, 'property Color: TColor read GetColor write SetColor;');
  RegisterMethod(TTextAttributes, 'function GetConsistentAttributes: TConsistentAttributes;',
                @TTextAttributes_GetConsistentAttributes, Fake);
  RegisterProperty(TTextAttributes, 'property ConsistentAttributes: TConsistentAttributes'
                  +' read GetConsistentAttributes;');
  RegisterMethod(TTextAttributes, 'function GetName: TFontName;',
                @TTextAttributes_GetName, Fake);
  RegisterMethod(TTextAttributes, 'procedure SetName(Value: TFontName);',
                @TTextAttributes_SetName, Fake);
  RegisterProperty(TTextAttributes, 'property Name: TFontName read GetName'
                +' write SetName;');
  RegisterMethod(TTextAttributes, 'function GetPitch: TFontPitch;',
                @TTextAttributes_GetPitch, Fake);
  RegisterMethod(TTextAttributes, 'procedure SetPitch(Value: TFontPitch);',
                @TTextAttributes_SetPitch, Fake);
  RegisterProperty(TTextAttributes, 'property Pitch: TFontPitch read GetPitch'
                +' write SetPitch;');
  RegisterMethod(TTextAttributes, 'function GetProtected: Boolean;',
                @TTextAttributes_GetProtected, Fake);
  RegisterMethod(TTextAttributes, 'procedure SetProtected(Value: Boolean);',
                @TTextAttributes_SetProtected, Fake);
  RegisterProperty(TTextAttributes, 'property Protected: Boolean read'
                +' GetProtected write SetProtected;');
  RegisterMethod(TTextAttributes, 'function GetSize: Integer;',
                @TTextAttributes_GetSize, Fake);
  RegisterMethod(TTextAttributes, 'procedure SetSize(Value: Integer);',
                @TTextAttributes_SetSize, Fake);
  RegisterProperty(TTextAttributes, 'property Size: Integer read GetSize'
                +' write SetSize;');
  RegisterMethod(TTextAttributes, 'function GetStyle: TFontStyles;',
                @TTextAttributes_GetStyle, Fake);
  RegisterMethod(TTextAttributes, 'procedure SetStyle(Value: TFontStyles);',
                @TTextAttributes_SetStyle, Fake);
  RegisterProperty(TTextAttributes, 'property Style: TFontStyles read GetStyle'
                +' write SetStyle;');
  RegisterMethod(TTextAttributes, 'function GetHeight: Integer;',
                @TTextAttributes_GetHeight, Fake);
  RegisterMethod(TTextAttributes, 'procedure SetHeight(Value: Integer);',
                @TTextAttributes_SetHeight, Fake);
  RegisterProperty(TTextAttributes, 'property Height: Integer read'
                +' GetHeight write SetHeight;');

//---- TParaAttributes ---------------------------------------------------------

  RegisterClassType(TParaAttributes, H);
  RegisterMethod(TParaAttributes, 'constructor Create(AOwner: TCustomRichEdit);',
                 @TParaAttributes.Create);
  RegisterMethod(TParaAttributes, 'procedure Assign(Source: TPersistent); override;',
                         @TParaAttributes.Assign);
  RegisterMethod(TParaAttributes, 'function GetAlignment: TAlignment;',
                         @TParaAttributes_GetAlignment, Fake);
  RegisterMethod(TParaAttributes, 'procedure SetAlignment(Value: TAlignment);',
                         @TParaAttributes_SetAlignment, Fake);
  RegisterProperty(TParaAttributes, 'property Alignment: TAlignment read'
                         +' GetAlignment write SetAlignment;');
  RegisterMethod(TParaAttributes, 'function GetFirstIndent: Longint;',
                         @TParaAttributes_GetFirstIndent, Fake);
  RegisterMethod(TParaAttributes, 'procedure SetFirstIndent(Value: Longint);',
                         @TParaAttributes_SetFirstIndent, Fake);
  RegisterProperty(TParaAttributes, 'property FirstIndent: Longint read'
                         +' GetFirstIndent write SetFirstIndent;');
  RegisterMethod(TParaAttributes, 'function GetLeftIndent: Longint;',
                         @TParaAttributes_GetLeftIndent, Fake);
  RegisterMethod(TParaAttributes, 'procedure SetLeftIndent(Value: Longint);',
                         @TParaAttributes_SetLeftIndent, Fake);
  RegisterProperty(TParaAttributes, 'property LeftIndent: Longint read'
                         +' GetLeftIndent write SetLeftIndent;');
  RegisterMethod(TParaAttributes, 'function GetNumbering: TNumberingStyle;',
                         @TParaAttributes_GetNumbering, Fake);
  RegisterMethod(TParaAttributes, 'procedure SetNumbering(Value: TNumberingStyle);',
                         @TParaAttributes_SetNumbering, Fake);
  RegisterProperty(TParaAttributes, 'property Numbering: TNumberingStyle read'
                         +' GetNumbering write SetNumbering;');
  RegisterMethod(TParaAttributes, 'function GetRightIndent: Longint;',
                         @TParaAttributes_GetRightIndent, Fake);
  RegisterMethod(TParaAttributes, 'procedure SetRightIndent(Value: Longint);',
                         @TParaAttributes_SetRightIndent, Fake);
  RegisterProperty(TParaAttributes, 'property RightIndent: Longint read'
                         +' GetRightIndent write SetRightIndent;');
  RegisterMethod(TParaAttributes, 'function GetTab(Index: Byte): Longint;',
                         @TParaAttributes_GetTab, Fake);
  RegisterMethod(TParaAttributes, 'procedure SetTab(Index: Byte; Value: Longint);',
                         @TParaAttributes_SetTab, Fake);
  RegisterProperty(TParaAttributes, 'property Tab[Index: Byte]: Longint read'
                         +' GetTab write SetTab;');
  RegisterMethod(TParaAttributes, 'function GetTabCount: Integer;',
                         @TParaAttributes_GetTabCount, Fake);
  RegisterMethod(TParaAttributes, 'procedure SetTabCount(Value: Integer);',
                         @TParaAttributes_SetTabCount, Fake);
  RegisterProperty(TParaAttributes, 'property TabCount: Integer read'
                         +' GetTabCount write SetTabCount;');

//---- TCustomRichEdit ---------------------------------------------------------

  RegisterClassType(TCustomRichEdit, H);
  RegisterMethod(TCustomRichEdit, 'constructor Create(AOwner: TComponent); override;',
                         @TCustomRichEdit.Create);
  RegisterMethod(TCustomRichEdit, 'procedure Clear; override;',
                         @TCustomRichEdit.Clear);
  RegisterMethod(TCustomRichEdit, 'function FindText(const SearchStr: string;'
                         +' StartPos, Length: Integer; Options: TSearchTypes): Integer;',
                         @TCustomRichEdit.FindText);
  RegisterMethod(TCustomRichEdit, 'function GetSelTextBuf(Buffer: PChar;'
                         +' BufSize: Integer): Integer; override;',
                         @TCustomRichEdit.GetSelTextBuf);
  RegisterMethod(TCustomRichEdit, 'procedure Print(const Caption: string);',
                         @TCustomRichEdit.Print);
  RegisterMethod(TCustomRichEdit, 'function GetDefAttributes: TTextAttributes;',
                         @TCustomRichEdit_GetDefAttributes, Fake);
  RegisterMethod(TCustomRichEdit,'procedure SetDefAttributes(Value: TTextAttributes);',
                         @TCustomRichEdit_SetDefAttributes, Fake);
  RegisterProperty(TCustomRichEdit, 'property DefAttributes: TTextAttributes read'
                         +' GetDefAttributes write SetDefAttributes;');
  RegisterMethod(TCustomRichEdit, 'function GetSelAttributes: TTextAttributes;',
                         @TCustomRichEdit_GetSelAttributes, Fake);
  RegisterMethod(TCustomRichEdit, 'procedure SetSelAttributes(Value: TTextAttributes);',
                         @TCustomRichEdit_SetSelAttributes, Fake);
  RegisterProperty(TCustomRichEdit, 'property SelAttributes: TTextAttributes read'
                         +' GetSelAttributes write SetSelAttributes;');
  RegisterMethod(TCustomRichEdit, 'function GetPageRect: TRect;',
                         @TCustomRichEdit_GetPageRect, Fake);
  RegisterMethod(TCustomRichEdit, 'procedure SetPageRect(Value: TRect);',
                         @TCustomRichEdit_SetPageRect, Fake);
  RegisterProperty(TCustomRichEdit, 'property PageRect: TRect read GetPageRect'
                         +' write SetPageRect;');
  RegisterMethod(TCustomRichEdit, 'function GetParagraph: TParaAttributes;',
                         @TCustomRichEdit_GetParagraph, Fake);
  RegisterProperty(TCustomRichEdit, 'property Paragraph: TParaAttributes read'
                         +' GetParagraph;');

//---- TRichEdit ---------------------------------------------------------------

  RegisterClassType(TRichEdit, H);
  RegisterMethod(TRichEdit, 'constructor Create(AOwner: TComponent); override;',
                         @TRichEdit.Create);

//---- TConversion -------------------------------------------------------------

  RegisterClassType(TConversion, H);
  RegisterMethod(TConversion, 'constructor Create;',
                @TConversion.Create);
  RegisterMethod(TConversion, 'function ConvertReadStream(Stream: TStream;'
                         +' Buffer: PChar; BufSize: Integer): Integer; virtual;',
                         @TConversion.ConvertReadStream);
  RegisterMethod(TConversion, 'function ConvertWriteStream(Stream: TStream;'
                         +' Buffer: PChar; BufSize: Integer): Integer; virtual;',
                         @TConversion.ConvertWriteStream);

//---- TCustomUpDown -----------------------------------------------------------

  RegisterClassType(TCustomUpDown, H);
  RegisterMethod(TCustomUpDown, 'constructor Create(AOwner: TComponent); override;',
                             @TCustomUpDown.Create);

//---- TUpDown -----------------------------------------------------------------

  RegisterClassType(TUpDown, H);
  RegisterMethod(TUpDown, 'constructor Create(AOwner: TComponent); override;',
                         @TUpDown.Create);

//---- TCustomHotKey -----------------------------------------------------------

  RegisterClassType(TCustomHotKey, H);
  RegisterMethod(TCustomHotKey, 'constructor Create(AOwner: TComponent); override;',
               @TCustomHotKey.Create);

//----THotKey ------------------------------------------------------------------

  RegisterClassType(THotKey, H);
  RegisterMethod(THotKey, 'constructor Create(AOwner: TComponent); override;',
               @THotKey.Create);

{$ENDIF} // MSWINDOWS

//----TListColumn --------------------------------------------------------------

  RegisterClassType(TListColumn, H);
  RegisterMethod(TListColumn, 'constructor Create(Collection: TCollection); override;',
                 @TlistColumn.Create);
  RegisterMethod(TListColumn, 'procedure Assign(Source: TPersistent); override;',
                         @TListColumn.Assign);

//----TListColumns -------------------------------------------------------------

  RegisterClassType(TListColumns, H);
  RegisterMethod(TListColumns, 'constructor Create(AOwner: TCustomListView);',
                 @TListColumns.Create);
  RegisterMethod(TListColumns, 'function Add: TListColumn;',
                         @TListColumns.Add);
  RegisterMethod(TListColumns, 'function GetItem(Index: Integer):TListColumn;',
                         @TListColumns_GetItem, Fake);
  RegisterMethod(TListColumns, 'procedure SetItem(Index: Integer; Value: TListColumn);',
                         @TListColumns_SetItem, Fake);
  RegisterProperty(TListColumns, 'property Items[Index: Integer]: TListColumn'
                         +' read GetItem write SetItem;');

//----TListItem ----------------------------------------------------------------

  RegisterClassType(TListItem, H);
  RegisterMethod(TListItem, 'constructor Create(AOwner: TListItems);',
                         @TListItem.Create);
  RegisterMethod(TListItem, 'procedure Assign(Source: TPersistent); override;',
                         @TListItem.Assign);
  RegisterMethod(TListItem, 'procedure Delete;',
                         @TListItem.Delete);
  RegisterMethod(TListItem, 'function DisplayRect(Code: TDisplayCode): TRect;',
                         @TListItem.DisplayRect);
  RegisterMethod(TListItem, 'procedure MakeVisible(PartialOK: Boolean);',
                         @TListItem.MakeVisible);
  RegisterMethod(TListItem, 'function GetCaption: String;',
                         @TListItem_GetCaption, Fake);
  RegisterMethod(TListItem, 'procedure SetCaption(const Value: string);',
                         @TListItem_SetCaption, Fake);
  RegisterProperty(TListItem, 'property Caption: string read GetCaption write'
                         +' SetCaption;');
  RegisterMethod(TListItem, 'function GetChecked: Boolean;',
                         @TListItem_GetChecked, Fake);
  RegisterMethod(TListItem, 'procedure SetChecked(Value: Boolean);',
                         @TListItem_SetChecked, Fake);
  RegisterProperty(TListItem, 'property Checked: Boolean read GetChecked'
                         +' write SetChecked;');
  RegisterMethod(TListItem, 'function GetData: Pointer;',
                         @TListItem_GetData, Fake);
  RegisterMethod(TListItem, 'procedure SetData(Value: Pointer);',
                         @TListItem_SetData, Fake);
  RegisterProperty(TListItem, 'property Data: Pointer read GetData write SetData;');
  RegisterMethod(TListItem, 'function GetFocused: Boolean;',
                         @TListItem_GetFocused, Fake);
  RegisterMethod(TListItem, 'procedure SetFocused(State: Boolean);',
                         @TListItem_SetFocused, Fake);
  RegisterProperty(TListItem, 'property Focused: Boolean read GetFocused'
                         +' write SetFocused;');
  RegisterMethod(TListItem, 'function GetImageIndex: TImageIndex;',
                         @TListItem_GetImageIndex, Fake);
  RegisterMethod(TListItem, 'procedure SetImageIndex(Value: TImageIndex);',
                         @TListItem_SetImageIndex, Fake);
  RegisterProperty(TListItem, 'property ImageIndex: TImageIndex read'
                         +' GetImageIndex write SetImageIndex;');
  RegisterMethod(TListItem, 'function GetIndex: Integer;',
                         @TListItem_GetIndex, Fake);
  RegisterProperty(TListItem, 'property Index: Integer read GetIndex;');
  RegisterMethod(TListItem, 'function GetListView: TCustomListView;',
                         @TListItem_GetListView, Fake);
  RegisterProperty(TListItem, 'property ListView: TCustomListView read GetListView;');
  RegisterMethod(TListItem, 'function GetOwner: TListItems;',
                         @TListItem_GetOwner, Fake);
  RegisterProperty(TListItem, 'property Owner: TListItems read GetOwner;');
  RegisterMethod(TListItem, 'function GetSelected: Boolean;',
                         @TListItem_GetSelected, Fake);
  RegisterMethod(TListItem, 'procedure SetSelected(State: Boolean);',
                         @TListItem_SetSelected, Fake);
  RegisterProperty(TListItem, 'property Selected: Boolean read GetSelected'
                         +' write SetSelected;');
  RegisterMethod(TListItem, 'function GetSubItems: TStrings;',
                         @TListItem_GetSubItems, Fake);
  RegisterMethod(TListItem, 'procedure SetSubItems(Value: TStrings);',
                         @TListItem_SetSubItems, Fake);
  RegisterProperty(TListItem, 'property SubItems: TStrings read GetSubItems'
                         +' write SetSubItems;');
  RegisterMethod(TListItem, 'function GetSubItemImage(Index: Integer): Integer;',
                         @TListItem_GetSubItemImage, Fake);
  RegisterMethod(TListItem, 'procedure SetSubItemImage(Index: Integer; const Value: Integer);',
                         @TListItem_SetSubItemImage, Fake);
  RegisterProperty(TListItem, 'property SubItemImages[Index: Integer]: Integer'
                         +' read GetSubItemImage write SetSubItemImage;');

//----TListItems ---------------------------------------------------------------

  RegisterClassType(TListItems, H);
  RegisterMethod(TListItems, 'constructor Create(AOwner: TCustomListView);',
                         @TListItems.Create);
  RegisterMethod(TListItems, 'function Add: TListItem;',
                         @TListItems.Add);
  RegisterMethod(TListItems, 'procedure Assign(Source: TPersistent); override;',
                         @TListItems.Assign);
  RegisterMethod(TListItems, 'procedure BeginUpdate;',
                         @TListItems.BeginUpdate);
  RegisterMethod(TListItems, 'procedure Clear;',
                         @TListItems.Clear);
  RegisterMethod(TListItems, 'procedure Delete(Index: Integer);',
                         @TListItems.Delete);
  RegisterMethod(TListItems, 'procedure EndUpdate;',
                         @TListItems.EndUpdate);
  RegisterMethod(TListItems, 'function IndexOf(Value: TListItem): Integer;',
                         @TListItems.IndexOf);
  RegisterMethod(TListItems, 'function Insert(Index: Integer): TListItem;',
                         @TListItems.Insert);
  RegisterMethod(TListItems, 'function GetCount: Integer;',
                         @TListItems_GetCount, Fake);
  RegisterProperty(TListItems, 'property Count: Integer read GetCount;');
  RegisterMethod(TListItems, 'function GetItem(Index: Integer): TListItem;',
                         @TListItems_GetItem, Fake);
  RegisterMethod(TListItems, 'procedure SetItem(Index: Integer; Value: TListItem);',
                         @TListItems_SetItem, Fake);
  RegisterProperty(TListItems, 'property Item[Index: Integer]: TListItem read'
                         +' GetItem write SetItem;');
  RegisterMethod(TListItems, 'function GetOwner: TCustomListView;',
                         @TListItems_GetOwner, Fake);
  RegisterProperty(TListItems, 'property Owner: TCustomListView read GetOwner;');

{$IFDEF MSWINDOWS}  
//----TWorkArea ----------------------------------------------------------------

  RegisterClassType(TWorkArea, H);
  RegisterMethod(TWorkArea, 'constructor Create(Collection: TCollection); override;',
                         @TWorkArea.Create);
  RegisterMethod(TWorkArea, 'procedure SetDisplayName(const Value: string); override;',
                         @TWorkArea.SetDisplayName);
  RegisterMethod(TWorkArea, 'function  GetDisplayName: string; override;',
                         @TWorkArea.GetDisplayName);
  RegisterMethod(TWorkArea, 'function GetRect: TRect;',
                         @TWorkArea_GetRect, Fake);
  RegisterMethod(TWorkArea, 'procedure SetRect(const Value: TRect);',
                         @TWorkArea_SetRect, Fake);
  RegisterProperty(TWorkArea, 'property Rect: TRect read GetRect write SetRect;');
  RegisterMethod(TWorkArea, 'function GetColor: TColor;',
                         @TWorkArea_GetColor, Fake);
  RegisterMethod(TWorkArea, 'procedure SetColor(const Value: TColor);',
                         @TWorkArea_SetColor, Fake);
  RegisterProperty(TWorkArea, 'property Color: TColor read GetColor write SetColor;');

//----TWorkAreas ---------------------------------------------------------------

  RegisterClassType(TWorkAreas, H);
  RegisterMethod(TWorkAreas, 'constructor Create(AOwner: TPersistent; ItemClass: TCollectionItemClass);',
                 @TWorkAreas.Create);
  RegisterMethod(TWorkAreas, 'function  Add: TWorkArea;',
                         @TWorkAreas.Add);
  RegisterMethod(TWorkAreas, 'procedure Delete(Index: Integer);',
                         @TWorkAreas.Delete);
  RegisterMethod(TWorkAreas, 'function  Insert(Index: Integer): TWorkArea;',
                         @TWorkAreas.Insert);
  RegisterMethod(TWorkAreas, 'function GetItem(Index: Integer): TWorkArea;',
                         @TWorkAreas_GetItem, Fake);
  RegisterMethod(TWorkAreas, 'procedure SetItem(Index: Integer; const Value: TWorkArea);',
                         @TWorkAreas_SetItem, Fake);
  RegisterProperty(TWorkAreas, 'property  Items[Index: Integer]: TWorkArea read'
                         +' GetItem write SetItem;');

{$ENDIF}
//---- TIconOptions ------------------------------------------------------------

  RegisterClassType(TIconOptions, H);
  RegisterMethod(TIconOptions, 'constructor Create(AOwner: TCustomListView);',
                 @TIconOptions.Create);

//---- TCustomListView ---------------------------------------------------------

  RegisterClassType(TCustomListView, H);
  RegisterMethod(TCustomListView, 'constructor Create(AOwner: TComponent); override;',
                         @TCustomListView.Create);
  RegisterMethod(TCustomListView, 'function AlphaSort: Boolean;',
                         @TCustomListView.AlphaSort);
  RegisterMethod(TCustomListView, 'function FindCaption(StartIndex: Integer;'
                         +' Value: string; Partial, Inclusive, Wrap: Boolean): TListItem;',
                         @TCustomListView.FindCaption);
  RegisterMethod(TCustomListView, 'function FindData(StartIndex: Integer; Value: Pointer;'
                         +' Inclusive, Wrap: Boolean): TListItem;',
                         @TCustomListView.FindData);
  RegisterMethod(TCustomListView, 'function GetItemAt(X, Y: Integer): TListItem;',
                         @TCustomListView.GetItemAt);
  RegisterMethod(TCustomListView, 'function GetNearestItem(Point: TPoint;'
                         +' Direction: TSearchDirection): TListItem;',
                         @TCustomListView.GetNearestItem);
  RegisterMethod(TCustomListView, 'function GetNextItem(StartItem: TListItem;'
                         +' Direction: TSearchDirection; States: TItemStates): TListItem;',
                         @TCustomListView.GetNextItem);
  RegisterMethod(TCustomListView, 'function IsEditing: Boolean;',
                         @TCustomListView.IsEditing);
  RegisterMethod(TCustomListView, 'procedure Scroll(DX, DY: Integer);',
                         @TCustomListView.Scroll);
  RegisterProperty(TCustomListView, 'property Checkboxes: Boolean read'
                         +' GetCheckboxes write SetCheckboxes;');
  RegisterMethod(TCustomListView, 'function GetDropTarget: TListItem;',
                         @TCustomListView_GetDropTarget, Fake);
  RegisterMethod(TCustomListView, 'function GetFocused: TListItem;',
                         @TCustomListView_GetFocused, Fake);
  RegisterMethod(TCustomListView, 'procedure SetFocused(Value: TListItem);',
                         @TCustomListView_SetFocused, Fake);
  RegisterProperty(TCustomListView, 'property ItemFocused: TListItem read'
                         +' GetFocused write SetFocused;');
  RegisterMethod(TCustomListView, 'function GetSelection: TListItem;',
                         @TCustomListView_GetSelection, Fake);
  RegisterMethod(TCustomListView, 'procedure SetSelection(Value: TListItem);',
                         @TCustomListView_SetSelection, Fake);
  RegisterProperty(TCustomListView, 'property Selected: TListItem read'
                         +' GetSelection write SetSelection;');
  RegisterMethod(TCustomListView, 'procedure UpdateItems(FirstIndex, LastIndex: Integer);',
                         @TCustomListView.UpdateItems);
  RegisterMethod(TCustomListView, 'function GetTopItem: TListItem;',
                         @TCustomListView_GetTopItem, Fake);
  RegisterProperty(TCustomListView, 'property TopItem: TListItem read GetTopItem;');
  RegisterProperty(TCustomListView, 'property ViewOrigin: TPoint read GetViewOrigin;');
  RegisterProperty(TCustomListView, 'property VisibleRowCount: Integer read GetVisibleRowCount;');
  RegisterProperty(TCustomListView, 'property BoundingRect: TRect read GetBoundingRect;');

//---- TListView ---------------------------------------------------------------

  RegisterClassType(TListView, H);
  RegisterMethod(TListView, 'constructor Create(AOwner: TListItems);',
                 @TListView.Create);

//---- TStatusPanel-------------------------------------------------------------

  RegisterClassType(TStatusPanel, H);
  RegisterMethod(TStatusPanel, 'constructor Create(Collection: TCollection); override;',
                 @TStatusPanel.Create);
  RegisterMethod(TStatusPanel, 'procedure Assign(Source: TPersistent); override;',
                 @TStatusPanel.Assign);

//---- TStatusPanels -----------------------------------------------------------

  RegisterClassType(TStatusPanels, H);
  RegisterMethod(TStatusPanels, 'constructor Create(StatusBar: TStatusBar);',
                 @TStatusPanels.Create);
  RegisterMethod(TStatusPanels, 'function Add: TStatusPanel;',
                 @TStatusPanels.Add);
  RegisterMethod(TStatusPanels, 'function GetItem(Index: Integer): TStatusPanel;',
                 @TStatusPanels_GetItem, Fake);
  RegisterMethod(TStatusPanels, 'procedure SetItem(Index: Integer; Value: TStatusPanel);',
                 @TStatusPanels_SetItem, Fake);
  RegisterProperty(TStatusPanels, 'property Items[Index: Integer]: TStatusPanel'
                 +' read GetItem write SetItem;');

//---- TStatusBar---------------------------------------------------------------

  RegisterClassType(TStatusBar, H);
  RegisterMethod(TStatusBar, 'constructor Create(AOwner: TComponent); override;',
                 @TStatusBar.Create);
  RegisterMethod(TStatusBar, 'function ExecuteAction(Action: TBasicAction):'
                 +' Boolean; override;',
                 @TStatusBar.ExecuteAction);
  RegisterMethod(TStatusBar, 'procedure FlipChildren(AllLevels: Boolean); override;',
                 @TStatusBar.FlipChildren);
  RegisterMethod(TStatusBar, 'function GetCanvas: TCanvas;',
                 @TStatusBar_GetCanvas, Fake);
  RegisterProperty(TStatusBar, 'property Canvas: TCanvas read GetCanvas;');

//---- THeaderSection ----------------------------------------------------------

  RegisterClassType(THeaderSection, H);
  RegisterMethod(THeaderSection, 'constructor Create(Collection: TCollection); override;',
                 @THeaderSection.Create);
  RegisterMethod(THeaderSection, 'procedure Assign(Source: TPersistent); override;',
                 @THeaderSection.Assign);
  RegisterMethod(THeaderSection, 'function GetLeft: Integer;',
                 @THeaderSection_GetLeft, Fake);
  RegisterProperty(THeaderSection, 'property Left: Integer read GetLeft;');
  RegisterMethod(THeaderSection, 'function GetRight: Integer;',
                 @THeaderSection_GetRight, Fake);
  RegisterProperty(THeaderSection, 'property Right: Integer read GetRight;');

//---- THeaderControl ----------------------------------------------------------

  RegisterClassType(THeaderControl, H);
  RegisterMethod(THeaderControl, 'constructor Create(AOwner: TComponent); override;',
                 @THeaderControl.Create);
  RegisterMethod(THeaderControl, 'procedure FlipChildren(AllLevels: Boolean); override;',
                 @THeaderControl.FlipChildren);
  RegisterMethod(THeaderControl, 'function GetCanvas: TCanvas;',
                 @THeaderControl_GetCanvas, Fake);
  RegisterProperty(THeaderControl, 'property Canvas: TCanvas read GetCanvas;');

//---- THeaderSections ---------------------------------------------------------

  RegisterClassType(THeaderSections, H);
  RegisterMethod(THeaderSections, 'constructor Create(HeaderControl: THeaderControl);',
                 @THeaderSections.Create);
  RegisterMethod(THeaderSections, 'function Add: THeaderSection;',
                 @THeaderSections.Add);
  RegisterMethod(THeaderSections, 'function GetItem(Index: Integer): THeaderSection;',
                 @THeaderSections_GetItem, Fake);
  RegisterMethod(THeaderSections, 'procedure SetItem(Index: Integer; Value: THeaderSection);',
                 @THeaderSections_SetItem, Fake);
  RegisterProperty(THeaderSections, 'property Items[Index: Integer]:'
                 +' THeaderSection read GetItem write SetItem;');

//---- TTreeNode ---------------------------------------------------------------

  RegisterClassType(TTreeNode, H);
  RegisterMethod(TTreeNode, 'constructor Create(AOwner: TTreeNodes);',
                 @TTreeNode.Create);
  RegisterMethod(TTreeNode, 'function AlphaSort: Boolean;',
                 @TTreeNode.AlphaSort);
  RegisterMethod(TTreeNode, 'procedure Assign(Source: TPersistent); override;',
                 @TTreeNode.Assign);
  RegisterMethod(TTreeNode, 'procedure Collapse(Recurse: Boolean);',
                 @TTreeNode.Collapse);
  RegisterMethod(TTreeNode, 'procedure Delete;',
                 @TTreeNode.Delete);
  RegisterMethod(TTreeNode, 'procedure DeleteChildren;',
                 @TTreeNode.DeleteChildren);
  RegisterMethod(TTreeNode, 'function DisplayRect(TextOnly: Boolean): TRect;',
                 @TTreeNode.DisplayRect);
  RegisterMethod(TTreeNode, 'function EditText: Boolean;',
                 @TTreeNode.EditText);
  RegisterMethod(TTreeNode, 'procedure Expand(Recurse: Boolean);',
                 @TTreeNode.Expand);
  RegisterMethod(TTreeNode, 'function getFirstChild: TTreeNode;',
                 @TTreeNode.getFirstChild);
  RegisterMethod(TTreeNode, 'function GetLastChild: TTreeNode;',
                 @TTreeNode.GetLastChild);
  RegisterMethod(TTreeNode, 'function GetNext: TTreeNode;',
                 @TTreeNode.GetNext);
  RegisterMethod(TTreeNode, 'function GetNextChild(Value: TTreeNode): TTreeNode;',
                 @TTreeNode.GetNextChild);
  RegisterMethod(TTreeNode, 'function getNextSibling: TTreeNode;',
                 @TTreeNode.getNextSibling);
  RegisterMethod(TTreeNode, 'function GetNextVisible: TTreeNode;',
                 @TTreeNode.GetNextVisible);
  RegisterMethod(TTreeNode, 'function GetPrev: TTreeNode;',
                 @TTreeNode.GetPrev);
  RegisterMethod(TTreeNode, 'function GetPrevChild(Value: TTreeNode): TTreeNode;',
                 @TTreeNode.GetPrevChild);
  RegisterMethod(TTreeNode, 'function getPrevSibling: TTreeNode;',
                 @TTreeNode.getPrevSibling);
  RegisterMethod(TTreeNode, 'function GetPrevVisible: TTreeNode;',
                 @TTreeNode.GetPrevVisible);
  RegisterMethod(TTreeNode, 'function HasAsParent(Value: TTreeNode): Boolean;',
                 @TTreeNode.HasAsParent);
  RegisterMethod(TTreeNode, 'function IndexOf(Value: TTreeNode): Integer;',
                 @TTreeNode.IndexOf);
  RegisterMethod(TTreeNode, 'procedure MakeVisible;',
                 @TTreeNode.MakeVisible);
  RegisterMethod(TTreeNode, 'procedure MoveTo(Destination: TTreeNode; Mode: TNodeAttachMode);',
                 @TTreeNode.MoveTo);
  RegisterMethod(TTreeNode, 'function GetAbsoluteIndex: Integer;',
                 @TTreeNode_GetAbsoluteIndex, Fake);
  RegisterProperty(TTreeNode, 'property AbsoluteIndex: Integer read GetAbsoluteIndex;');
  RegisterMethod(TTreeNode, 'function GetCount: Integer;',
                 @TTreeNode_GetCount, Fake);
  RegisterProperty(TTreeNode, 'property Count: Integer read GetCount;');
  RegisterMethod(TTreeNode, 'function GetData: Pointer;',
                 @TTreeNode_GetData, Fake);
  RegisterMethod(TTreeNode, 'procedure SetData(Value: Pointer);',
                 @TTreeNode_SetData, Fake);
  RegisterProperty(TTreeNode, 'property Data: Pointer read GetData write SetData;');
  RegisterMethod(TTreeNode, 'function GetDeleting: Boolean;',
                 @TTreeNode_GetDeleting, Fake);
  RegisterProperty(TTreeNode, 'property Deleting: Boolean read GetDeleting;');
  RegisterMethod(TTreeNode, 'function GetFocused: Boolean;',
                 @TTreeNode_GetFocused, Fake);
  RegisterMethod(TTreeNode, 'procedure SetFocused(Value: Boolean);',
                 @TTreeNode_SetFocused, Fake);
  RegisterProperty(TTreeNode, 'property Focused: Boolean read GetFocused write'
                 +' SetFocused;');
  RegisterMethod(TTreeNode, 'function GetDropTarget: Boolean;',
                 @TTreeNode_GetDropTarget, Fake);
  RegisterMethod(TTreeNode, 'function GetSelected: Boolean;',
                 @TTreeNode_GetSelected, Fake);
  RegisterMethod(TTreeNode, 'procedure SetSelected(Value: Boolean);',
                 @TTreeNode_SetSelected, Fake);
  RegisterProperty(TTreeNode, 'property Selected: Boolean read GetSelected'
                 +' write SetSelected;');
  RegisterMethod(TTreeNode, 'function GetExpanded: Boolean;',
                 @TTreeNode_GetExpanded, Fake);
  RegisterMethod(TTreeNode, 'procedure SetExpanded(Value: Boolean);',
                 @TTreeNode_SetExpanded, Fake);
  RegisterProperty(TTreeNode, 'property Expanded: Boolean read GetExpanded'
                 +' write SetExpanded;');
  RegisterMethod(TTreeNode, 'function GetChildren: Boolean;',
                 @TTreeNode_GetChildren, Fake);
  RegisterMethod(TTreeNode,'procedure SetChildren(Value: Boolean);',
                 @TTreeNode_SetChildren, Fake);
  RegisterProperty(TTreeNode, 'property HasChildren: Boolean read GetChildren'
                 +' write SetChildren;');
  RegisterMethod(TTreeNode, 'function GetImageIndex: TImageIndex;',
                 @TTreeNode_GetImageIndex, Fake);
  RegisterMethod(TTreeNode, 'procedure SetImageIndex(Value: TImageIndex);',
                 @TTreeNode_SetImageIndex, Fake);
  RegisterProperty(TTreeNode, 'property ImageIndex: TImageIndex read'
                 +' GetImageIndex write SetImageIndex;');
  RegisterMethod(TTreeNode, 'function GetIndex: Integer;',
                 @TTreeNode_GetIndex, Fake);
  RegisterProperty(TTreeNode, 'property Index: Integer read GetIndex;');
  RegisterMethod(TTreeNode, 'function IsNodeVisible: Boolean;',
                 @TTreeNode_IsNodeVisible, Fake);
  RegisterProperty(TTreeNode, 'property IsVisible: Boolean read IsNodeVisible;');
  RegisterMethod(TTreeNode, 'function GetItem(Index: Integer): TTreeNode;',
                 @TTreeNode_GetItem, Fake);
  RegisterMethod(TTreeNode, 'procedure SetItem(Index: Integer; Value: TTreeNode);',
                 @TTreeNode_SetItem, Fake);
  RegisterProperty(TTreeNode, 'property Item[Index: Integer]: TTreeNode read'
                 +' GetItem write SetItem;');
  RegisterMethod(TTreeNode, 'function GetLevel: Integer;',
                 @TTreeNode_GetLevel, Fake);
  RegisterMethod(TTreeNode, 'function GetOwner: TTreeNodes;',
                 @TTreeNode_GetOwner, Fake);
  RegisterProperty(TTreeNode, 'property Owner: TTreeNodes read GetOwner;');
  RegisterMethod(TTreeNode, 'function GetParent: TTreeNode;',
                 @TTreeNode_GetParent, Fake);
  RegisterProperty(TTreeNode, 'property Parent: TTreeNode read GetParent;');
  RegisterMethod(TTreeNode, 'function GetSelectedIndex: Integer;',
                 @TTreeNode_GetSelectedIndex, Fake);
  RegisterMethod(TTreeNode, 'procedure SetSelectedIndex(Value: Integer);',
                 @TTreeNode_SetSelectedIndex, Fake);
  RegisterProperty(TTreeNode, 'property SelectedIndex: Integer read'
                 +' GetSelectedIndex write SetSelectedIndex;');
  RegisterMethod(TTreeNode, 'function GetText: String;',
                 @TTreeNode_GetText, Fake);
  RegisterMethod(TTreeNode, 'procedure SetText(const S: string);',
                 @TTreeNode_SetText, Fake);
  RegisterProperty(TTreeNode, 'property Text: string read GetText write SetText;');
  RegisterMethod(TTreeNode, 'function GetTreeView: TCustomTreeView;',
                 @TTreeNode_GetTreeView, Fake);
  RegisterProperty(TTreeNode, 'property TreeView: TCustomTreeView read GetTreeView;');

//---- TTreeNodes --------------------------------------------------------------

  RegisterClassType(TTreeNodes, H);
  RegisterMethod(TTreeNodes, 'constructor Create(AOwner: TCustomTreeView);',
                 @TTreeNodes.Create);
  RegisterMethod(TTreeNodes, 'function AddChildFirst(Node: TTreeNode; const S: string): TTreeNode;',
                 @TTreeNodes.AddChildFirst);
  RegisterMethod(TTreeNodes, 'function AddChild(Node: TTreeNode; const S: string): TTreeNode;',
                 @TTreeNodes.AddChild);
  RegisterMethod(TTreeNodes, 'function AddChildObjectFirst(Node: TTreeNode; const S: string;'
                 +' Ptr: Pointer): TTreeNode;', @TTreeNodes.AddChildObjectFirst);
  RegisterMethod(TTreeNodes, 'function AddChildObject(Node: TTreeNode; const S: string;'
                 +' Ptr: Pointer): TTreeNode;', @TTreeNodes.AddChildObject);
  RegisterMethod(TTreeNodes, 'function AddFirst(Node: TTreeNode; const S: string): TTreeNode;',
                 @TTreeNodes.AddFirst);
  RegisterMethod(TTreeNodes, 'function Add(Node: TTreeNode; const S: string): TTreeNode;',
                 @TTreeNodes.Add);
  RegisterMethod(TTreeNodes, 'function AddObjectFirst(Node: TTreeNode; const S: string;'
                 +' Ptr: Pointer): TTreeNode;', @TTreeNodes.AddObjectFirst);
  RegisterMethod(TTreeNodes, 'function AddObject(Node: TTreeNode; const S: string;'
                 +' Ptr: Pointer): TTreeNode;', @TTreeNodes.AddObject);
  RegisterMethod(TTreeNodes, 'procedure Assign(Source: TPersistent); override;',
                 @TTreeNodes.Assign);
  RegisterMethod(TTreeNodes, 'procedure BeginUpdate;',
                 @TTreeNodes.BeginUpdate);
  RegisterMethod(TTreeNodes, 'procedure Clear;',
                 @TTreeNodes.Clear);
  RegisterMethod(TTreeNodes, 'procedure Delete(Node: TTreeNode);',
                 @TTreeNodes.Delete);
  RegisterMethod(TTreeNodes, 'procedure EndUpdate;',
                 @TTreeNodes.EndUpdate);
  RegisterMethod(TTreeNodes, 'function GetFirstNode: TTreeNode;',
                 @TTreeNodes.GetFirstNode);
  RegisterMethod(TTreeNodes, 'function Insert(Node: TTreeNode; const S: string): TTreeNode;',
                 @TTreeNodes.Insert);
  RegisterMethod(TTreeNodes, 'function InsertObject(Node: TTreeNode; const S: string;'
                 +' Ptr: Pointer): TTreeNode;', @TTreeNodes.InsertObject);
  RegisterMethod(TTreeNodes, 'function GetCount: Integer;',
                 @TTreeNodes_GetCount, Fake);
  RegisterProperty(TTreeNodes, 'property Count: Integer read GetCount;');
  RegisterMethod(TTreeNodes, 'function GetNodeFromIndex(Index: Integer): TTreeNode;',
                 @TTreeNodes_GetNodeFromIndex, Fake);
  RegisterProperty(TTreeNodes, 'property Item[Index: Integer]: TTreeNode read GetNodeFromIndex;');
  RegisterMethod(TTreeNodes, 'function GetOwner: TCustomTreeView;',
                 @TTreeNodes_GetOwner, Fake);
  RegisterProperty(TTreeNodes, 'property Owner: TCustomTreeView read GetOwner;');

//---- TCustomTreeView ---------------------------------------------------------

  RegisterClassType(TCustomTreeView, H);
  RegisterMethod(TCustomTreeView, 'constructor Create(AOwner: TComponent); override;',
                 @TCustomTreeView.Create);
  RegisterMethod(TCustomTreeView, 'function AlphaSort: Boolean;',
                 @TCustomTreeView.AlphaSort);
  RegisterMethod(TCustomTreeView, 'procedure FullCollapse;',
                 @TCustomTreeView.FullCollapse);
  RegisterMethod(TCustomTreeView, 'procedure FullExpand;',
                 @TCustomTreeView.FullExpand);
  RegisterMethod(TCustomTreeView, 'function GetNodeAt(X, Y: Integer): TTreeNode;',
                 @TCustomTreeView.GetNodeAt);
  RegisterMethod(TCustomTreeView, 'function IsEditing: Boolean;',
                 @TCustomTreeView.IsEditing);
  RegisterMethod(TCustomTreeView, 'procedure LoadFromFile(const FileName: string);',
                 @TCustomTreeView.LoadFromFile);
  RegisterMethod(TCustomTreeView, 'procedure LoadFromStream(Stream: TStream);',
                 @TCustomTreeView.LoadFromStream);
  RegisterMethod(TCustomTreeView, 'procedure SaveToFile(const FileName: string);',
                 @TCustomTreeView.SaveToFile);
  RegisterMethod(TCustomTreeView, 'procedure SaveToStream(Stream: TStream);',
                 @TCustomTreeView.SaveToStream);
  RegisterMethod(TCustomTreeView, 'function GetSelection: TTreeNode;',
                 @TCustomTreeView_GetSelection, Fake);
  RegisterMethod(TCustomTreeView, 'procedure SetSelection(Value: TTreeNode);',
                 @TCustomTreeView_SetSelection, Fake);
  RegisterProperty(TCustomTreeView, 'property Selected: TTreeNode read'
                 +' GetSelection write SetSelection;');
  RegisterMethod(TCustomTreeView, 'function GetTopItem: TTreeNode;',
                 @TCustomTreeView_GetTopItem, Fake);
  RegisterMethod(TCustomTreeView, 'procedure SetTopItem(Value: TTreeNode);',
                 @TCustomTreeView_SetTopItem, Fake);
  RegisterProperty(TCustomTreeView, 'property TopItem: TTreeNode read'
                 +' GetTopItem write SetTopItem;');

//---- TTreeView ---------------------------------------------------------------

  RegisterClassType(TTreeView, H);
  RegisterMethod(TTreeView, 'constructor Create(AOwner: TComponent);',
                 @TTreeView.Create);

//---- TTrackBar ---------------------------------------------------------------

  RegisterClassType(TTrackBar, H);
  RegisterMethod(TTrackBar, 'constructor Create(AOwner: TComponent); override;',
                 @TTrackBar.Create);

//---- TProgressBar-------------------------------------------------------------

  RegisterClassType(TProgressBar, H);
  RegisterMethod(TProgressBar, 'constructor Create(AOwner: TComponent); override;',
                 @TProgressBar.Create);
  RegisterMethod(TProgressBar, 'procedure StepIt;',
                 @TProgressBar.StepIt);
  RegisterMethod(TProgressBar, 'procedure StepBy(Delta: Integer);',
                 @TProgressBar.StepBy);

//---- TCustomTabControl -------------------------------------------------------

  RegisterClassType(TCustomTabControl, H);
  RegisterMethod(TCustomTabControl, 'constructor Create(AOwner: TComponent); override;',
                 @TCustomTabControl.Create);
  RegisterMethod(TCustomTabControl, 'function IndexOfTabAt(X, Y: Integer): Integer;',
                 @TCustomTabControl.IndexOfTabAt);
  RegisterMethod(TCustomTabControl, 'function TabRect(Index: Integer): TRect;',
                 @TCustomTabControl.TabRect);
  RegisterMethod(TCustomTabControl, 'procedure ScrollTabs(Delta: Integer);',
                 @TCustomTabControl.ScrollTabs);
  RegisterMethod(TCustomTabControl, 'function GetCanvas: TCanvas;',
                 @TCustomTabControl_GetCanvas, Fake);
  RegisterProperty(TCustomTabControl, 'property Canvas: TCanvas read GetCanvas;');

//---- TTabControl--------------------------------------------------------------

  RegisterClassType(TTabControl, H);
  RegisterMethod(TTabControl, 'constructor Create(AOwner: TComponent); override;',
                 @TTabControl.Create);

//---- TPageControl-------------------------------------------------------------

  RegisterClassType(TPageControl, H);
  RegisterMethod(TPageControl, 'constructor Create(AOwner: TComponent); override;',
                 @TPageControl.Create);
  RegisterMethod(TPageControl, 'function FindNextPage(CurPage: TTabSheet;'
                 +' GoForward, CheckTabVisible: Boolean): TTabSheet;',
                 @TPageControl.FindNextPage);
  RegisterMethod(TPageControl, 'procedure SelectNextPage(GoForward: Boolean);',
                @TPageControl.SelectNextPage);
  RegisterMethod(TPageControl, 'function GetActivePageIndex: Integer;',
                @TPageControl_GetActivePageIndex, Fake);
  RegisterMethod(TPageControl, 'procedure SetActivePageIndex(const Value: Integer);',
                @TPageControl_SetActivePageIndex, Fake);
  RegisterProperty(TPageControl, 'property ActivePageIndex: Integer read'
                +' GetActivePageIndex write SetActivePageIndex;');
  RegisterMethod(TPageControl, 'function GetPageCount: Integer;',
                @TPageControl_GetPageCount, Fake);
  RegisterProperty(TPageControl, 'property PageCount: Integer read GetPageCount;');
  RegisterMethod(TPageControl, 'function GetPage(Index: Integer): TTabSheet;',
                @TPageControl_GetPage, Fake);
  RegisterProperty(TPageControl, 'property Pages[Index: Integer]:'
                +' TTabSheet read GetPage;');

//---- TTabSheet----------------------------------------------------------------

  RegisterClassType(TTabSheet, H);
  RegisterMethod(TTabSheet, 'constructor Create(AOwner: TComponent); override;',
                 @TTabSheet.Create);
  RegisterMethod(TTabSheet, 'function GetPageControl: TPageControl;',
                 @TTabSheet_GetPageControl,Fake);
  RegisterMethod(TTabSheet, 'procedure SetPageControl(APageControl: TPageControl);',
                 @TTabSheet_SetPageControl,Fake);
  RegisterProperty(TTabSheet, 'property PageControl: TPageControl read GetPageControl write SetPageControl;');
  RegisterMethod(TTabSheet, 'function GetTabIndex: Integer;',
                 @TTabSheet_GetTabIndex, Fake);
  RegisterProperty(TTabSheet, 'property TabIndex: Integer read GetTabIndex;');

//---- TAnimate-----------------------------------------------------------------

  RegisterClassType(TAnimate, H);
  RegisterMethod(TAnimate, 'constructor Create(AOwner: TComponent); override;',
                 @TAnimate.Create);
  RegisterMethod(TAnimate, 'procedure Play(FromFrame, ToFrame: Word; Count: Integer);',
                 @TAnimate.Play);
  RegisterMethod(TAnimate, 'procedure Seek(Frame: Smallint);',
                 @TAnimate.Seek);
  RegisterMethod(TAnimate, 'procedure Stop;',
                 @TAnimate.Stop);
  RegisterMethod(TAnimate, 'function GetFrameHeight: Integer;',
                 @TAnimate_GetFrameHeight, Fake);
  RegisterProperty(TAnimate, 'property FrameHeight: Integer read GetFrameHeight;');
  RegisterMethod(TAnimate, 'function GetFrameWidth: Integer;',
                 @TAnimate_GetFrameWidth, Fake);
  RegisterProperty(TAnimate, 'property FrameWidth: Integer read GetFrameWidth;');
  RegisterMethod(TAnimate, 'function GetOpen: Boolean;',
                 @TAnimate_GetOpen, Fake);
  RegisterMethod(TAnimate, 'procedure SetOpen(Value: Boolean);',
                 @TAnimate_SetOpen, Fake);
  RegisterProperty(TAnimate, 'property Open: Boolean read GetOpen write SetOpen;');

//---- TToolButton--------------------------------------------------------------

  RegisterClassType(TToolButton, H);
  RegisterMethod(TToolButton, 'constructor Create(AOwner: TComponent); override;',
                 @TToolButton.Create);
  RegisterMethod(TToolButton, 'function CheckMenuDropdown: Boolean; dynamic;',
                 @TToolButton.CheckMenuDropdown);
  RegisterMethod(TToolButton, 'procedure Click; override;',
                 @TToolButton.Click);
  RegisterMethod(TToolButton, 'procedure SetBounds(ALeft, ATop, AWidth,'
                 +' AHeight: Integer); override;',
                 @TToolButton.SetBounds);
  RegisterMethod(TToolButton, 'function GetIndex: Integer;',
                 @TToolButton_GetIndex, Fake);
  RegisterProperty(TToolButton, 'property Index: Integer read GetIndex;');

//---- TToolBar-----------------------------------------------------------------

  RegisterClassType(TToolBar, H);
  RegisterMethod(TToolBar, 'constructor Create(AOwner: TComponent); override;',
                 @TToolBar.Create);
  RegisterMethod(TToolBar, 'procedure FlipChildren(AllLevels: Boolean); override;',
                 @TToolBar.FlipChildren);
  RegisterMethod(TToolBar, 'function GetButtonCount: Integer;',
                 @TToolBar_GetButtonCount, Fake);
  RegisterProperty(TToolBar, 'property ButtonCount: Integer read GetButtonCount;');

{$IFDEF MSWINDOWS}
//---- TPageScroller -----------------------------------------------------------

  RegisterClassType(TPageScroller, H);
  RegisterMethod(TPageScroller, 'constructor Create(AOwner: TComponent); override;',
                 @TPageScroller.Create);
  RegisterMethod(TPageScroller, 'function GetButtonState(Button: TPageScrollerButton):'
                 +' TPageScrollerButtonState;',
                 @TPageScroller.GetButtonState);
//---- TCommonCalendar ---------------------------------------------------------

  RegisterClassType(TCommonCalendar, H);
  RegisterMethod(TCommonCalendar, 'constructor Create(AOwner: TComponent); override;',
                 @TCommonCalendar.Create);

//---- TMonthCalColors ---------------------------------------------------------

  RegisterClassType(TMonthCalColors, H);
  RegisterMethod(TMonthCalColors, 'constructor Create(AOwner: TCommonCalendar);',
                 @TMonthCalColors.Create);
  RegisterMethod(TMonthCalColors, 'procedure Assign(Source: TPersistent); override;',
                 @TMonthCalColors.Assign);

//---- TMonthCalendar ----------------------------------------------------------

  RegisterClassType(TMonthCalendar, H);
  RegisterMethod(TMonthCalendar, 'constructor Create(AOwner: TComponent); override;',
                 @TMonthCalendar.Create);

//---- TDateTimePicker ---------------------------------------------------------

  RegisterClassType(TDateTimePicker, H);
  RegisterMethod(TDateTimePicker, 'constructor Create(AOwner: TComponent); override;',
                 @TDateTimePicker.Create);
  RegisterMethod(TDateTimePicker, 'function GetDroppedDown: Boolean;',
                 @TDateTimePicker_GetDroppedDown, Fake);
  RegisterProperty(TDateTimePicker, 'property DroppedDown: Boolean read GetDroppedDown;');

//---- TCoolBand ---------------------------------------------------------------

  RegisterClassType(TCoolBand, H);
  RegisterMethod(TCoolBand, 'constructor Create(Collection: TCollection); override;',
                 @TCoolBand.Create);
  RegisterMethod(TCoolBand, 'procedure Assign(Source: TPersistent); override;',
                 @TCoolBand.Assign);
  RegisterMethod(TCoolBand, 'function GetHeight: Integer;',
                 @TCoolBand_GetHeight, Fake);
  RegisterProperty(TCoolBand, 'property Height: Integer read GetHeight;');

//---- TCoolBands --------------------------------------------------------------

  RegisterClassType(TCoolBands, H);
  RegisterMethod(TCoolBands, 'constructor Create(CoolBar: TCoolBar);',
                 @TCoolBands.Create);
  RegisterMethod(TCoolBands, 'function Add: TCoolBand;',
                 @TCoolBands.Add);
  RegisterMethod(TCoolBands, 'function FindBand(AControl: TControl): TCoolBand;',
                 @TCoolBands.FindBand);
  RegisterMethod(TCoolBands, 'function GetCoolBar: TCoolBar;',
                 @TCoolBands_GetCoolBar, Fake);
  RegisterProperty(TCoolBands, 'property CoolBar: TCoolBar read GetCoolBar;');
  RegisterMethod(TCoolBands, 'function GetItem(Index: Integer): TCoolBand;',
                 @TCoolBands_GetItem, Fake);
  RegisterMethod(TCoolBands, 'procedure SetItem(Index: Integer; Value: TCoolBand);',
                 @TCoolBands_SetItem, Fake);
  RegisterProperty(TCoolBands, 'property Items[Index: Integer]: TCoolBand read'
                 +' GetItem write SetItem;');

//---- TCoolBar ----------------------------------------------------------------

  RegisterClassType(TCoolBar, H);
  RegisterMethod(TCoolBar, 'constructor Create(AOwner: TComponent); override;',
                 @TCoolBar.Create);
  RegisterMethod(TCoolBar, 'procedure FlipChildren(AllLevels: Boolean); override;',
                 @TCoolBar.FlipChildren);

{$ENDIF} // MSWINDOWS

  RegisterClassType(TSubItems, H);
end.

