////////////////////////////////////////////////////////////////////////////
// PAXScript Importing
// Author: Alexander Baranovsky (ab@cable.netlux.org)
// ========================================================================
// Copyright (c) Alexander Baranovsky, 2003. All rights reserved.                                  
// Code Version: 1.5
// ========================================================================
// Unit: IMP_Controls.pas
// ========================================================================
////////////////////////////////////////////////////////////////////////////

// Imported classes:
//   TBaseDragControlObject,
//   TControl,
//   TControlCanvas,
//   TCustomControl,
//   TDragControlObject,
//   TDragDockObject,
//   TDragImageList,
//   TDragObject,
//   TGraphicControl,
//   THintWindow,
//   TImageList,
//   TMouse,
//   TSizeConstraints,
//   TWinControl,

unit IMP_Controls;
interface
uses
  TypInfo,
  Classes,
{$IFDEF WIN32}
  Windows,
{$ENDIF}
{$IFDEF LINUX}
  Types,
  QControls,
  QGraphics,
{$ELSE}
  Controls,
  Graphics,
{$ENDIF}
  PaxScripter;

implementation

//----TDragObject --------------------------------------------------------------

function TDragObject_GetDragTargetPos: TPoint;
begin
 result := TDragObject(_Self).DragTargetPos;
end;

procedure TDragObject_SetDragTargetPos(Value: TPoint);
begin
 TDragObject(_Self).DragTargetPos := Value;
end;

//----TBaseDragControlObject ---------------------------------------------------

function TBaseDragControlObject_GetControl: TControl;
begin
 result := TBaseDragControlObject(_Self).Control;
end;

procedure TBaseDragControlObject_SetControl(Value: TControl);
begin
 TBaseDragControlObject(_Self).Control := Value;
end;

{$IFDEF WIN32}
//----TDragDockObject ----------------------------------------------------------

function TDragDockObject_GetBrush: TBrush;
begin
 result := TDragDockObject(_Self).Brush;
end;

procedure TDragDockObject_SetBrush(Value: TBrush);
begin
 TDragDockObject(_Self).Brush := Value;
end;

function TDragDockObject_GetDockRect: TRect;
begin
 result := TDragDockObject(_Self).DockRect;
end;

procedure TDragDockObject_SetDockRect(Value: TRect);
begin
 TDragDockObject(_Self).DockRect := Value;
end;

function TDragDockObject_GetDropAlign: TAlign;
begin
 result := TDragDockObject(_Self).DropAlign;
end;

function TDragDockObject_GetDropOnControl: TControl;
begin
 result := TDragDockObject(_Self).DropOnControl;
end;

function TDragDockObject_GetFloating: Boolean;
begin
 result := TDragDockObject(_Self).Floating;
end;

procedure TDragDockObject_SetFloating(Value: Boolean);
begin
 TDragDockObject(_Self).Floating := Value;
end;

function TDragDockObject_GetFrameWidth: Integer;
begin
 result := TDragDockObject(_Self).FrameWidth;
end;
{$ENDIF}

//----TControlCanvas -----------------------------------------------------------

function TControlCanvas_GetControl: TControl;
begin
 result := TControlCanvas(_Self).Control;
end;

procedure TControlCanvas_SetControl(AControl: TControl);
begin
 TControlCanvas(_Self).Control := AControl;
end;

//----TControl -----------------------------------------------------------------

function TControl_GetAction: TBasicAction;
begin
 result := TControl(_Self).Action;
end;

procedure TControl_SetAction(Value: TBasicAction);
begin
 TControl(_Self).Action := Value;
end;

function TControl_GetAlign: TAlign;
begin
 result := TControl(_Self).Align;
end;

procedure TControl_SetAlign(Value: TAlign);
begin
 TControl(_Self).Align := Value;
end;

function TControl_GetAnchors: TAnchors;
begin
 result := TControl(_Self).Anchors;
end;

procedure TControl_SetAnchors(Value: TAnchors);
begin
 TControl(_Self).Anchors := Value;
end;

function TControl_GetBoundsRect: TRect;
begin
 result := TControl(_Self).BoundsRect;
end;

procedure TControl_SetBoundsRect(const Rect: TRect);
begin
 TControl(_Self).BoundsRect := Rect;
end;

function TControl_GetClientHeight: Integer;
begin
 result := TControl(_Self).ClientHeight;
end;

procedure TControl_SetClientHeight(Value: Integer);
begin
 TControl(_Self).ClientHeight := Value;
end;

function TControl_GetClientOrigin: TPoint;
begin
 result := TControl(_Self).ClientOrigin;
end;

function TControl_GetClientRect: TRect;
begin
 result := TControl(_Self).ClientRect;
end;

function TControl_GetClientWidth: Integer;
begin
 result := TControl(_Self).ClientWidth;
end;

procedure TControl_SetClientWidth(Value: Integer);
begin
 TControl(_Self).ClientWidth := Value;
end;

function TControl_GetConstraints: TSizeConstraints;
begin
 result := TControl(_Self).Constraints;
end;

procedure TControl_SetConstraints(Value: TSizeConstraints);
begin
 TControl(_Self).Constraints := Value;
end;

function TControl_GetControlState: TControlState;
begin
 result := TControl(_Self).ControlState;
end;

procedure TControl_SetControlState(Value: TControlState);
begin
 TControl(_Self).ControlState := Value;
end;

function TControl_GetControlStyle: TControlStyle;
begin
 result := TControl(_Self).ControlStyle;
end;

procedure TControl_SetControlStyle(Value: TControlStyle);
begin
 TControl(_Self).ControlStyle := Value;
end;

function TControl_GetParent: TWinControl;
begin
 result := TControl(_Self).Parent;
end;

procedure TControl_SetParent(AParent: TWinControl);
begin
 TControl(_Self).Parent := AParent;
end;

function TControl_GetShowHint: Boolean;
begin
 result := TControl(_Self).ShowHint;
end;

procedure TControl_SetShowHint(Value: Boolean);
begin
  TControl(_Self).ShowHint := Value;
end;

function TControl_GetVisible: Boolean;
begin
 result := TControl(_Self).Visible;
end;

procedure TControl_SetVisible(Value: Boolean);
begin
  TControl(_Self).Visible := Value;
end;

//----TWinControl --------------------------------------------------------------

function TWinControl_GetHandle: Cardinal;
begin
 result := TWinControl(_Self).Handle;
end;

function TWinControl_GetBrush: TBrush;
begin
 result := TWinControl(_Self).Brush;
end;

function TWinControl_GetControl(Index: Integer): TControl;
begin
 result := TWinControl(_Self).Controls[Index];
end;

function TWinControl_GetControlCount: Integer;
begin
 result := TWinControl(_Self).ControlCount;
end;

function TWinControl_GetShowing: Boolean;
begin
 result := TWinControl(_Self).Showing;
end;

function TWinControl_GetTabOrder: TTabOrder;
begin
 result := TWinControl(_Self).TabOrder;
end;

procedure TWinControl_SetTabOrder(Value: TTabOrder);
begin
 TWinControl(_Self).TabOrder := Value;
end;

function TWinControl_GetTabStop: Boolean;
begin
 result := TWinControl(_Self).TabStop;
end;

procedure TWinControl_SetTabStop(Value: Boolean);
begin
 TWinControl(_Self).TabStop := Value;
end;

//----TMouse -------------------------------------------------------------------

function TMouse_GetCursorPos: TPoint;
begin
 result := TMouse(_Self).CursorPos;
end;

procedure TMouse_SetCursorPos(const Value: TPoint);
begin
 TMouse(_Self).CursorPos := Value;
end;

function TMouse_GetDragImmediate: Boolean;
begin
 result := TMouse(_Self).DragImmediate;
end;

procedure TMouse_SetDragImmediate(Value: Boolean);
begin
 TMouse(_Self).DragImmediate := Value;
end;

function TMouse_GetDragThreshold: Integer;
begin
 result := TMouse(_Self).DragThreshold;
end;

procedure TMouse_SetDragThreshold(Value: Integer);
begin
 TMouse(_Self).DragThreshold := Value;
end;

const Fake = true;

var
  H: Integer;
initialization
  H := RegisterNamespace('Controls');

  RegisterRTTIType(TypeInfo(THandle));
  RegisterRTTIType(TypeInfo(TControlState));
  RegisterRTTIType(TypeInfo(TControlStyle));
  RegisterRTTIType(TypeInfo(TAlign));
  RegisterRTTIType(TypeInfo(TBorderWidth));


//---- TDragObject -------------------------------------------------------------

  RegisterClassType(TDragObject, H);

  RegisterMethod(TDragObject, 'constructor Create;', @TDragObject.Create);
  RegisterMethod(TDragObject, 'procedure Assign(Source: TDragObject); virtual;',
                @TDragObject.Assign);
  RegisterMethod(TDragObject, 'procedure HideDragImage; virtual;',
                @TDragObject.HideDragImage);
  RegisterMethod(TDragObject, 'procedure ShowDragImage; virtual;',
                @TDragObject.ShowDragImage);
  RegisterMethod(TDragObject, 'function GetDragTargetPos: TPoint;',
                @TDragObject_GetDragTargetPos, Fake);
  RegisterMethod(TDragObject, 'procedure SetDragTargetPos(Value: TPoint);',
                @TDragObject_SetDragTargetPos, Fake);
  RegisterProperty(TDragObject, 'property DragTargetPos: TPoint read'
                +' GetDragTargetPos write SetDragTargetPos;');

//---- TBaseDragControlObject --------------------------------------------------

  RegisterClassType(TBaseDragControlObject, H);
  RegisterMethod(TBaseDragControlObject, 'constructor Create(AControl: TControl); virtual;',
                @TBaseDragControlObject.Create);
  RegisterMethod(TBaseDragControlObject, 'procedure Assign(Source: TDragObject); override;',
                @TBaseDragControlObject.Assign);
  RegisterMethod(TBaseDragControlObject, 'function GetControl: TControl;',
                @TBaseDragControlObject_GetControl, Fake);
  RegisterMethod(TBaseDragControlObject, 'procedure SetControl(Value: TControl);',
                @TBaseDragControlObject_SetControl, Fake);
  RegisterProperty(TBaseDragControlObject, 'property Control: TControl read'
                +' GetControl write SetControl;');

//---- TDragControlObject ------------------------------------------------------

  RegisterClassType(TDragControlObject, H);
  RegisterMethod(TDragControlObject, 'constructor Create(AControl: TControl); virtual;',
                @TDragControlObject.Create);
  RegisterMethod(TDragControlObject, 'procedure HideDragImage; override;',
                @TDragControlObject.HideDragImage);
  RegisterMethod(TDragControlObject, 'procedure ShowDragImage; override;',
                @TDragControlObject.ShowDragImage);

{$IFDEF MSWINDOWS}
//---- TDragDockObject ---------------------------------------------------------

  RegisterClassType(TDragDockObject, H);
  RegisterMethod(TDragDockObject, 'constructor Create(AControl: TControl); override;',
                @TDragDockObject.Create);
  RegisterMethod(TDragDockObject, 'procedure Assign(Source: TDragObject); override;',
                @TDragDockObject.Assign);
  RegisterMethod(TDragDockObject, 'function GetBrush: TBrush;',
                @TDragDockObject_GetBrush, Fake);
  RegisterMethod(TDragDockObject, 'procedure SetBrush(Value: TBrush);',
                @TDragDockObject_SetBrush, Fake);
  RegisterProperty(TDragDockObject, 'property Brush: TBrush read GetBrush write'
                +' SetBrush;');
  RegisterMethod(TDragDockObject, 'function GetDockRect: TRect;',
                @TDragDockObject_GetDockRect, Fake);
  RegisterMethod(TDragDockObject, 'procedure SetDockRect(Value: TRect);',
                @TDragDockObject_SetDockRect, Fake);
  RegisterProperty(TDragDockObject, 'property DockRect: TRect read GetDockRect'
                +' write SetDockRect;');
  RegisterMethod(TDragDockObject, 'function GetDropAlign: TAlign;',
                @TDragDockObject_GetDropAlign, Fake);
  RegisterProperty(TDragDockObject, 'property DropAlign: TAlign read GetDropAlign;');
  RegisterMethod(TDragDockObject, 'function GetDropOnControl: TControl;',
                @TDragDockObject_GetDropOnControl, Fake);
  RegisterProperty(TDragDockObject, 'property DropOnControl: TControl read'
                +' GetDropOnControl;');
  RegisterMethod(TDragDockObject, 'function GetFloating: Boolean;',
                @TDragDockObject_GetFloating, Fake);
  RegisterMethod(TDragDockObject, 'procedure SetFloating(Value: Boolean);',
                @TDragDockObject_SetFloating, Fake);
  RegisterProperty(TDragDockObject, 'property Floating: Boolean read GetFloating'
                +' write SetFloating;');
  RegisterMethod(TDragDockObject, 'function GetFrameWidth: Integer;',
                @TDragDockObject_GetFrameWidth, Fake);
  RegisterProperty(TDragDockObject, 'property FrameWidth: Integer read GetFrameWidth;');

{$ENDIF}

//---- TControlCanvas ----------------------------------------------------------

  RegisterClassType(TControlCanvas, H);
  RegisterMethod(TControlCanvas, 'constructor Create;', @TControlCanvas.Create);
  RegisterMethod(TControlCanvas, 'procedure FreeHandle;',
                @TControlCanvas.FreeHandle);
  RegisterMethod(TControlCanvas, 'function GetControl: TControl;',
                @TControlCanvas_GetControl, Fake);
  RegisterMethod(TControlCanvas, 'procedure SetControl(AControl: TControl);',
                @TControlCanvas_SetControl, Fake);
  RegisterProperty(TControlCanvas, 'property Control: TControl read GetControl'
                +' write SetControl;');

//---- TSizeConstraints --------------------------------------------------------

  RegisterClassType(TSizeConstraints, H);
  RegisterMethod(TSizeConstraints, 'constructor Create(Control: TControl); virtual;',
                @TSizeConstraints.Create);

//---- TControl ----------------------------------------------------------------

  RegisterClassType(TControl, H);
  RegisterMethod(TControl, 'constructor Create(AOwner: TComponent); override;',
                @TControl.Create);
//  RegisterMethod(TControl, 'procedure BeginDrag(Immediate: Boolean; Threshold: Integer = -1);',
//                @TControl.BeginDrag);
  RegisterMethod(TControl, 'procedure BringToFront;',
                @TControl.BringToFront);
  RegisterMethod(TControl, 'function ClientToScreen(const Point: TPoint): TPoint;',
                @TControl.ClientToScreen);
  RegisterMethod(TControl, 'procedure DefaultHandler(var Message); override;',
                @TControl.DefaultHandler);
  RegisterMethod(TControl, 'function Dragging: Boolean;',
                @TControl.Dragging);
  RegisterMethod(TControl, 'procedure DragDrop(Source: TObject; X, Y: Integer);',
                @TControl.DragDrop);
  RegisterMethod(TControl, 'procedure EndDrag(Drop: Boolean);',
                @TControl.EndDrag);
  RegisterMethod(TControl, 'function GetParentComponent: TComponent; override;',
                @TControl.GetParentComponent);
  RegisterMethod(TControl, 'function HasParent: Boolean; override;',
                @TControl.HasParent);
  RegisterMethod(TControl, 'procedure Hide;',
                @TControl.Hide);
  RegisterMethod(TControl, 'procedure InitiateAction;',
                @TControl.InitiateAction);
  RegisterMethod(TControl, 'procedure Invalidate;',
                @TControl.Invalidate);
  RegisterMethod(TControl, 'procedure Refresh;',
                @TControl.Refresh);
  RegisterMethod(TControl, 'procedure Repaint;',
                @TControl.Repaint);
  RegisterMethod(TControl, 'function ScreenToClient(const Point: TPoint): TPoint;',
                @TControl.ScreenToClient);
  RegisterMethod(TControl, 'procedure SendToBack;',
                @TControl.SendToBack);
  RegisterMethod(TControl, 'procedure SetBounds(ALeft, ATop, AWidth, AHeight: Integer);',
                @TControl.SetBounds);
  RegisterMethod(TControl, 'procedure Show;',
                @TControl.Show);
  RegisterMethod(TControl, 'procedure Update;',
                @Tcontrol.Update);
  RegisterMethod(TControl, 'function GetAction: TBasicAction;',
                @TControl_GetAction, Fake);
  RegisterMethod(TControl, 'procedure SetAction(Value: TBasicAction);',
                @TControl_SetAction, Fake);
  RegisterProperty(TControl, 'property Action: TBasicAction read GetAction'
                +' write SetAction;');
{
  RegisterMethod(TControl, 'function GetAlign: TAlign;',
                @TControl_GetAlign, Fake);
  RegisterMethod(TControl, 'procedure SetAlign(Value: TAlign);',
                @TControl_SetAlign, Fake);
  RegisterProperty(TControl, 'property Align: TAlign read GetAlign write SetAlign;');
}  
  RegisterMethod(TControl, 'function GetAnchors: TAnchors;',
                @TControl_GetAnchors, Fake);
  RegisterMethod(TControl, 'procedure SetAnchors(Value: TAnchors);',
                @TControl_SetAnchors, Fake);
  RegisterProperty(TControl, 'property Anchors: TAnchors read GetAnchors write'
                +' SetAnchors;');
  RegisterMethod(TControl, 'function GetBoundsRect: TRect;',
                @TControl_GetBoundsRect, Fake);
  RegisterMethod(TControl, 'procedure SetBoundsRect(const Rect: TRect);',
                @TControl_SetBoundsRect, Fake);
  RegisterProperty(TControl, 'property BoundsRect: TRect read GetBoundsRect'
                +' write SetBoundsRect;');
  RegisterMethod(TControl, 'function GetClientHeight: Integer;',
                @TControl_GetClientHeight, Fake);
  RegisterMethod(TControl, 'procedure SetClientHeight(Value: Integer);',
                @TControl_SetClientHeight, Fake);
  RegisterProperty(TControl, 'property ClientHeight: Integer read GetClientHeight'
                +' write SetClientHeight;');
  RegisterMethod(TControl, 'function GetClientOrigin: TPoint;',
                @TControl_GetClientOrigin, Fake);
  RegisterProperty(TControl, 'property ClientOrigin: TPoint read GetClientOrigin;');
  RegisterMethod(TControl, 'function GetClientRect: TRect;',
                @TControl_GetClientRect, Fake);
  RegisterProperty(TControl, 'property ClientRect: TRect read GetClientRect;');
  RegisterMethod(TControl, 'function GetClientWidth: Integer;',
                @TControl_GetClientWidth, Fake);
  RegisterMethod(TControl, 'procedure SetClientWidth(Value: Integer);',
                @TControl_SetClientWidth, Fake);
  RegisterProperty(TControl, 'property ClientWidth: Integer read GetClientWidth'
                +' write SetClientWidth;');
  RegisterMethod(TControl, 'function GetConstraints: TSizeConstraints;',
                @TControl_GetConstraints, Fake);
  RegisterMethod(TControl, 'procedure SetConstraints(Value: TSizeConstraints);',
                @TControl_SetConstraints, Fake);
  RegisterProperty(TControl, 'property Constraints: TSizeConstraints read'
                +' GetConstraints write SetConstraints;');
  RegisterMethod(TControl, 'function GetControlState: TControlState;',
                @TControl_GetControlState, Fake);
  RegisterMethod(TControl, 'procedure SetControlState(Value: TControlState);',
                @TControl_SetControlState, Fake);
  RegisterProperty(TControl, 'property ControlState: TControlState read'
                +' GetControlState write SetControlState;');
  RegisterMethod(TControl, 'function GetControlStyle: TControlStyle;',
                @TControl_GetControlStyle, Fake);
  RegisterMethod(TControl, 'procedure SetControlStyle(Value: TControlStyle);',
                @TControl_SetControlStyle, Fake);
  RegisterProperty(TControl, 'property ControlStyle: TControlStyle read'
                +' GetControlStyle write SetControlStyle;');
  RegisterMethod(TControl, 'function GetParent: TWinControl;',
                @TControl_GetParent, Fake);
  RegisterMethod(TControl, 'procedure SetParent(AParent: TWinControl);',
                @TControl_SetParent, Fake);
  RegisterProperty(TControl, 'property Parent: TWinControl read GetParent write SetParent;');
  RegisterMethod(TControl, 'function GetShowHint: Boolean;',
                @TControl_GetShowHint, Fake);
  RegisterMethod(TControl, 'procedure SetShowHint(Value: Boolean);',
                @TControl_SetShowHint, Fake);
  RegisterProperty(TControl, 'property ShowHint: Boolean read GetShowHint write'
                +' SetShowHint;');
  RegisterMethod(TControl, 'function GetVisible: Boolean;',
                @TControl_GetVisible, Fake);
  RegisterMethod(TControl, 'procedure SetVisible(Value: Boolean);',
                @TControl_SetVisible, Fake);
  RegisterProperty(TControl, 'property Visible: Boolean read GetVisible write'
                +' SetVisible;');

//---- TWinControl -------------------------------------------------------------

  RegisterClassType(TWinControl, H);
  RegisterMethod(TWinControl, 'constructor Create(AOwner: TComponent); override;',
                @TWinControl.Create);
  RegisterMethod(TWinControl, 'constructor CreateParented(ParentWindow: HWnd);',
                @TWinControl.CreateParented);
  RegisterMethod(TWinControl, 'class function CreateParentedControl(ParentWindow:'
                +' HWnd): TWinControl;',
                @TWinControl.CreateParentedControl);
  RegisterMethod(TWinControl, 'procedure Broadcast(var Message);',
                @TWinControl.Broadcast);
  RegisterMethod(TWinControl, 'function CanFocus: Boolean;',
                @TWinControl.CanFocus);
  RegisterMethod(TWinControl, 'function ContainsControl(Control: TControl): Boolean;',
                @TWinControl.ContainsControl);
//  RegisterMethod(TWinControl, 'function ControlAtPos(const Pos: TPoint;'
//                +' AllowDisabled: Boolean; AllowWinControls: Boolean = False):'
//                +' TControl;',
//                @TWinControl.ControlAtPos);
  RegisterMethod(TWinControl, 'procedure DefaultHandler(var Message); override;',
                @TWinControl.DefaultHandler);
  RegisterMethod(TWinControl, 'procedure DisableAlign;',
                @TWinControl.DisableAlign);
  RegisterMethod(TWinControl, 'procedure EnableAlign;',
                @TWinControl.EnableAlign);
  RegisterMethod(TWinControl, 'function FindChildControl(const ControlName:'
                +' string): TControl;',
                @TWinControl.FindChildControl);
  RegisterMethod(TWinControl, 'procedure FlipChildren(AllLevels: Boolean);',
                @TWinControl.FlipChildren);
  RegisterMethod(TWinControl, 'function Focused: Boolean;',
                @TWinControl.Focused);
  RegisterMethod(TWinControl, 'procedure GetTabOrderList(List: TList);',
                @TWinControl.GetTabOrderList);
  RegisterMethod(TWinControl, 'function HandleAllocated: Boolean;',
                @TWinControl.HandleAllocated);
  RegisterMethod(TWinControl, 'procedure HandleNeeded;',
                @TWinControl.HandleNeeded);
  RegisterMethod(TWinControl, 'procedure InsertControl(AControl: TControl);',
                @TWinControl.InsertControl);
  RegisterMethod(TWinControl, 'procedure Invalidate; override;',
                @TWinControl.Invalidate);
  RegisterMethod(TWinControl, 'procedure RemoveControl(AControl: TControl);',
                @TWinControl.RemoveControl);
  RegisterMethod(TWinControl, 'procedure Realign;',
                @TWinControl.Realign);
  RegisterMethod(TWinControl, 'procedure Repaint; override;',
                @TWinControl.Repaint);
  RegisterMethod(TWinControl, 'procedure ScaleBy(M, D: Integer);',
                @TWinControl.ScaleBy);
  RegisterMethod(TWinControl, 'procedure ScrollBy(DeltaX, DeltaY: Integer);',
                @TWinControl.ScrollBy);
  RegisterMethod(TWinControl, 'procedure SetBounds(ALeft, ATop, AWidth, AHeight: Integer); override;',
                @TWinControl.SetBounds);
  RegisterMethod(TWinControl, 'procedure SetFocus;',
                @TWinControl.SetFocus);
  RegisterMethod(TWinControl, 'procedure Update; override;',
                @TWinControl.Update);
  RegisterMethod(TWinControl, 'procedure UpdateControlState;',
                @TWinControl.UpdateControlState);
  RegisterMethod(TWinControl, 'function GetBrush: TBrush;',
                @TWinControl_GetBrush, Fake);
  RegisterProperty(TWinControl, 'property Brush: TBrush read GetBrush;');
  RegisterMethod(TWinControl, 'function GetHandle: Cardinal;',
                @TWinControl_GetHandle, Fake);
  RegisterProperty(TWinControl, 'property Handle: Cardinal read GetHandle;');
  RegisterMethod(TWinControl, 'function GetControl(Index: Integer): TControl;',
                @TWinControl_GetControl, Fake);
  RegisterProperty(TWinControl, 'property Controls[Index: Integer]: TControl'
                +' read GetControl;');
  RegisterMethod(TWinControl, 'function GetControlCount: Integer;',
                @TWinControl_GetControlCount, Fake);
  RegisterProperty(TWinControl, 'property ControlCount: Integer read GetControlCount;');
  RegisterMethod(TWinControl, 'function GetShowing: Boolean;',
                @TWinControl_GetShowing, Fake);
  RegisterProperty(TWinControl, 'property Showing: Boolean read GetShowing;');
  RegisterMethod(TWinControl, 'function GetTabOrder: TTabOrder;',
                @TWinControl_GetTabOrder, Fake);
  RegisterMethod(TWinControl, 'procedure SetTabOrder(Value: TTabOrder);',
                @TWinControl_SetTabOrder, Fake);
  RegisterProperty(TWinControl, 'property TabOrder: TTabOrder read GetTabOrder'
                +' write SetTabOrder;');
  RegisterMethod(TWinControl, 'function GetTabStop: Boolean;',
                @TWinControl_GetTabStop, Fake);
  RegisterMethod(TWinControl, 'procedure SetTabStop(Value: Boolean);',
                @TWinControl_SetTabStop, Fake);
  RegisterProperty(TWinControl, 'property TabStop: Boolean read GetTabStop'
                +' write SetTabStop;');

//---- TGraphicControl ---------------------------------------------------------

  RegisterClassType(TGraphicControl, H);
  RegisterMethod(TGraphicControl, 'constructor Create(AOwner: TComponent); override;',
                @TGraphicControl.Create);

//---- TCustomControl ----------------------------------------------------------

  RegisterClassType(TCustomControl, H);
  RegisterMethod(TCustomControl, 'constructor Create(AOwner: TComponent); override;',
                @TCustomControl.Create);

//---- THintWindow -------------------------------------------------------------

  RegisterClassType(THintWindow, H);
  RegisterMethod(THintWindow, 'constructor Create(AOwner: TComponent); override;',
                @THintWindow.Create);
  RegisterMethod(THintWindow, 'procedure ActivateHint(Rect: TRect; const AHint:'
                +' string);',
                @THintWindow.ActivateHint);
  RegisterMethod(THintWindow, 'procedure ActivateHintData(Rect: TRect; const'
                +' AHint: string; AData: Pointer);',
                @THintWindow.ActivateHintData);
  RegisterMethod(THintWindow, 'function CalcHintRect(MaxWidth: Integer; const'
                +' AHint: string; AData: Pointer): TRect;',
                @THintWindow.CalcHintRect);
  RegisterMethod(THintWindow, 'procedure ReleaseHandle;',
                @THintWindow.ReleaseHandle);

{$IFDEF MSWINDOWS}
//---- TDragImageList ----------------------------------------------------------

  RegisterClassType(TDragImageList, H);
  RegisterMethod(TDragImageList, 'constructor Create(AOwner: TComponent); override;',
                 @TDragImageList.Create);
  RegisterMethod(TDragImageList, 'function BeginDrag(Window: HWND; X, Y: Integer):'
                +' Boolean;',
                @TDragImageList.BeginDrag);
  RegisterMethod(TDragImageList, 'function DragLock(Window: HWND; XPos, YPos: Integer): Boolean;',
                @TDragImageList.DragLock);
  RegisterMethod(TDragImageList, 'function DragMove(X, Y: Integer): Boolean;',
                @TDragImageList.DragMove);
  RegisterMethod(TDragImageList, 'procedure DragUnlock;',
                @TDragImageList.DragUnlock);
  RegisterMethod(TDragImageList, 'function EndDrag: Boolean;',
                @TDragImageList.EndDrag);
  RegisterMethod(TDragImageList, 'function GetHotSpot: TPoint; override;',
                @TDragImageList.GetHotSpot);
  RegisterMethod(TDragImageList, 'procedure HideDragImage;',
                @TDragImageList.HideDragImage);
  RegisterMethod(TDragImageList, 'function SetDragImage(Index, HotSpotX, HotSpotY: Integer): Boolean;',
                @TDragImageList.SetDragImage);
  RegisterMethod(TDragImageList, 'procedure ShowDragImage;',
                @TDragImageList.ShowDragImage);


//---- TImageList --------------------------------------------------------------

  RegisterClassType(TImageList, H);
  RegisterMethod(TImageList, 'constructor Create(AOwner: TComponent); override;',
                @TImageList.Create);

{$ENDIF}

//---- TMouse ------------------------------------------------------------------

  RegisterClassType(TMouse, H);
  RegisterMethod(TMouse, 'constructor Create;',
                @TMouse.Create);
  RegisterMethod(TMouse, 'function GetCursorPos: TPoint;',
                @TMouse_GetCursorPos, Fake);
  RegisterMethod(TMouse, 'procedure SetCursorPos(const Value: TPoint);',
                @TMouse_SetCursorPos, Fake);
  RegisterProperty(TMouse, 'property CursorPos: TPoint read GetCursorPos write'
                +' SetCursorPos;');
  RegisterMethod(TMouse, 'function GetDragImmediate: Boolean;',
                @TMouse_GetDragImmediate, Fake);
  RegisterMethod(TMouse, 'procedure SetDragImmediate(Value: Boolean);',
                @TMouse_SetDragImmediate, Fake);
  RegisterProperty(TMouse, 'property DragImmediate: Boolean read GetDragImmediate'
                +' write SetDragImmediate;');
  RegisterMethod(TMouse, 'function GetDragThreshold: Integer;',
                @TMouse_GetDragThreshold, Fake);
  RegisterMethod(TMouse, 'procedure SetDragThreshold(Value: Integer);',
                @TMouse_SetDragThreshold, Fake);
  RegisterProperty(TMouse, 'property DragThreshold: Integer read GetDragThreshold'
                +' write SetDragThreshold;');
end.
