////////////////////////////////////////////////////////////////////////////
// PAXScript Importing
// Author: Alexander Baranovsky (ab@cable.netlux.org)
// ========================================================================
// Copyright (c) Alexander Baranovsky, 2003. All rights reserved.                                  
// Code Version: 1.5
// ========================================================================
// Unit: IMP_Dialogs.pas
// ========================================================================
////////////////////////////////////////////////////////////////////////////


// Imports classes:
//
//   TColorDialog,
//   TCommonDialog,
//   TFindDialog,
//   TFontDialog,
//   TOpenDialog,
//   TPrintDialog,
//   TPrinterSetupDialog,
//   TReplaceDialog,
//   TSaveDialog


unit IMP_Dialogs;

interface

uses
  Classes,
{$IFDEF WIN32}
  Windows,
{$ENDIF}
{$IFDEF LINUX}
  Types,
  QDialogs,
{$ELSE}
  Dialogs,
{$ENDIF}
  PaxScripter;

implementation

//------TOpenDialog-------------------------------------------------------------

function TOpenDialog_GetFiles: TStrings;
begin
 result := TOpenDialog(_Self).Files;
end;

function TOpenDialog_GetHistoryList: TStrings;
begin
 result := TOpenDialog(_Self).HistoryList;
end;

procedure TOpenDialog_SetHistoryList(Value: TStrings);
begin
 TOpenDialog(_Self).HistoryList := Value;
end;

//-----TFindDialog--------------------------------------------------------------

function TFindDialog_GetPosition: TPoint;
begin
 result := TFindDialog(_Self).Position;
end;

procedure TFindDialog_SetPosition(const Value: TPoint);
begin
 TFindDialog(_Self).Position := Value;
end;

var
  H: Integer;

initialization

  H := RegisterNamespace('Dialogs');

{$IFDEF WIN32}
//---- TCommonDialog -----------------------------------------------------------

  RegisterClassType(TCommonDialog, H);
  RegisterMethod(TCommonDialog, 'constructor Create(AOwner: TComponent); override;',
                 @TCommonDialog.Create);
{$ENDIF}
//---- TOpenDialog--------------------------------------------------------------

  RegisterClassType(TOpenDialog, H);
  RegisterMethod(TOpenDialog, 'constructor Create(AOwner: TComponent); override;',
                 @TOpenDialog.Create);
  RegisterMethod(TOpenDialog, 'function Execute: Boolean; override;',
                 @TOpenDialog.Execute);
  RegisterMethod(TOpenDialog, 'function GetFiles: TStrings;',
                 @TOpenDialog_GetFiles, Fake);
  RegisterProperty(TOpenDialog, 'property Files: TStrings read GetFiles;');
  RegisterMethod(TOpenDialog, 'function GetHistoryList: TStrings;',
                 @TOpenDialog_GetHistoryList, Fake);
  RegisterMethod(TOpenDialog, 'procedure SetHistoryList(Value: TStrings);',
                 @TOpenDialog_SetHistoryList, Fake);
  RegisterProperty(TOpenDialog, 'property HistoryList: TStrings read'
                 +' GetHistoryList write SetHistoryList;');

//---- TSaveDialog--------------------------------------------------------------

  RegisterClassType(TSaveDialog, H);
  RegisterMethod(TSaveDialog, 'constructor Create(AOwner: TComponent); override;',
                 @TSaveDialog.Create);
  RegisterMethod(TSaveDialog, 'function Execute: Boolean; override;',
                 @TSaveDialog.Execute);

//---- TColorDialog-------------------------------------------------------------

  RegisterClassType(TColorDialog, H);
  RegisterMethod(TColorDialog, 'constructor Create(AOwner: TComponent); override;',
                 @TColorDialog.Create);
  RegisterMethod(TColorDialog, 'function Execute: Boolean; override;',
                 @TColorDialog.Execute);

//---- TFontDialog--------------------------------------------------------------

  RegisterClassType(TFontDialog, H);
  RegisterMethod(TFontDialog, 'constructor Create(AOwner: TComponent); override;',
                 @TFontDialog.Create);
  RegisterMethod(TFontDialog, 'function Execute: Boolean; override;',
                 @TFontDialog.Execute);

{$IFDEF WIN32}
//---- TPrinterSetupDialog -----------------------------------------------------

  RegisterClassType(TPrinterSetupDialog, H);
  RegisterMethod(TPrinterSetupDialog, 'constructor Create(AOwner: TComponent); override;',
                 @TPrinterSetupDialog.Create);
  RegisterMethod(TPrinterSetupDialog, 'function Execute: Boolean; override;',
                 @TPrinterSetupDialog.Execute);

//---- TPrintDialog ------------------------------------------------------------

  RegisterClassType(TPrintDialog, H);
  RegisterMethod(TPrintDialog, 'constructor Create(AOwner: TComponent); override;',
                 @TPrintDialog.Create);
  RegisterMethod(TPrintDialog, 'function Execute: Boolean; override;',
                 @TPrintDialog.Execute);

{$ENDIF}
//---- TFindDialog -------------------------------------------------------------

  RegisterClassType(TFindDialog, H);
  RegisterMethod(TFindDialog, 'constructor Create(AOwner: TComponent); override;',
                 @TFindDialog.Create);
  RegisterMethod(TFindDialog, 'function Execute: Boolean; override;',
                 @TFindDialog.Execute);
  RegisterMethod(TFindDialog, 'function GetPosition: TPoint;',
                 @TFindDialog_GetPosition, Fake);
  RegisterMethod(TFindDialog, 'procedure SetPosition(const Value: TPoint);',
                 @TFindDialog_SetPosition, Fake);
  RegisterProperty(TFindDialog, 'property Position: TPoint read GetPosition'
                 +' write SetPosition;');

//---- TReplaceDialog ----------------------------------------------------------

  RegisterClassType(TReplaceDialog, H);
  RegisterMethod(TReplaceDialog, 'constructor Create(AOwner: TComponent); override;',
                 @TReplaceDialog.Create);

  RegisterRoutine('procedure ShowMessage(const Msg: string);',
                 @ShowMessage, H);

//---- Input Dialog ------------------------------------------------------------

  RegisterRoutine('function InputBox(const ACaption, APrompt, ADefault: string): string;',
                 @InputBox, H);
  RegisterRoutine('function InputQuery(const ACaption, APrompt: string;'
                 +' var Value: string): Boolean;',
                 @InputQuery, H);
end.
