////////////////////////////////////////////////////////////////////////////
// PAXScript Importing
// Author: Alexander Baranovsky (ab@cable.netlux.org)
// ========================================================================
// Copyright (c) Alexander Baranovsky, 2003. All rights reserved.                                  
// Code Version: 1.5
// ========================================================================
// Unit: IMP_Forms.pas
// ========================================================================
////////////////////////////////////////////////////////////////////////////

// Imports classes:
//   TApplication,
//   TDataModule,
//   TControlScrollBar,
//   TCustomDockForm,
//   TCustomForm,
//   TCustomFrame,
//   TForm,
//   TFrame,
//   TMonitor,
//   TScreen,
//   TScrollBox,
//   TScrollingWinControl

unit IMP_Forms;
interface
uses
  Classes,
{$IFDEF WIN32}
  Windows,
{$ENDIF}

{$IFDEF LINUX}
  Types,
  QGraphics,
  QControls,
  QMenus,
  QForms,
{$ELSE}
  Graphics,
  Controls,
  Menus,
  Forms,
{$ENDIF}
  PaxScripter,
  BASE_EXTERN;

implementation

//-----TControlScrollBar--------------------------------------------------------

function TControlScrollBar_GetKind: TScrollBarKind;
begin
 result := TControlScrollBar(_Self).Kind;
end;

function TControlScrollBar_GetScrollPos: Integer;
begin
 result := TControlScrollBar(_Self).ScrollPos;
end;

{$IFDEF WIN32}
//-----TMonitor-----------------------------------------------------------------

function TMonitor_GetHandle: Integer;
begin
 result := TMonitor(_Self).Handle;
end;

function TMonitor_GetMonitorNum: Integer;
begin
 result := TMonitor(_Self).MonitorNum;
end;

function TMonitor_GetLeft: Integer;
begin
 result := TMonitor(_Self).Left;
end;

function TMonitor_GetHeight: Integer;
begin
 result := TMonitor(_Self).Height;
end;

function TMonitor_GetTop: Integer;
begin
 result := TMonitor(_Self).Top;
end;

function TMonitor_GetWidth: Integer;
begin
 result := TMonitor(_Self).Width;
end;
{$ENDIF}

//-------TCustomForm------------------------------------------------------------

function TCustomForm_GetActive: Boolean;
begin
 result := TCustomForm(_Self).Active;
end;

function TCustomForm_GetActiveControl: TWinControl;
begin
 result := TCustomForm(_Self).ActiveControl;
end;

procedure TCustomForm_SetActiveControl(Control: TWinControl);
begin
 TCustomForm(_Self).ActiveControl := Control;
end;

function TCustomForm_GetCanvas: TCanvas;
begin
 result := TCustomForm(_Self).Canvas;
end;

function TCustomForm_GetDropTarget: Boolean;
begin
 result := TCustomForm(_Self).DropTarget;
end;

procedure TCustomForm_SetDropTarget(Value: Boolean);
begin
 TCustomForm(_Self).DropTarget := Value;
end;

function TCustomForm_GetFormState: TFormState;
begin
 result := TCustomForm(_Self).FormState;
end;

function TCustomForm_GetHelpFile: string;
begin
 result := TCustomForm(_Self).HelpFile;
end;

procedure TCustomForm_SetHelpFile(Value: string);
begin
 TCustomForm(_Self).HelpFile := Value;
end;

function TCustomForm_GetKeyPreview: Boolean;
begin
 result := TCustomForm(_Self).KeyPreview;
end;

procedure TCustomForm_SetKeyPreview(Value: Boolean);
begin
 TCustomForm(_Self).KeyPreview := Value;
end;

function TCustomForm_GetMenu: TMainMenu;
begin
 result := TCustomForm(_Self).Menu;
end;

procedure TCustomForm_SetMenu(Value: TMainMenu);
begin
 TCustomForm(_Self).Menu := Value;
end;

function TCustomForm_GetModalResult: TModalResult;
begin
 result := TCustomForm(_Self).ModalResult;
end;

procedure TCustomForm_SetModalResult(Value: TModalResult);
begin
 TCustomForm(_Self).ModalResult := Value;
end;

function TCustomForm_GetWindowState: TWindowState;
begin
 result := TCustomForm(_Self).WindowState;
end;

procedure TCustomForm_SetWindowState(Value: TWindowState);
begin
 TCustomForm(_Self).WindowState := Value;
end;

//-------TDataModule------------------------------------------------------------

function TDataModule_GetDesignOffset: TPoint;
begin
 result := TDataModule(_Self).DesignOffset;
end;

procedure TDataModule_SetDesignOffset(Value: TPoint);
begin
 TDataModule(_Self).DesignOffset := Value;
end;

function TDataModule_GetDesignSize: TPoint;
begin
 result := TDataModule(_Self).DesignSize;
end;

procedure TDataModule_SetDesignSize(Value: TPoint);
begin
 TDataModule(_Self).DesignSize := Value;
end;

//-------TScreen----------------------------------------------------------------

function TScreen_GetActiveControl: TWinControl;
begin
 result := TScreen(_Self).ActiveControl;
end;

function TScreen_GetActiveCustomForm: TCustomForm;
begin
 result := TScreen(_Self).ActiveCustomForm;
end;

function TScreen_GetActiveForm: TForm;
begin
 result := TScreen(_Self).ActiveForm;
end;

function TScreen_GetCustomFormCount: Integer;
begin
 result := TScreen(_Self).CustomFormCount;
end;

function TScreen_GetCustomForms(Index: Integer): TCustomForm;
begin
 result := TScreen(_Self).CustomForms[Index];
end;

function TScreen_GetCursor : TCursor;
begin
 result := TScreen(_Self).Cursor;
end;

procedure TScreen_SetCursor(Value: TCursor);
begin
 TScreen(_Self).Cursor := Value;
end;

function TScreen_GetDataModule(Index: Integer): TDataModule;
begin
 result := TScreen(_Self).DataModules[Index];
end;

function TScreen_GetDataModuleCount: Integer;
begin
 result := TScreen(_Self).DataModuleCount;
end;

function TScreen_GetHintFont: TFont;
begin
 result := TScreen(_Self).HintFont;
end;

procedure TScreen_SetHintFont(Value: TFont);
begin
 TScreen(_Self).HintFont := Value;
end;

function TScreen_GetFonts: TStrings;
begin
 result := TScreen(_Self).Fonts;
end;

function TScreen_GetFormCount: Integer;
begin
 result := TScreen(_Self).FormCount;
end;

function TScreen_GetForm(Index: Integer): TForm;
begin
 result := TScreen(_Self).Forms[Index];
end;

function TScreen_GetHeight: Integer;
begin
 result := TScreen(_Self).Height;
end;

function TScreen_GetPixelsPerInch: Integer;
begin
 result := TScreen(_Self).PixelsPerInch;
end;

function TScreen_GetWidth: Integer;
begin
 result := TScreen(_Self).Width;
end;

function TScreen_GetOnActiveControlChange: TNotifyEvent;
begin
 result := TScreen(_Self).OnActiveControlChange;
end;

procedure TScreen_SetOnActiveControlChange(Value: TNotifyEvent);
begin
  TScreen(_Self).OnActiveControlChange := Value;
end;

function TScreen_GetOnActiveFormChange: TNotifyEvent;
begin
 result := TScreen(_Self).OnActiveFormChange;
end;

procedure TScreen_SetOnActiveFormChange(Value: TNotifyEvent);
begin
 TScreen(_Self).OnActiveFormChange := Value;
end;

//-------TApplication-----------------------------------------------------------

function TApplication_GetActive: Boolean;
begin
 result := TApplication(_Self).Active;
end;

function TApplication_GetCurrentHelpFile: string;
begin
 result := TApplication(_Self).CurrentHelpFile;
end;

function TApplication_GetExeName: string;
begin
 result := TApplication(_Self).ExeName;
end;

function TApplication_GetHelpFile: string;
begin
 result := TApplication(_Self).HelpFile;
end;

procedure TApplication_SetHelpFile(Value: string);
begin
 TApplication(_Self).HelpFile := Value;
end;

function TApplication_GetHint: string;
begin
 result := TApplication(_Self).Hint;
end;

procedure TApplication_SetHint(const Value: string);
begin
 TApplication(_Self).Hint := Value;
end;

function TApplication_GetHintColor: TColor;
begin
 result := TApplication(_Self).HintColor;
end;

procedure TApplication_SetHintColor(Value: TColor);
begin
 TApplication(_Self).HintColor := Value;
end;

function TApplication_GetHintHidePause: Integer;
begin
 result := TApplication(_Self).HintHidePause;
end;

procedure TApplication_SetHintHidePause(Value: Integer);
begin
 TApplication(_Self).HintHidePause := Value;
end;

function TApplication_GetHintPause: Integer;
begin
 result := TApplication(_Self).HintPause;
end;

procedure TApplication_SetHintPause(Value: Integer);
begin
 TApplication(_Self).HintPause := Value;
end;

function TApplication_GetHintShortCuts: Boolean;
begin
 result := TApplication(_Self).HintShortCuts;
end;

procedure TApplication_SetHintShortCuts(Value: Boolean);
begin
 TApplication(_Self).HintShortCuts := Value;
end;

function TApplication_GetHintShortPause: Integer;
begin
 result := TApplication(_Self).HintShortPause;
end;

procedure TApplication_SetHintShortPause(Value: Integer);
begin
 TApplication(_Self).HintShortPause := Value;
end;

function TApplication_GetIcon: TIcon;
begin
 result := TApplication(_Self).Icon;
end;

procedure TApplication_SetIcon(Value: TIcon);
begin
 TApplication(_Self).Icon := Value;
end;

function TApplication_GetMainForm: TForm;
begin
 result := TForm(TApplication(_Self).MainForm);
end;

function TApplication_GetShowHint: Boolean;
begin
 result := TApplication(_Self).ShowHint;
end;

procedure TApplication_SetShowHint(Value: Boolean);
begin
 TApplication(_Self).ShowHint := Value;
end;

function TApplication_GetShowMainForm: Boolean;
begin
 result := TApplication(_Self).ShowMainForm;
end;

procedure TApplication_SetShowMainForm(Value: Boolean);
begin
 TApplication(_Self).ShowMainForm := Value;
end;

function TApplication_GetTerminated: Boolean;
begin
 result := TApplication(_Self).Terminated;
end;

function TApplication_GetTitle: string;
begin
 result := TApplication(_Self).Title;
end;

procedure TApplication_SetTitle(const Value: string);
begin
 TApplication(_Self).Title := Value;
end;

//-------TForm------------------------------------------------------------------

function TForm_GetClientRect: TRect;
begin
  Result := TForm(_Self).ClientRect;
end;

var
  H: Integer;

initialization

  H := RegisterNamespace('Forms');

  RegisterRTTIType(TypeInfo(TBorderIcons));
  RegisterRTTIType(TypeInfo(TAlignment));
  RegisterRTTIType(TypeInfo(TFormBorderStyle));
  RegisterRTTIType(TypeInfo(TBorderIcon));
  
//---- TControlScrollBar -------------------------------------------------------

  RegisterClassType(TControlScrollBar, H);
  RegisterMethod(TControlScrollBar, 'constructor Create;',
                @TControlScrollBar.Create);
  RegisterMethod(TControlScrollBar, 'procedure Assign(Source: TPersistent); override;',
                @TControlScrollBar.Assign);
  RegisterMethod(TControlScrollBar, 'function GetKind: TScrollBarKind;',
                @TControlScrollBar_GetKind, Fake);
  RegisterProperty(TControlScrollBar, 'property Kind: TScrollBarKind read GetKind;');
  RegisterMethod(TControlScrollBar, 'function IsScrollBarVisible: Boolean;',
                @TControlScrollBar.IsScrollBarVisible);
  RegisterMethod(TControlScrollBar, 'function GetScrollPos: Integer;',
                @TControlScrollBar_GetScrollPos, Fake);
  RegisterProperty(TControlScrollBar, 'property ScrollPos: Integer read GetScrollPos;');

//---- TScrollingWinControl ----------------------------------------------------

  RegisterClassType(TScrollingWinControl, H);
  RegisterMethod(TScrollingWinControl, 'constructor Create(AOwner: TComponent); override;',
                @TScrollingWinControl.Create);
  RegisterMethod(TScrollingWinControl, 'procedure DisableAutoRange;',
                @TScrollingWinControl.DisableAutoRange);
  RegisterMethod(TScrollingWinControl, 'procedure EnableAutoRange;',
                @TScrollingWinControl.EnableAutoRange);
  RegisterMethod(TScrollingWinControl, 'procedure ScrollInView(AControl: TControl);',
                @TScrollingWinControl.ScrollInView);

//---- TScrollBox---------------------------------------------------------------

  RegisterClassType(TScrollBox, H);
  RegisterMethod(TScrollBox, 'constructor Create(AOwner: TComponent);',
                 @TScrollBox.Create);

//---- TCustomFrame ------------------------------------------------------------

  RegisterClassType(TCustomFrame, H);
  RegisterMethod(TCustomFrame, 'constructor Create(AOwner: TComponent); override;',
                @TCustomFrame.Create);

//---- TFrame ------------------------------------------------------------------

  RegisterClassType(TFrame, H);
  RegisterMethod(TFrame, 'constructor Create(AOwner: TComponent); override;',
                @TFrame.Create);

{$IFDEF WIN32}
//---- TMonitor ----------------------------------------------------------------

  RegisterClassType(TMonitor, H);
  RegisterMethod(TMonitor, 'constructor Create(AOwner: TComponent);',
                @TMonitor.Create);
  RegisterMethod(TMonitor, 'function GetHandle: Integer;',
                @TMonitor_GetHandle, Fake);
  RegisterProperty(TMonitor, 'property Handle: Integer read GetHandle;');
  RegisterMethod(TMonitor, 'function GetMonitorNum: Integer;',
                @TMonitor_GetMonitorNum, Fake);
  RegisterProperty(TMonitor, 'property MonitorNum: Integer read GetMonitorNum;');
  RegisterMethod(TMonitor, 'function GetLeft: Integer;',
                @TMonitor_GetLeft, Fake);
  RegisterProperty(TMonitor, 'property Left: Integer read GetLeft;');
  RegisterMethod(TMonitor, 'function GetHeight: Integer;',
                @TMonitor_GetHeight, Fake);
  RegisterProperty(TMonitor, 'property Height: Integer read GetHeight;');
  RegisterMethod(TMonitor, 'function GetTop: Integer;',
                @TMonitor_GetTop, Fake);
  RegisterProperty(TMonitor, 'property Top: Integer read GetTop;');
  RegisterMethod(TMonitor, 'function GetWidth: Integer;',
                @TMonitor_GetWidth, Fake);
  RegisterProperty(TMonitor, 'property Width: Integer read GetWidth;');
{$ENDIF}

//---- TCustomForm -------------------------------------------------------------

  RegisterClassType(TCustomForm, H);
  RegisterMethod(TCustomForm, 'constructor Create(AOwner: TComponent); override;',
                @TCustomForm.Create);
  RegisterMethod(TCustomForm, 'procedure AfterConstruction; override;',
                @TCustomForm.AfterConstruction);
  RegisterMethod(TCustomForm, 'procedure BeforeDestruction; override;',
                @TCustomForm.BeforeDestruction);
  RegisterMethod(TCustomForm, 'procedure Close;',
                @TCustomForm.Close);
  RegisterMethod(TCustomForm, 'function CloseQuery: Boolean; virtual;',
                @TCustomForm.CloseQuery);
  RegisterMethod(TCustomForm, 'procedure DefaultHandler(var Message); override;',
                @TCustomForm.DefaultHandler);
  RegisterMethod(TCustomForm, 'procedure DefocusControl(Control: TWinControl; Removing: Boolean);',
                @TCustomForm.DefocusControl);
  RegisterMethod(TCustomForm, 'procedure FocusControl(Control: TWinControl);',
                @TCustomForm.FocusControl);
  RegisterMethod(TCustomForm, 'procedure Hide;',
                @TCustomForm.Hide);
  RegisterMethod(TCustomForm, 'function IsShortCut(var Message: TWMKey): Boolean; dynamic;',
                @TCustomForm.IsShortCut);
  RegisterMethod(TCustomForm, 'procedure Release;',
                @TCustomForm.Release);
  RegisterMethod(TCustomForm, 'procedure SetFocus; override;',
                @TCustomForm.SetFocus);
  RegisterMethod(TCustomForm, 'function SetFocusedControl(Control: TWinControl): Boolean; virtual;',
                @TCustomForm.SetFocusedControl);
  RegisterMethod(TCustomForm, 'procedure Show;',
                @TCustomForm.Show);
  RegisterMethod(TCustomForm, 'function ShowModal: Integer; virtual;',
                @TCustomForm.ShowModal);
  RegisterMethod(TCustomForm, 'function GetActive: Boolean;',
                @TCustomForm_GetActive, Fake);
  RegisterProperty(TCustomForm, 'property Active: Boolean read GetActive;');
  RegisterMethod(TCustomForm, 'function GetActiveControl: TWinControl;',
                @TCustomForm_GetActiveControl, Fake);
  RegisterMethod(TCustomForm, 'procedure SetActiveControl(Control: TWinControl);',
                @TCustomForm_SetActiveControl, Fake);
  RegisterProperty(TCustomForm, 'property ActiveControl: TWinControl read'
                +' GetActiveControl write SetActiveControl;');
  RegisterProperty(TCustomForm, 'property ActiveOleControl: TWinControl read'
                +' GetActiveOleControl write SetActiveOleControl;');
  RegisterProperty(TCustomForm, 'property BorderStyle: TFormBorderStyle read'
                +' GetBorderStyle write SetBorderStyle;');
  RegisterMethod(TCustomForm, 'function GetCanvas: TCanvas;',
                @TCustomForm_GetCanvas, Fake);
  RegisterProperty(TCustomForm, 'property Canvas: TCanvas read GetCanvas;');
  RegisterMethod(TCustomForm, 'function GetDropTarget: Boolean;',
                @TCustomForm_GetDropTarget, Fake);
  RegisterMethod(TCustomForm, 'procedure SetDropTarget(Value: Boolean);',
                @TCustomForm_SetDropTarget, Fake);
  RegisterProperty(TCustomForm, 'property DropTarget: Boolean read GetDropTarget'
                +' write SetDropTarget;');
  RegisterMethod(TCustomForm, 'function GetFormState: TFormState;',
                @TCustomForm_GetFormState, Fake);
  RegisterProperty(TCustomForm, 'property FormState: TFormState read GetFormState;');
  RegisterMethod(TCustomForm, 'function GetHelpFile: string;',
                @TCustomForm_GetHelpFile, Fake);
  RegisterMethod(TCustomForm, 'procedure SetHelpFile(Value: string);',
                @TCustomForm_SetHelpFile, Fake);
  RegisterProperty(TCustomForm, 'property HelpFile: string read GetHelpFile'
                +' write SetHelpFile;');
  RegisterMethod(TCustomForm, 'function GetKeyPreview: Boolean;',
                @TCustomForm_GetKeyPreview, Fake);
  RegisterMethod(TCustomForm, 'procedure SetKeyPreview(Value: Boolean);',
                @TCustomForm_SetKeyPreview, Fake);
  RegisterProperty(TCustomForm, 'property KeyPreview: Boolean read GetKeyPreview'
                +' write SetKeyPreview;');
  RegisterMethod(TCustomForm, 'function GetMenu: TMainMenu;',
                @TCustomForm_GetMenu, Fake);
  RegisterMethod(TCustomForm, 'procedure SetMenu(Value: TMainMenu);',
                @TCustomForm_SetMenu, Fake);
  RegisterProperty(TCustomForm, 'property Menu: TMainMenu read GetMenu'
                +' write SetMenu;');
  RegisterMethod(TCustomForm, 'function GetWindowState: TWindowState;',
                @TCustomForm_GetWindowState, Fake);
  RegisterMethod(TCustomForm, 'procedure SetWindowState(Value: TWindowState);',
                @TCustomForm_SetWindowState, Fake);
  RegisterProperty(TCustomForm, 'property WindowState: TWindowState read'
                +' GetWindowState write SetWindowState;');

{$IFDEF WIN32}
//---- TCustomActiveForm -------------------------------------------------------

  RegisterClassType(TCustomActiveForm, H);
  RegisterMethod(TCustomActiveForm, 'constructor Create(AOwner: TComponent); override;',
                @TCustomActiveForm.Create);
  RegisterMethod(TCustomActiveForm, 'function WantChildKey(Child: TControl;'
                +' var Message: TMessage): Boolean; override;',
                @TCustomActiveForm.WantChildKey);
{$ENDIF}

//---- TForm -------------------------------------------------------------------

  RegisterClassType(TForm, H);
  RegisterMethod(TForm, 'constructor Create(AOwner: TComponent); override;',
                @TForm.Create);
  RegisterMethod(TForm, 'function GetClientRect: TRect;',
                @TForm_GetClientRect, Fake);
  RegisterProperty(TForm, 'property ClientRect: TRect read GetClientRect;');

{$IFDEF WIN32}
//---- TCustomDockForm ---------------------------------------------------------

  RegisterClassType(TCustomDockForm, H);
  RegisterMethod(TCustomDockForm, 'constructor Create(AOwner: TComponent); override;',
                @TCustomDockForm.Create);
{$ENDIF}

//---- TDataModule -------------------------------------------------------------

  RegisterClassType(TDataModule, H);
  RegisterMethod(TDataModule, 'constructor Create(AOwner: TComponent); override;',
                @TDataModule.Create);
  RegisterMethod(TDataModule, 'procedure AfterConstruction; override;',
                @TDataModule.AfterConstruction);
  RegisterMethod(TDataModule, 'procedure BeforeDestruction; override;',
                @TDataModule.BeforeDestruction);
  RegisterMethod(TDataModule, 'function GetDesignOffset: TPoint;',
                @TDataModule_GetDesignOffset, Fake);
  RegisterMethod(TDataModule, 'procedure SetDesignOffset(Value: TPoint);',
                @TDataModule_SetDesignOffset, Fake);
  RegisterProperty(TDataModule, 'property DesignOffset: TPoint read'
                +' GetDesignOffset write SetDesignOffset;');
  RegisterMethod(TDataModule, 'function GetDesignSize: TPoint;',
                @TDataModule_GetDesignSize, Fake);
  RegisterMethod(TDataModule, 'procedure SetDesignSize(Value: TPoint);',
                @TDataModule_SetDesignSize, Fake);
  RegisterProperty(TDataModule, 'property DesignSize: TPoint read GetDesignSize'
                +' write SetDesignSize;');

//---- TScreen -----------------------------------------------------------------

  RegisterClassType(TScreen, H);
  RegisterMethod(TScreen, 'constructor Create(AOwner: TComponent); override;',
                @TScreen.Create);
  RegisterMethod(TScreen, 'function GetActiveControl: TWinControl;',
                @TScreen_GetActiveControl, Fake);
  RegisterProperty(TScreen, 'property ActiveControl: TWinControl read'
                +' GetActiveControl;');
  RegisterMethod(TScreen, 'function GetActiveCustomForm: TCustomForm;',
                @TScreen_GetActiveCustomForm, Fake);
  RegisterProperty(TScreen, 'property ActiveCustomForm: TCustomForm read'
                +' GetActiveCustomForm;');
  RegisterMethod(TScreen, 'function GetActiveForm: TForm;',
                @TScreen_GetActiveForm, Fake);
  RegisterProperty(TScreen, 'property ActiveForm: TForm read GetActiveForm;');
  RegisterMethod(TScreen, 'function GetCustomFormCount: Integer;',
                @TScreen_GetCustomFormCount, Fake);
  RegisterProperty(TScreen, 'property CustomFormCount: Integer read GetCustomFormCount;');
  RegisterMethod(TScreen, 'function GetCustomForms(Index: Integer): TCustomForm;',
                @TScreen_GetCustomForms, Fake);
  RegisterProperty(TScreen, 'property CustomForms[Index: Integer]: TCustomForm'
                +' read GetCustomForms;');
  RegisterMethod(TScreen, 'function GetCursor : TCursor;',
                @TScreen_GetCursor, Fake);
  RegisterMethod(TScreen, 'procedure SetCursor(Value: TCursor);',
                @TScreen_SetCursor, Fake);
  RegisterProperty(TScreen, 'property Cursor: TCursor read GetCursor write SetCursor;');
  RegisterMethod(TScreen, 'function GetDataModule(Index: Integer): TDataModule;',
                @TScreen_GetDataModule, Fake);
  RegisterProperty(TScreen, 'property DataModules[Index: Integer]: TDataModule'
                +' read GetDataModule;');
  RegisterMethod(TScreen, 'function GetDataModuleCount: Integer;',
                @TScreen_GetDataModuleCount, Fake);
  RegisterProperty(TScreen, 'property DataModuleCount: Integer read GetDataModuleCount;');
  RegisterMethod(TScreen, 'function GetHintFont: TFont;',
                @TScreen_GetHintFont, Fake);
  RegisterMethod(TScreen, 'procedure SetHintFont(Value: TFont);',
                @TScreen_SetHintFont, Fake);
  RegisterProperty(TScreen, 'property HintFont: TFont read GetHintFont'
                +' write SetHintFont;');
  RegisterProperty(TScreen, 'property IconFont: TFont read GetIconFont'
                +' write SetIconFont;');
  RegisterProperty(TScreen, 'property MenuFont: TFont read GetMenuFont'
                +' write SetMenuFont;');
  RegisterMethod(TScreen, 'function GetFonts: TStrings;',
                @TScreen_GetFonts, Fake);
  RegisterProperty(TScreen, 'property Fonts: TStrings read GetFonts;');
  RegisterMethod(TScreen, 'function GetFormCount: Integer;',
                @TScreen_GetFormCount, Fake);
  RegisterProperty(TScreen, 'property FormCount: Integer read GetFormCount;');
  RegisterMethod(TScreen, 'function GetForm(Index: Integer): TForm;',
                @TScreen_GetForm, Fake);
  RegisterProperty(TScreen, 'property Forms[Index: Integer]: TForm read GetForm;');
  RegisterMethod(TScreen, 'function GetHeight: Integer;',
                @TScreen_GetHeight, Fake);
  RegisterProperty(TScreen, 'property Height: Integer read GetHeight;');
  RegisterMethod(TScreen, 'function GetPixelsPerInch: Integer;',
                @TScreen_GetPixelsPerInch, Fake);
  RegisterProperty(TScreen, 'property PixelsPerInch: Integer read GetPixelsPerInch;');
  RegisterMethod(TScreen, 'function GetWidth: Integer;',
                @TScreen_GetWidth, Fake);
  RegisterProperty(TScreen, 'property Width: Integer read GetWidth;');
  RegisterMethod(TScreen, 'function GetOnActiveControlChange: TNotifyEvent;',
                @TScreen_GetOnActiveControlChange, Fake);
  RegisterMethod(TScreen, 'procedure SetOnActiveControlChange(Value: TNotifyEvent);',
                @TScreen_SetOnActiveControlChange, Fake);
  RegisterProperty(TScreen, 'property OnActiveControlChange: TNotifyEvent read'
                +' GetOnActiveControlChange write SetOnActiveControlChange;');
  RegisterMethod(TScreen, 'function GetOnActiveFormChange: TNotifyEvent;',
                @TScreen_GetOnActiveFormChange, Fake);
  RegisterMethod(TScreen, 'procedure SetOnActiveFormChange(Value: TNotifyEvent);',
                @TScreen_SetOnActiveFormChange, Fake);
  RegisterProperty(TScreen, 'property OnActiveFormChange: TNotifyEvent read'
                +' GetOnActiveFormChange write SetOnActiveFormChange;');

//---- TApplication ------------------------------------------------------------

  RegisterClassType(TApplication, H);
  RegisterMethod(TApplication, 'constructor Create(AOwner: TComponent); override;',
                @TApplication.Create);
  RegisterMethod(TApplication, 'procedure ActivateHint(CursorPos: TPoint);',
                @TApplication.ActivateHint);
  RegisterMethod(TApplication, 'procedure BringToFront;',
                @TApplication.BringToFront);
  RegisterMethod(TApplication, 'procedure ControlDestroyed(Control: TControl);',
                @TApplication.ControlDestroyed);
  RegisterMethod(TApplication, 'procedure CancelHint;',
                @TApplication.CancelHint);
  RegisterMethod(TApplication, 'procedure CreateForm(InstanceClass: TComponentClass;'
                +' var Reference);',
                @TApplication.CreateForm);
  RegisterMethod(TApplication, 'function ExecuteAction(Action: TBasicAction):'
                +' Boolean; reintroduce;',
                @TApplication.ExecuteAction);
  RegisterMethod(TApplication, 'procedure HandleException(Sender: TObject);',
                @TApplication.HandleException);
  RegisterMethod(TApplication, 'procedure HandleMessage;',
                @TApplication.HandleMessage);
  RegisterMethod(TApplication, 'procedure HideHint;',
                @TApplication.HideHint);
  RegisterMethod(TApplication, 'procedure HintMouseMessage(Control: TControl;'
                +' var Message: TMessage);',
                @TApplication.HintMouseMessage);
  RegisterMethod(TApplication, 'procedure Initialize;',
                @TApplication.Initialize);
  RegisterMethod(TApplication, 'function MessageBox(const Text, Caption: PChar;'
                +' Flags: Longint): Integer;',
                @TApplication.MessageBox);
  RegisterMethod(TApplication, 'procedure Minimize;',
                @TApplication.Minimize);
  RegisterMethod(TApplication, 'procedure NormalizeTopMosts;',
                @TApplication.NormalizeTopMosts);
  RegisterMethod(TApplication, 'procedure ProcessMessages;',
                @TApplication.ProcessMessages);
  RegisterMethod(TApplication, 'procedure Restore;',
                @TApplication.Restore);
  RegisterMethod(TApplication, 'procedure RestoreTopMosts;',
                @TApplication.RestoreTopMosts);
  RegisterMethod(TApplication, 'procedure Run;',
                @TApplication.Run);
  RegisterMethod(TApplication, 'procedure Terminate;',
                @TApplication.Terminate);
  RegisterMethod(TApplication, 'function GetActive: Boolean;',
                @TApplication_GetActive, Fake);
  RegisterProperty(TApplication, 'property Active: Boolean read GetActive;');
  RegisterProperty(TApplication, 'property AllowTesting: Boolean read'
                +' GetAllowTesting write SetAllowTesting;');
  RegisterMethod(TApplication, 'function GetCurrentHelpFile: string;',
                @TApplication_GetCurrentHelpFile, Fake);
  RegisterProperty(TApplication, 'property CurrentHelpFile: string read'
                +' GetCurrentHelpFile;');
  RegisterMethod(TApplication, 'function GetExeName: string;',
                @TApplication_GetExeName, Fake);
  RegisterProperty(TApplication, 'property ExeName: string read GetExeName;');
  RegisterMethod(TApplication, 'function GetHelpFile: string;',
                @TApplication_GetHelpFile, Fake);
  RegisterMethod(TApplication, 'procedure SetHelpFile(Value: string);',
                @TApplication_SetHelpFile, Fake);
  RegisterProperty(TApplication, 'property HelpFile: string read GetHelpFile'
                +' write SetHelpFile;');
  RegisterMethod(TApplication, 'function GetHint: string;',
                @TApplication_GetHint, Fake);
  RegisterMethod(TApplication, 'procedure SetHint(const Value: string);',
                @TApplication_SetHint, Fake);
  RegisterProperty(TApplication, 'property Hint: string read GetHint write SetHint;');
  RegisterMethod(TApplication, 'function GetHintColor: TColor;',
                @TApplication_GetHintColor, Fake);
  RegisterMethod(TApplication, 'procedure SetHintColor(Value: TColor);',
                @TApplication_SetHintColor, Fake);
  RegisterProperty(TApplication, 'property HintColor: TColor read GetHintColor'
                +' write SetHintColor;');
  RegisterMethod(TApplication, 'function GetHintHidePause: Integer;',
                @TApplication_GetHintHidePause, Fake);
  RegisterMethod(TApplication, 'procedure SetHintHidePause(Value: Integer);',
                @TApplication_SetHintHidePause, Fake);
  RegisterProperty(TApplication, 'property HintHidePause: Integer read'
                +' GetHintHidePause write SetHintHidePause;');
  RegisterMethod(TApplication, 'function GetHintPause: Integer;',
                @TApplication_GetHintPause, Fake);
  RegisterMethod(TApplication, 'procedure SetHintPause(Value: Integer);',
                @TApplication_SetHintPause, Fake);
  RegisterProperty(TApplication, 'property HintPause: Integer read'
                +' GetHintPause write SetHintPause;');
  RegisterMethod(TApplication, 'function GetHintShortCuts: Boolean;',
                @TApplication_GetHintShortCuts, Fake);
  RegisterMethod(TApplication, 'procedure SetHintShortCuts(Value: Boolean);',
                @TApplication_SetHintShortCuts, Fake);
  RegisterProperty(TApplication, 'property HintShortCuts: Boolean read'
                +' GetHintShortCuts write SetHintShortCuts;');
  RegisterMethod(TApplication, 'function GetHintShortPause: Integer;',
                @TApplication_GetHintShortPause, Fake);
  RegisterMethod(TApplication, 'procedure SetHintShortPause(Value: Integer);',
                @TApplication_SetHintShortPause, Fake);
  RegisterProperty(TApplication, 'property HintShortPause: Integer read'
                +' GetHintShortPause write SetHintShortPause;');
  RegisterMethod(TApplication, 'function GetIcon: TIcon;',
                @TApplication_GetIcon, Fake);
  RegisterMethod(TApplication, 'procedure SetIcon(Value: TIcon);',
                @TApplication_SetIcon, Fake);
  RegisterProperty(TApplication, 'property Icon: TIcon read GetIcon write SetIcon;');
  RegisterMethod(TApplication, 'function GetMainForm: TForm;',
                @TApplication_GetMainForm, Fake);
  RegisterProperty(TApplication, 'property MainForm: TForm read GetMainForm;');
end.
