////////////////////////////////////////////////////////////////////////////
// PAXScript Importing
// Author: Alexander Baranovsky (ab@cable.netlux.org)
// ========================================================================
// Copyright (c) Alexander Baranovsky, 2003. All rights reserved.
// Code Version: 1.5
// ========================================================================
// Unit: IMP_SysUtils.pas
// ========================================================================
////////////////////////////////////////////////////////////////////////////


{$I PaxScript.def}
unit IMP_SysUtils;
interface
uses
{$IFDEF VARIANTS}
  Variants,
{$ENDIF}
  SysUtils,
  BASE_SYS,
  BASE_CLASS,
  BASE_EXTERN,
  PaxScripter;

implementation

procedure _FileRead(MethodBody: TPAXMethodBody);
var
  H, Count: Integer;
  P: Pointer;
begin
  with MethodBody do
  begin
    H := toInteger(Params[0].AsVariant);
    Count := toInteger(Params[2].AsVariant);
    P := AllocMem(Count);
    result.AsInteger := FileRead(H, P^, Count);
    Params[1].AsVariant := UntypedValueToVariant(P, Count, Params[1].AsVariant);
  end;
end;

procedure _FileWrite(MethodBody: TPAXMethodBody);
var
  H, Count: Integer;
  P: Pointer;
begin
  with MethodBody do
  begin
    H := toInteger(Params[0].AsVariant);
    Count := toInteger(Params[2].AsVariant);
    P := AllocMem(Count);
    VariantToUntypedValue(Params[1].AsVariant, P, Count);
    result.AsInteger := FileWrite(H, P^, Count);
  end;
end;

procedure _StringReplace(MethodBody: TPAXMethodBody);
var
  Flags: TReplaceFlags;
begin
  with MethodBody do
  begin
    Flags := [];
    result.AsString := StringReplace(Params[0].AsString, Params[1].AsString, Params[2].AsString, Flags);
  end;
end;

procedure _ChDir(const S: string);
begin
  ChDir(S);
end;

var
  H: Integer;

initialization

   H := RegisterNamespace('SysUtils', -1);

// File management

   RegisterConstant('fmClosed', fmClosed, H);
   RegisterConstant('fmInput', fmInput, H);
   RegisterConstant('fmOutput', fmOutput, H);
   RegisterConstant('fmInOut', fmInOut, H);

   RegisterConstant('fmOpenRead', fmOpenRead, H);
   RegisterConstant('fmOpenWrite', fmOpenWrite, H);
   RegisterConstant('fmOpenReadWrite', fmOpenReadWrite, H);
{$IFDEF WIN32}
   RegisterConstant('fmShareCompat', fmShareCompat, H);
   RegisterConstant('fmShareExclusive', fmShareExclusive, H);
   RegisterConstant('fmShareDenyWrite', fmShareDenyWrite, H);
   RegisterConstant('fmShareDenyRead', fmShareDenyRead, H);
   RegisterConstant('fmShareDenyNone', fmShareDenyNone, H);
{$ENDIF}

   RegisterConstant('SecsPerDay', SecsPerDay, H);
   RegisterConstant('MSecsPerDay', MSecsPerDay, H);

   RegisterRoutine('function CreateDir(const Dir: string): Boolean;',
      @CreateDir, H);
   RegisterRoutine('function GetCurrentDir: string;',
      @GetCurrentDir, H);
   RegisterRoutine('function SetCurrentDir(const Dir: string): Boolean;',
      @SetCurrentDir, H);
   RegisterRoutine('procedure ChDir(const S: string);',
      @_ChDir, H);
   RegisterStdRoutine('FileRead', _FileRead, 3, H);
   RegisterStdRoutine('FileWrite', _FileWrite, 3, H);
   RegisterRoutine('function DeleteFile(const FileName: string): Boolean;',
      @DeleteFile, H);
   RegisterRoutine('function ExtractFileDir(const FileName: string): string;',
      @ExtractFileDir, H);
   RegisterRoutine('function ExtractFileDrive(const FileName: string): string;',
      @ExtractFileDrive, H);
   RegisterRoutine('function ExtractFileExt(const FileName: string): string;',
      @ExtractFileExt, H);
   RegisterRoutine('function ExtractFileName(const FileName: string): string;',
      @ExtractFileName, H);
   RegisterRoutine('function ExtractFilePath(const FileName: string): string;',
      @ExtractFilePath, H);
   RegisterRoutine('function ExtractRelativePath(const BaseName, DestName: string): string;',
      @ExtractRelativePath, H);
   RegisterRoutine('function FileAge(const FileName: string): Integer;',
      @FileAge, H);
   RegisterRoutine('procedure FileClose(Handle: Integer);',
      @FileClose, H);
   RegisterRoutine('function FileCreate(const FileName: string): Integer;',
      @FileCreate, H);
   RegisterRoutine('function FileExists(const FileName: string): Boolean;',
      @FileExists, H);
   RegisterRoutine('function FileOpen(const FileName: string; Mode: LongWord): Integer;',
      @FileOpen, H);
   RegisterRoutine('function FileSearch(const Name, DirList: string): string;',
      @FileSearch, H);
   RegisterRoutine('function FileSeek(Handle, Offset, Origin: Integer): Integer;',
      @FileSeek, H);
   RegisterRoutine('function ExpandFileName(const FileName: string): string;',
      @ExpandFileName, H);
   RegisterRoutine('function RenameFile(const OldName, NewName: string): Boolean;',
      @RenameFile, H);
{$IFDEF WIN32}
   RegisterRoutine('function ExtractShortPathName(const FileName: string): string;',
      @ExtractShortPathName, H);
   RegisterRoutine('function FileSetAttr(const FileName: string; Attr: Integer): Integer;',
      @FileSetAttr, H);
   RegisterRoutine('function FileGetAttr(const FileName: string): Integer;',
      @FileGetAttr, H);
   RegisterRoutine('function DiskFree(Drive: Byte): Int64;',
      @DiskFree, H);
   RegisterRoutine('function DiskSize(Drive: Byte): Int64;',
      @DiskSize, H);
{$ENDIF}

// Package management

   RegisterRoutine('function LoadPackage(const Name: string): HMODULE;',
      @LoadPackage, H);
   RegisterRoutine('procedure UnloadPackage(Module: HMODULE);',
      @UnloadPackage, H);

// String management

  RegisterConstant('rfReplaceAll', rfReplaceAll, H);
   RegisterConstant('rfIgnoreCase', rfIgnoreCase, H);
   RegisterStdRoutine('StringReplace', _StringReplace, 4, H);

   RegisterRoutine('function StrToCurr(const S: string): Currency;',
      @StrToCurr, H);
   RegisterRoutine('function StrToDate(const S: string): TDateTime;',
      @StrToDate, H);
   RegisterRoutine('function StrToFloat(const S: string): Extended;',
      @StrToFloat, H);
   RegisterRoutine('function StrToInt(const S: string): Integer;',
      @StrToInt, H);
   RegisterRoutine('function StrToTime(const S: string): TDateTime;',
      @StrToTime, H);
   RegisterRoutine('function Time: TDateTime;',
      @Time, H);
   RegisterRoutine('function TimeToStr(Time: TDateTime): string;',
      @TimeToStr, H);
   RegisterRoutine('function Trim(const S: string): string;',
      @Trim, H);
   RegisterRoutine('function TrimLeft(const S: string): string;',
      @TrimLeft, H);
   RegisterRoutine('function TrimRight(const S: string): string;',
      @TrimRight, H);
   RegisterRoutine('function UpperCase(const S: string): string;',
      @UpperCase, H);
   RegisterRoutine('function LowerCase(const S: string): string;',
      @LowerCase, H);

// Conversions

   RegisterRoutine('function FloatToStr(Value: Extended): string;',
      @FloatToStr, H);
   RegisterRoutine('function CompareText(const S1, S2: string): Integer;',
      @CompareText, H);
   RegisterRoutine('function CurrToStr(Value: Currency): string;',
      @CurrToStr, H);
   RegisterRoutine('function IntToStr(Value: Integer): string; overload;',
      @IntToStr, H);
   RegisterRoutine('function DateTimeToFileDate(DateTime: TDateTime): Integer;',
      @DateTimeToFileDate, H);
   RegisterRoutine('function DateTimeToStr(DateTime: TDateTime): string;',
      @DateTimeToStr, H);
   RegisterRoutine('procedure DateTimeToString(var Result: string; const Format: string; DateTime: TDateTime);',
      @DateTimeToString, H);
   RegisterRoutine('function DateToStr(Date: TDateTime): string;',
      @DateToStr, H);
   RegisterRoutine('function IntToHex(Value: Integer; Digits: Integer): string; overload;',
      @IntToHex, H);

// Date management

   RegisterRoutine('function Date: TDateTime;',
      @Date, H);
   RegisterRoutine('function DayOfWeek(Date: TDateTime): Integer;',
      @DayOfWeek, H);
   RegisterRoutine('procedure DecodeDate(Date: TDateTime; var Year, Month, Day: Word);',
      @DecodeDate, H);
   RegisterRoutine('procedure DecodeTime(Time: TDateTime; var Hour, Min, Sec, MSec: Word);',
      @DecodeTime, H);
   RegisterRoutine('function EncodeDate(Year, Month, Day: Word): TDateTime;',
      @EncodeDate, H);
   RegisterRoutine('function EncodeTime(Hour, Min, Sec, MSec: Word): TDateTime;',
      @EncodeTime, H);
   RegisterRoutine('function IncMonth(const Date: TDateTime; NumberOfMonths: Integer): TDateTime;',
      @IncMonth, H);
   RegisterRoutine('function IsDelimiter(const Delimiters, S: string; Index: Integer): Boolean;',
      @IsDelimiter, H);
   RegisterRoutine('function IsLeapYear(Year: Word): Boolean;',
      @IsLeapYear, H);
   RegisterRoutine('function IsPathDelimiter(const S: string; Index: Integer): Boolean;',
      @IsPathDelimiter, H);
   RegisterRoutine('function LastDelimiter(const Delimiters, S: string): Integer;',
      @LastDelimiter, H);
   RegisterRoutine('function Now: TDateTime;',
      @Now, H);
   RegisterConstant('DateDelta', DateDelta, H);
   RegisterRoutine('function RemoveDir(const Dir: string): Boolean;',
      @RemoveDir, H);
   RegisterRoutine('procedure ReplaceDate(var DateTime: TDateTime; const NewDate: TDateTime);',
      @ReplaceDate, H);
   RegisterRoutine('procedure ReplaceTime(var DateTime: TDateTime; const NewTime: TDateTime);',
      @ReplaceTime, H);

// Misc

   RegisterRoutine('procedure Beep;',
      @Beep, H);
end.
